/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.echo;

import java.io.Serializable;
import java.util.EventListener;

import nextapp.echo.event.EventListenerList;
import nextapp.echo.event.ImageUpdateEvent;
import nextapp.echo.event.ImageUpdateListener;

/**
 * A base class from which ImageReferences which render images from binary 
 * streams are derived.
 */
public abstract class AbstractImageReference
implements ImageReference, Serializable {

    /**
     * A storage facility for <code>EventListener</code>s.
     * This <code>EventListenerList</code> is lazy-created, so it may be null
     * if no <code>ImageUpdateListener</code>s have yet been registered.
     */
    protected EventListenerList listenerList = null;

    /**
     * Default constructor.
     */
    public AbstractImageReference() {
        super();
    }
    
    /**
     * @see nextapp.echo.ImageReference#addImageUpdateListener(ImageUpdateListener)
     */
    public void addImageUpdateListener(ImageUpdateListener l) {
        if (listenerList == null) {
            listenerList = new EventListenerList();
        }

        listenerList.addListener(ImageUpdateListener.class, l);
    }
        
    /**
     * @see nextapp.echo.ImageReference#removeImageUpdateListener(ImageUpdateListener)
     */
    public void removeImageUpdateListener(ImageUpdateListener l) {
        if (listenerList != null) {
            listenerList.removeListener(ImageUpdateListener.class, l);
        }
    }
    
    /**
     * @see nextapp.echo.ImageReference#update()
     */
    public void update() {
        EventListener[] listeners = listenerList.getListeners(ImageUpdateListener.class);
        ImageUpdateEvent e = new ImageUpdateEvent(this);
        for (int index = 0; index < listeners.length; ++index) {
            ((ImageUpdateListener) listeners[index]).imageUpdate(e);
        }
    }
}
