/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.echo;

import nextapp.echo.event.ActionListener;
import nextapp.echo.event.ChangeListener;
import nextapp.echo.event.ItemListener;

/**
 * State model for buttons. <br>
 */
public interface ButtonModel {

    /**
     * Adds an <code>ActionListener</code> to the button.
     *
     * @param l The <code>ActionListener</code> to be added.
     */
    public void addActionListener(ActionListener l);
    
    /**
     * Adds a <code>ChangeListener</code> to the button.
     *
     * @param l The <code>ChangeListener</code> to be added.
     */
    public void addChangeListener(ChangeListener l);
    
    /**
     * Adds a <code>ItemListener</code> to the button.
     *
     * @param l The <code>ItemListener</code> to be added.
     */
    public void addItemListener(ItemListener l);
    
    /**
     * Notifies the model of the button's action having been invoked.
     */
    public void doAction();

    /**
     * Returns the action command for this button.
     *
     * @return The action command for this button.
     */
    public String getActionCommand();
    
    /**
     * Returns the button's selection state.
     *
     * @return The button's selection state.
     */
    public boolean isSelected();
    
    /**
     * Removes an <code>ActionListener</code> from the button.
     *
     * @param l The <code>ActionListener</code> to be removed.
     */
    public void removeActionListener(ActionListener l);

    /**
     * Removes a <code>ChangeListener</code> from the button.
     *
     * @param l The <code>ChangeListener</code> to be removed.
     */
    public void removeChangeListener(ChangeListener l);
    
    /**
     * Removes a <code>ItemListener</code> from the button.
     *
     * @param l The <code>ItemListener</code> to be removed.
     */
    public void removeItemListener(ItemListener l);
    
    /**
     * Sets the button's action command.
     *
     * @param actionCommand The new action command for this button.
     */
    public void setActionCommand(String actionCommand);
    
    /**
     * Sets the button's group.  (Needed for radio buttons)
     *
     * @param newValue The button's new group.
     */
    public void setGroup(ButtonGroup newValue);

    /**
     * Sets the button's selection state.
     *
     * @param selected The new selection state of the button.
     */
    public void setSelected(boolean selected);
}
