/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.echo;

/**
 * A selectable &quot;check&quot; button.
 */
public class CheckBox extends ToggleButton {

    /**
     * Creates an initially unselected check box with no text or image.
     */
    public CheckBox() {
        this(null, null, false);
    }
    
    /**
     * Creates an initially unselected check box with the specified text.
     *
     * @param text The text to be displayed in the button.
     */
    public CheckBox(String text) {
        this(text, null, false);
    }
    
    /**
     * Creates a check box with the specified text and selection state.
     *
     * @param text The text to be displayed in the button.
     * @param selected The selection state of the check box.
     */
    public CheckBox(String text, boolean selected) {
        this(text, null, selected);
    }
    
    /**
     * Creates a initially unselected check box with the specified icon.
     *
     * @param icon The icon to be displayed in the button.
     */
    public CheckBox(ImageReference icon) {
        this(null, icon, false);
    }

    /**
     * Creates a check box with the specified icon and selection state.
     *
     * @param icon The icon to be displayed in the button.
     * @param selected The selection state of the check box.
     */
    public CheckBox(ImageReference icon, boolean selected) {
        this(null, icon, selected);
    }

    /**
     * Creates a check box with the specified text, icon and selection state.
     *
     * @param text The text to be displayed in the button.
     * @param icon The icon to be displayed in the button.
     * @param selected The selection state of the check box.
     */
    public CheckBox(String text, ImageReference icon, boolean selected) {
        super(text, icon, selected);
    }
}
