/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.echo;

import java.util.ArrayList;
import java.util.List;

/**
 * The default implementation of a ListBox's data model.
 */
public class DefaultListModel extends AbstractListModel 
implements ListModel {

    private List items = new ArrayList();
    
    /**
     * Creates a new DefaultSelectListModel with the given content.
     */
    public DefaultListModel() {
        super(); 
    }
    
    /**
     * Creates a new DefaultSelectListModel containing the specified data.
     *
     * @param itemArray An array of the initial items to be displayed in the
     *        ListBox.
     */
    public DefaultListModel(Object[] itemArray) {
        this();
        
        for (int index = 0; index < itemArray.length; ++index) {
            add(itemArray[index]);
        }
    }
    
    /**
     * Adds an item at the end of the model.
     *
     * @param item The item to add.
     */
    public void add(Object item) {
        items.add(item); 

        int index = items.size() - 1;
    
        fireIntervalAdded(this, index, index); 
    }
    
    /**
     * Inserts an item into the model at the specified index.
     *
     * @param item The item to insert.
     * @param index The index at which to insert the item.
     */
    public void add(int index, Object item) {
        items.add(index, item);

        fireIntervalAdded(this, index, index); 
    }
    
    /**
     * Returns the item at the specified position in the list.
     *
     * @param index The index of the item to return.
     * @return The item at the specified index.
     */
    public Object get(int index) {
        return items.get(index);
    }
    
    /**
     * Returns the index of the specified item within the model.
     *
     * @param item An item in the model.
     * @return The index of the item within the model.
     */
    public int indexOf(Object item) {
        return items.indexOf(item);
    }
    
    /**
     * Removes the item at the specified index from the model.
     *
     * @param index The index of the item to remove.
     */
    public void remove(int index) {
        items.remove(index);

        fireIntervalRemoved(this, index, index); 
    }

    /**
     * Removes the specified item from the model.
     *
     * @param item The item to remove from the model.
     */
    public void remove(Object item) {
        int index = items.indexOf(item);
    
        items.remove(item);

        fireIntervalRemoved(this, index, index); 
    }

    /**
     * Returns the length of the list.
     *
     * @return The length of the list.
     */
    public int size() {
        return items.size();
    }
}
