/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.echo;

import java.io.Serializable;

/**
 * An immutable representation of a two-dimensional size (width and height).
 */
public class Dimension 
implements Serializable {

    private int width;
    private int height;

    /** 
     * Creates a new dimension of the given width and height.
     *
     * @param width The width of the dimension.
     * @param height The height of the dimension.
     */
    public Dimension(int width, int height) {
        super();

        this.width = width;
        this.height = height;
    }

    /**
     * Returns true if this coordinate is equivalent to the provided object.
     *
     * @param o The object to test this dimension for equality with.
     * @return True if this dimension is equivalent to the provided object.
     */
    public boolean equals(Object o) {
        boolean equal;

        if (o != null && o instanceof Dimension) {
            Dimension that = (Dimension) o;
            equal = (this.getWidth() == that.getWidth()) && (this.getHeight() == that.getHeight());
        } else {
            equal = false;
        }

        return equal;
    }

    /**
     * Returns the height of this dimension.
     *
     * @return The height of this dimension.
     */
    public int getHeight() {
        return height;
    }

    /**
     * Returns the width of this dimension.
     *
     * @return The width of this dimension.
     */
    public int getWidth() {
        return width;
    }
}

