/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.echo;

import java.io.Serializable;

import nextapp.echo.event.ImageUpdateListener;

/**
 * A reference to an image that may be retrieved through an HTTP request.
 */
public class HttpImageReference 
implements ImageReference, Serializable {

    private String uri;
    private int height;
    private int width;

    /**
     * Creates a reference to an image at the specified URI of unknown size.
     *
     * @param uri A URI referencing the image.
     */
    public HttpImageReference(String uri) {
        this(uri, ImageReference.SIZE_UNKNOWN, ImageReference.SIZE_UNKNOWN);
    }
    
    /**
     * Creates a reference to an image at the specified URI of the given width
     * and height.  If the image is not of the given width and height, it will
     * be scaled to the given width and height.
     *
     * @param uri A URI referencing the image.
     * @param width The width at which to render the image, in pixels.
     * @param height The height at which to render the image in pixels.
     */
    public HttpImageReference(String uri, int width, int height) {
        super();

        this.uri = uri;
        this.width = width;
        this.height = height;
    }
    
    /**
     * Not supported.
     * 
     * @see nextapp.echo.ImageReference#addImageUpdateListener(ImageUpdateListener)
     */
    public void addImageUpdateListener(ImageUpdateListener l) { }
    
    /**
     * Returns the height of the image in pixels.
     *
     * @return The height of the image in pixels.
     * 
     * @see nextapp.echo.ImageReference#getHeight()
     */
    public int getHeight() {
        return height;
    }
    
    /**
     * Returns the URI that contains the image.
     *
     * @return The URI that contains the image.
     */
    public String getUri() {
        return uri;
    }
    
    /**
     * Returns the width of the image in pixels.
     *
     * @return The width of the image in pixels.
     * 
     * @see nextapp.echo.ImageReference#getWidth()
     */
    public int getWidth() {
        return width;
    }
    
    /**
     * Not supported.
     * 
     * @see nextapp.echo.ImageReference#removeImageUpdateListener(ImageUpdateListener)
     */
    public void removeImageUpdateListener(ImageUpdateListener l) { }

    /**
     * Not supported.
     * 
     * @see nextapp.echo.ImageReference#update()
     */
    public void update() { }
}
