/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * Contributed by Phillip Baird
 */

package nextapp.echo.table;

import java.util.Iterator;

import nextapp.echo.event.TableColumnModelListener;

/**
 * A representation of a table's columns.
 */
public interface TableColumnModel {
    
    /**
     * Adds a table column to the end of the table column model.
     *
     * @param column The table column to be added.
     */
    public void addColumn(TableColumn column);
    
    /**
     * Adds a listener for table column model events.
     *
     * @param l The listener to add.
     */ 
    public void addColumnModelListener(TableColumnModelListener l);

    /**
     * Returns the table column found at the specified index.
     *
     * @param columnIndex The index of the TableColumn to return.
     * @return The table column at the given index.
     */
    public TableColumn getColumn(int columnIndex);
    
    /**
     * Returns the number of columns in the column model.
     *
     * @return The number of columns specified in this table column model.
     */
    public int getColumnCount();
    
    /**
     * Returns the index of the table column with the given identifier.
     *
     * @param identifier The identifier of the table column to return.
     * @return The index of the given table column.
     * @throws IllegalArgumentException if the value of <code>identifier</code>
     *         is null or if the no column was found with the given identifier.
     */
    public int getColumnIndex(Object identifier);
    
    /**
     * Returns an iterator over the columns of the column model.
     *
     * @return An iterator over the columns of the column model.
     */
    public Iterator getColumns();
    
    /**
     * Moves a table column to a new index.
     *
     * @param columnIndex The index of the column to move.
     * @param newIndex The index to move the column to.
     */
    public void moveColumn(int columnIndex, int newIndex);
    
    /**
     * Remove a table column.
     *
     * @param column The column to remove.
     */
    public void removeColumn(TableColumn column);
    
    /**
     * Removes a listener for table column model events.
     *
     * @param l The listener to remove.
     */ 
    public void removeColumnModelListener(TableColumnModelListener l);
}
