package nextapp.echo.test;

import java.util.Locale;

import nextapp.echo.Color;
import nextapp.echo.Component;
import junit.framework.TestCase;

/**
 * <code>TestCase</code> for <code>nextapp.echo.Component</code>. 
 */
public class ComponentTest extends TestCase {
    
    /**
     * Tests <code>background</code> property.
     */
    public void testBackground() {
        NullComponent c = new NullComponent();
        PropertyChangeEvaluator pce = new PropertyChangeEvaluator();
        c.addPropertyChangeListener(pce);
        c.setBackground(new Color(0x12, 0x34, 0x56));
        assertEquals(new Color(0x12, 0x34, 0x56), c.getBackground());
        assertEquals(Component.BACKGROUND_CHANGED_PROPERTY, pce.lastEvent.getPropertyName());
    }

    public void testFont() {
    }

    /**
     * Tests <code>foreground</code> property.
     */
    public void testForeground() {
        NullComponent c = new NullComponent();
        PropertyChangeEvaluator pce = new PropertyChangeEvaluator();
        c.addPropertyChangeListener(pce);
        c.setForeground(new Color(0x12, 0x34, 0x56));
        assertEquals(new Color(0x12, 0x34, 0x56), c.getForeground());
        assertEquals(Component.FOREGROUND_CHANGED_PROPERTY, pce.lastEvent.getPropertyName());
    }

    /**
     * Tests adding multiple child components and retrieving one at a specific
     * index via <code>getComponent()</code>.
     */
    public void testGetComponent() {
        NullComponent c = new NullComponent();
        for (int i = 0; i < 5; ++ i) {
            c.add(new NullComponent());
        }
        NullComponent sixthComponent = new NullComponent();
        c.add(sixthComponent);
        for (int i = 0; i < 5; ++ i) {
            c.add(new NullComponent());
        }
        assertTrue(sixthComponent == c.getComponent(5));
    }

    /**
     * Tests <code>getComponentCount()</code>.
     */
    public void testGetComponentCount() {
        NullComponent c = new NullComponent();
        for (int i = 0; i < 5; ++ i) {
            c.add(new NullComponent());
        }
        assertEquals(5, c.getComponentCount());
    }

    public void testGetComponents() {
    }

    /**
     * Tests <code>identifier</code> property.
     */
    public void testIdentifier() {
        NullComponent c = new NullComponent();
        PropertyChangeEvaluator pce = new PropertyChangeEvaluator();
        c.addPropertyChangeListener(pce);
        c.setIdentifier("foo");
        assertEquals("foo", c.getIdentifier());
        assertEquals(Component.IDENTIFIER_CHANGED_PROPERTY, pce.lastEvent.getPropertyName());
    }

    /**
     * Tests querying <code>locale</code> property when no application is 
     * active. 
     */
    public void testLocaleWithoutApplication() {
        NullComponent c = new NullComponent();
        assertNull(c.getLocale());
        c.setLocale(Locale.TRADITIONAL_CHINESE);
        assertEquals(Locale.TRADITIONAL_CHINESE, c.getLocale());
    }
    
    /**
     * Tests basic <code>PropertyChangeListener</code> functionality.
     */
    public void testPropertyChangeListeners() {
        PropertyChangeEvaluator pce = new PropertyChangeEvaluator();
        NullComponent c = new NullComponent();
        c.addPropertyChangeListener(pce);
        c.setBackground(new Color(0xabcdef));
        assertEquals(null, pce.lastEvent.getOldValue());
        assertEquals(new Color(0xabcdef), pce.lastEvent.getNewValue());
        assertEquals(c, pce.lastEvent.getSource());
        assertEquals(Component.BACKGROUND_CHANGED_PROPERTY, pce.lastEvent.getPropertyName());
        c.setBackground(new Color(0xfedcba));
        assertEquals(new Color(0xabcdef), pce.lastEvent.getOldValue());
        assertEquals(new Color(0xfedcba), pce.lastEvent.getNewValue());
        c.setBackground(null);
        assertEquals(new Color(0xfedcba), pce.lastEvent.getOldValue());
        assertEquals(null, pce.lastEvent.getNewValue());
    }
    
    /**
     * Tests <code>tabIndex</code> property.
     */
    public void testTabIndex() {
        Component c = new NullComponent();
        PropertyChangeEvaluator pce = new PropertyChangeEvaluator();
        c.addPropertyChangeListener(pce);
        assertEquals(0, c.getTabIndex());
        c.setTabIndex(5);
        assertEquals(Component.TAB_INDEX_CHANGED_PROPERTY, pce.lastEvent.getPropertyName());
        assertEquals(5, c.getTabIndex());
        c.setVisible(false);
        assertEquals(false, c.isVisible());
        assertEquals(5, c.getTabIndex());
        c.setTabIndex(70);
        assertEquals(false, c.isVisible());
        assertEquals(70, c.getTabIndex());
    }
}
