/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.echoservlet;

import nextapp.echo.BackgroundImageProperties;
import nextapp.echo.Extent;

/**
 * Utility to render add background data contained in a 
 * <code>BackgroundImageProperties</code> object to a 
 * <code>ComponentStyle</code>.
 */
public class BackgroundImagePropertiesRenderer {

    private static final Extent EXTENT_0_PX = new Extent(0, Extent.PX);
    
    /**
     * Renders background data contained in a 
     * <code>BackgroundImageProperties</code> object to a 
     * <code>ComponentStyle</code>.
     * 
     * @param bgProperties The background image data.
     * @param imageUri The URI of the background image.
     * @param style The <code>ComponentStyle</code> to be updated.
     */
    public static void render(BackgroundImageProperties bgProperties, String imageUri, ComponentStyle style) {
        style.setBackgroundImage(imageUri);
        switch (bgProperties.getRepeat()) {
        case BackgroundImageProperties.REPEAT:
            style.addAttribute("background-repeat", "repeat");
            break;
        case BackgroundImageProperties.REPEAT_HORIZONTAL:
            style.addAttribute("background-repeat", "repeat-x");
            break;
        case BackgroundImageProperties.REPEAT_VERTICAL:
            style.addAttribute("background-repeat", "repeat-y");
            break;
        case BackgroundImageProperties.NO_REPEAT:
            style.addAttribute("background-repeat", "no-repeat");
            break;
        }
        if (bgProperties.getAttachment() == BackgroundImageProperties.ATTACHMENT_FIXED) {
            style.addAttribute("background-attachment", "fixed");   
        } else if (bgProperties.getAttachment() == BackgroundImageProperties.ATTACHMENT_SCROLL) {
            style.addAttribute("background-attachment", "scroll");   
        }
        StringBuffer position = new StringBuffer();
        if (bgProperties.getHorizontalPositionExtent() == null) {
            position.append(EXTENT_0_PX);
        } else {
            position.append(ExtentRenderer.render(bgProperties.getHorizontalPositionExtent()));
        }
        position.append(" ");
        if (bgProperties.getVerticalPositionExtent() == null) {
            position.append(EXTENT_0_PX);
        } else {
            position.append(ExtentRenderer.render(bgProperties.getVerticalPositionExtent()));
        }
        style.addAttribute("background-position", position.toString());
    }
    
    /** Non-instantiable class. */
    private BackgroundImagePropertiesRenderer() { }
}
