/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.echoservlet;

import nextapp.echoservlet.html.Element;
import nextapp.echoservlet.html.ElementNames;

/**
 * A utility class that provides methods for creating commonly used HTML 
 * elements.
 */
public class HtmlElements {

    /**
     * Creates a hidden form field with the provided name and value.
     *
     * @param name The name of the form field.
     * @param value The initial value of the form field.  If the value
     *        is null, the hidden field will be rendered without a
     *        &quot;value&quot; attribute.  If a value is provided, it
     *        must be in <code>application/x-www-form-urlencoded</code> 
     *        MIME format.
     * @return The generated hidden form field.
     */
    public static Element createHiddenField(String name, String value) {
        Element hiddenField = new Element(ElementNames.INPUT, false);

        hiddenField.addAttribute("type", "hidden");
        hiddenField.addAttribute("name", name);
        if (value != null) {
            hiddenField.addAttribute("value", value);
        }
        
        return hiddenField;
    }
    
    /**
     * Creates a script element to include an external script file.
     *
     * @param conn The connection to which the document will be 
     *        rendered.
     * @param service The service containing the JavaScript code to be 
     *        included.
     * @return An &lt;script&gt; element that will include the 
     *         JavaScript code.
     */
    public static Element createScriptInclude(Connection conn, Service service) {
        Element include = new Element(ElementNames.SCRIPT, true);
        
        include.setWhitespaceRelevant(true);
        include.addAttribute("language", "JavaScript1.3");
        include.addAttribute("src", ClientObjects.getServiceUri(conn, service)); 
        
        return include;
    }
    
    /** Non-instantiable class */
    private HtmlElements() { }
}
