/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.echoservlet;

import java.io.Serializable;
import java.util.Collections;
import java.util.Iterator;
import java.util.Map;

/**
 * The implementation of the <code>InitialParameters</code> interface.
 * 
 * @see InitialParameters
 */
class InitialParametersImpl 
implements InitialParameters, Serializable {

    private Map parameterMap;

    InitialParametersImpl(Map parameterMap) {
        if (parameterMap == null)
            throw new IllegalArgumentException("The InitialParameters parameterMap must be non null!");
        this.parameterMap = Collections.unmodifiableMap(parameterMap);
    }

    /**
	 * @see nextapp.echoservlet.InitialParameters#getAllParameterNames()
	 */
    public String[] getAllParameterNames() {
        return (String[]) parameterMap.keySet().toArray(new String[parameterMap.keySet().size()]);
    }

    /**
	 * @see nextapp.echoservlet.InitialParameters#getParameter(java.lang.String)
	 */
    public String getParameter(String name) {
        String values[] = (String[]) parameterMap.get(name);
        if (values == null || values.length == 0)
            return null;
        return values[0];
    }

    /**
	 * @see nextapp.echoservlet.InitialParameters#getParameterMap()
	 */
    public Map getParameterMap() {
        return parameterMap;
    }

    /**
	 * @see nextapp.echoservlet.InitialParameters#getParameterNames()
	 */
    public Iterator getParameterNames() {
        return parameterMap.keySet().iterator();
    }

    /**
	 * @see nextapp.echoservlet.InitialParameters#getParameterValues(java.lang.String)
	 */
    public String[] getParameterValues(String name) {
        String values[] = (String[]) parameterMap.get(name);
        return values;
    }
}
