/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.echoservlet;

import nextapp.echoservlet.html.Element;
import nextapp.echoservlet.html.ElementNames;
import nextapp.echoservlet.resource.ResourceNames;

/**
 * A utility class used to create image elements of various sizes that
 * referencing a blank image generating service.  These elements are used
 * to force separation of other elements in an HTML document.
 */
public class LayoutStrut {

    /** The blank pixel generating service */
    public static final Service SERVICE_BLANK_PIXEL 
            = StaticBinary.createFromResource(ClientObjects.STD_PREFIX + "ls", ResourceNames.BLANK_PIXEL);
    
    static {
        EchoServer.addGlobalService(SERVICE_BLANK_PIXEL);
    }

    /**
     * Creates an HTML &lt;img&gt; element that references a transparent image.
     *
     * @param conn The connection to which the containing document will be 
     *        rendered.
     * @param width The desired pixel width of the layout strut.
     * @param height The desired pixel height of the layout strut.
     * @return An HTML &lt;img&gt; element that references a transparent image 
     *         of the desired size.
     */
    public static Element createElement(Connection conn, int width, int height) {
        Element img = new Element(ElementNames.IMG, false);

        img.addAttribute("src", ClientObjects.getServiceUri(conn, SERVICE_BLANK_PIXEL));
        img.addAttribute("width", width);
        img.addAttribute("height", height);
        img.addAttribute("border", 0);
        img.addAttribute("alt", "");
        
        return img;
    }
    
    /** Non-instantiable class. */
    private LayoutStrut() { }
}
