/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.echoservlet;

/**
 * An interface implemented by services that may be held in a ContainerPane.
 * <b>Classes that implement this interface must extend ComponentPeer.</b>
 */
public interface PaneUI {

    /**
     * A scrolling attribute indicating that scrollbars should be displayed 
     * if necessary.
     */
    public static final String SCROLLING_AUTO = "auto";

    /**
     * A scrolling attribute indicating that scrollbars should always be
     * displayed.
     */
    public static final String SCROLLING_ALWAYS = "yes";

    /**
     * A scrolling attribute indicating that scrollbars should never be
     * displayed.
     */
    public static final String SCROLLING_NEVER = "no";

    /**
     * Returns the underlying <code>Service</code> <code>Id</code> for the 
     * pane.
     *
     * @return The underlying <code>Service</code> <code>Id</code> for the 
     *         pane.
     */
    public Id getId();

    /**
     * Returns the scrolling property of the pane.
     *
     * @return The scrolling property of the pane, one of the following values:
     *         <ul>
     *         <li>SCROLLING_AUTO</li>
     *         <li>SCROLLING_ALWAYS</li>
     *         <li>SCROLLING_NEVER</li>
     *         </ul>
     */
    public String getScrolling();

    /**
     * Returns the URI from which the pane's service may be rendered.
     *
     * @param conn The connection from which to derive the URI.
     * @return The URI from which the pane's service may be rendered.
     */
    public String getUri(Connection conn);
}
