/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.echoservlet;

import java.io.Serializable;
import java.security.Principal;
import javax.servlet.ServletConfig;
import javax.servlet.http.HttpSession;

/**
 * The implementation of the <code>ServerContext</code> interface.
 * @see ServerContext
 */
class ServerContextImpl 
implements Serializable, ServerContext {

    private InstancePeer instancePeer;
    private String defaultExitUri = "about:blank";

    /**
     * Creates a new instance for the given <code>InstancePeer</code>.
     *
     * @param instancePeer The <code>InstancePeer</code> that this 
     *        <code>ServerContext</code> will serve.
     */
    public ServerContextImpl(InstancePeer instancePeer) {
        super();
        
        this.instancePeer = instancePeer;
    }
    
    /**
     * @see nextapp.echoservlet.ServerContext#exit()
     */
    public void exit() {
        instancePeer.exit(defaultExitUri);
    }
    
    /**
     * @see nextapp.echoservlet.ServerContext#exit(String)
     */
    public void exit(String uri) {
        instancePeer.exit(uri);
    }
    
    /**
     * @see nextapp.echoservlet.ServerContext#getAbnormalExitUri()
     */
    public String getAbnormalExitUri() {
        return instancePeer.getErrorUri();
    }

    /**
     * @see nextapp.echoservlet.ServerContext#getClientProperties()
     */
    public ClientProperties getClientProperties() {
        return instancePeer.getClientProperties();
    }
    
    /**
     * @see nextapp.echoservlet.ServerContext#getCookieManager()
     */
    public CookieManager getCookieManager() {
        return instancePeer.getCookieManager();
    }
    
    /**
     * @see nextapp.echoservlet.ServerContext#getDefaultExitUri()
     */
    public String getDefaultExitUri() {
        return defaultExitUri;
    }
    
    /**
     * @see nextapp.echoservlet.ServerContext#getCharacterEncoding()
     */
    public String getCharacterEncoding() {
        return instancePeer.getCharacterEncoding();
    }

    /**
     * @see nextapp.echoservlet.ServerContext#getServletConfig()
     */
    public ServletConfig getServletConfig() {
        return instancePeer.getServletConfig();
    }
    
    /**
     * @see nextapp.echoservlet.ServerContext#getSession()
     */
    public HttpSession getSession() {
        return instancePeer.getSession();
    }
    
    /**
     * @see nextapp.echoservlet.ServerContext#getUserPrincipal()
     */
    public Principal getUserPrincipal() {
        return instancePeer.getUserPrincipal();
    }
    
    /**
     * @see nextapp.echoservlet.ServerContext#isUserInRole(String)
     */
    public boolean isUserInRole(String role) {
        return instancePeer.isUserInRole(role);
    }

    /**
     * @see nextapp.echoservlet.ServerContext#setAbnormalExitUri(String)
     */
    public void setAbnormalExitUri(String uri) {
        instancePeer.setErrorUri(uri);
    }
    
    /**
     * @see nextapp.echoservlet.ServerContext#setCharacterEncoding(String)
     */
    public void setCharacterEncoding(String characterEncoding) {
        instancePeer.setCharacterEncoding(characterEncoding);
    }
    
    /**
     * @see nextapp.echoservlet.ServerContext#setDefaultExitUri(String)
     */
    public void setDefaultExitUri(String uri) {
        defaultExitUri = uri;
    }
    
    /**
     * @see nextapp.echoservlet.ServerContext#suspend()
     */
    public void suspend() {
        instancePeer.suspend(defaultExitUri);
    }
    
    /**
     * @see nextapp.echoservlet.ServerContext#suspend(String)
     */
    public void suspend(String uri) {
        instancePeer.suspend(uri);
    }
}
