/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.echoservlet;

import java.io.Serializable;
import java.util.HashMap;
import java.util.Map;

/**
 * A container of custom data that is inserted into <code>Template</code>
 * documents at the time they are rendered.
 */
public class VariableData 
implements Serializable {

    /** A constant variable name used for storing an application's URI */
    public static final String APPLICATION_URI = "ApplicationURI";

    /** 
     * A constant variable name whose contents will be displayed during the 
     * application startup.
     */
    public static final String STARTUP_WINDOW_TITLE = "StartupWindowTitle";

    /** 
     * A constant variable name whose contents will be displayed during the 
     * application startup.
     */
    public static final String STARTUP_WINDOW_TEXT = "StartupWindowText";
    
    /** 
     * A constant variable name whose content is an integer indicating the
     * number of milliseconds to delay during the application startup.
     */
    public static final String STARTUP_DELAY = "StartupDelay";
    
    /** 
     * A constant variable name whose contents will be displayed during the 
     * application startup if JavaScript is not enabled.
     */
    public static final String STARTUP_NO_SCRIPT_ERROR_TEXT = "StartupNoScriptErrorText";
    
    /** 
     * A constant variable name identifying the URI of the splash screen
     * that should be displayed during the application startup.
     */
    public static final String SPLASH_SCREEN_URI = "SplashScreenUri";

    /** 
     * A constant variable name identifying the URI of the client detection
     * page that should be displayed during the application startup.
     */
    public static final String CLIENT_DETECT_URI = "ClientDetectUri";

    /** 
     * A constant variable name identifying the target frame to which the client 
     * detection page should submit.
     */                                                     
    public static final String CLIENT_DETECT_TARGET_FRAME = "ClientDetectTargetFrame";
    
    /**
     * A constant variable name used for storing the URI to which an expired 
     * session's client browser will be redirected 
     */
    public static final String SESSION_EXPIRATION_URI = "SessionExpirationURI";
    
    /**
     * A constant variable name used for storing the message which will 
     * be displayed in the event the user initiates an action on the client 
     * when it is not ready.
     */
    public static final String CLIENT_ERROR_NOT_READY = "ClientErrorNotReady";

    private Map fieldValues = new HashMap();
    
    /**
     * Creates a new <code>VariableData</code> object.
     */
    public VariableData() {
        super();
    }

    /**
     * Returns the dynamic content associated with the given <code>key<code>.
     *
     * @param key The key under which the dynamic content is stored.
     * @return The dynamic content stored under the specified <code>key</code>.
     */
    public String get(String key) {
        return (String) fieldValues.get(key);
    }

    /**
     * Sets the dynamic content associated with the given <code>key</code>.
     *
     * @param key The key under which the dynamic content is to be stored.
     * @param value The dynamic content to store.
     */
    public void set(String key, String value) {
        fieldValues.put(key, value);
    }
}
