/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.echoservlet.html;

/**
 * Constants for commonly used HTML element names.
 */
public class ElementNames {

    /**
     * Constants for commonly used HTML attribute names.
     */
    public static class Attributes {
    
        public static final String ALIGN = "align";
        public static final String ALT = "alt";
        public static final String BORDER = "border";
        public static final String CELLPADDING = "cellpadding";
        public static final String CELLSPACING = "cellspacing";
        public static final String CLASS = "class";
        public static final String HEIGHT = "height";
        public static final String HREF = "href";
        public static final String ID = "id";
        public static final String NAME = "name";
        public static final String ONMOUSEDOWN = "onmousedown";
        public static final String ONMOUSEOVER = "onmouseover";
        public static final String ONMOUSEOUT = "onmouseout";
        public static final String ONMOUSEUP = "onmouseup";
        public static final String ONCLICK = "onclick";
        public static final String SRC = "src";
        public static final String TITLE = "title";
        public static final String VALIGN = "valign";
        public static final String WIDTH = "width";
        
        /** Non-instantiable class. */
        private Attributes() { }
    }

    /**
     * Constants for commonly used CSS attribute names.
     */
    public static class CssAttributes {
    
        public static final String BACKGROUND_COLOR = "background-color";
        public static final String BACKGROUND_IMAGE = "background-image";
        public static final String BORDER_COLOR = "border-color";
        public static final String BORDER_STYLE = "border-style";
        public static final String BORDER_WIDTH = "border-width";
        public static final String COLOR = "color";
        public static final String FONT_FAMILY = "font-family";
        public static final String FONT_SIZE = "font-size";
        public static final String FONT_STYLE = "font-style";
        public static final String FONT_WEIGHT = "font-weight";
        public static final String HEIGHT = "height";
        public static final String TEXT_ALIGN = "text-align";
        public static final String TEXT_DECORATION = "text-decoration";
        public static final String VERTICAL_ALIGN = "vertical-align";
        public static final String WIDTH = "width";
        
        /** Non-instantiable class. */
        private CssAttributes() { }
    }

    public static final String A                            = "a";
    public static final String BODY                         = "body";
    public static final String BR                           = "br";
    public static final String COL                          = "col";
    public static final String COLGROUP                     = "colGroup";
    public static final String DIV                          = "div";
    public static final String FORM                         = "form";
    public static final String FRAME                        = "frame";
    public static final String FRAMESET                     = "frameset";
    public static final String HEAD                         = "head";
    public static final String HTML                         = "html";
    public static final String IFRAME                       = "iframe";
    public static final String IMG                          = "img";
    public static final String INPUT                        = "input";
    public static final String META                         = "meta";
    public static final String OPTION                       = "option";
    public static final String SCRIPT                       = "script";
    public static final String SELECT                       = "select";
    public static final String SPAN                         = "span";
    public static final String STYLE                        = "style";
    public static final String TABLE                        = "table";
    public static final String TD                           = "td";
    public static final String TEXTAREA                     = "textarea";
    public static final String TITLE                        = "title";
    public static final String TR                           = "tr";

    /** Non-instantiable class. */
    private ElementNames() { }
}
