/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.echoservlet.image;

import java.io.IOException;

import nextapp.echo.AwtImageReference;
import nextapp.echo.event.ImageUpdateEvent;
import nextapp.echo.event.ImageUpdateListener;
import nextapp.echoservlet.CacheableService;
import nextapp.echoservlet.ClientObjects;
import nextapp.echoservlet.Connection;
import nextapp.echoservlet.Id;
import nextapp.echoservlet.Service;
import nextapp.echoservlet.util.ContentType;

/**
 * An image peer for <code>AwtImageReference</code>s.
 */
public class AwtImagePeer extends ImagePeer 
implements CacheableService, ImageUpdateListener {

    private Id id = null;
    private int version = 0;

    /**
     * Default constructor.
     */
    public AwtImagePeer() {
        super();
    }
    
    /**
     * @see nextapp.echoservlet.image.ImagePeer#getAncillaryService()
     */
    public Service getAncillaryService() {
        return this;
    }

    /**
     * @see nextapp.echoservlet.Service#getId()
     */
    public Id getId() {
        return id;
    }
    
    /**
     * @see nextapp.echoservlet.image.ImagePeer#getUri(Connection)
     */
    public String getUri(Connection conn) {
        return ClientObjects.getServiceUri(conn, this);
    }

    /**
     * @see nextapp.echoservlet.CacheableService#getVersion()
     */
    public int getVersion() {
        return version;
    }
    
    /**
     * @see nextapp.echo.event.ImageUpdateListener#imageUpdate(ImageUpdateEvent)
     */
    public void imageUpdate(ImageUpdateEvent e) {
        ++version;
    }
    
	/**
	 * @see nextapp.echoservlet.image.ImagePeer#registered()
	 */
    public void registered() {
        getImageReference().addImageUpdateListener(this);
    }
    
	/**
	 * @see nextapp.echoservlet.image.ImagePeer#setId(Id)
	 */
    public void setId(Id id) {
        this.id = id;
    }

    /**
     * @see nextapp.echoservlet.Service#service(Connection)
     */
    public void service(Connection conn) 
    throws IOException {
        
        PngEncoder encoder = new PngEncoder(((AwtImageReference) getImageReference()).getImage(), true, null, 3);
        conn.setContentType(ContentType.IMAGE_PNG);
        encoder.encode(conn.getOutputStream());
    }
}
