/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.echoservlet.ui;

import nextapp.echo.CheckBox;

import nextapp.echoservlet.ClientInputProducer;
import nextapp.echoservlet.ClientObjects;
import nextapp.echoservlet.ControllerFieldInitialState;
import nextapp.echoservlet.EchoServer;
import nextapp.echoservlet.RenderingContext;
import nextapp.echoservlet.Service;
import nextapp.echoservlet.StaticBinary;
import nextapp.echoservlet.resource.ResourceNames;

/**
 * A peer for <code>CheckBox</code> components.
 */
public class CheckBoxUI extends ToggleButtonUI 
implements ClientInputProducer, ControllerFieldInitialState {

    /**
     * The value that will be stored in the controller form when the
     * button state is selected.
     */
    private static final String active = "1";

    /** A service that renders the default deselected check box image. */
    public static final Service SERVICE_CHECK_BOX_OFF 
            = StaticBinary.createFromResource(ClientObjects.STD_PREFIX + "cb0", ResourceNames.CHECK_BOX_OFF);
    
    /** A service that renders the default selected check box image. */
    public static final Service SERVICE_CHECK_BOX_ON 
            = StaticBinary.createFromResource(ClientObjects.STD_PREFIX + "cb1", ResourceNames.CHECK_BOX_ON);
    
    static {
        EchoServer.addGlobalService(SERVICE_CHECK_BOX_OFF);
        EchoServer.addGlobalService(SERVICE_CHECK_BOX_ON);
    }

    /**
     * @see nextapp.echoservlet.ClientInputProducer#clientInput(String)
     */
    public void clientInput(String input) {
        CheckBox checkBox = (CheckBox) getComponent();
        
        if (input != null && input.indexOf(active) != -1) {
            checkBox.setSelected(true);
        } else {
            checkBox.setSelected(false);
        }
    }
    
    /**
     * @see nextapp.echoservlet.ControllerFieldInitialState#getControllerFieldValue()
     */
    public String getControllerFieldValue() {
        CheckBox checkBox = (CheckBox) getComponent();
        return checkBox.isSelected() ? "1" : "0";
    }
    
    /**
     * @see nextapp.echoservlet.ui.ToggleButtonUI#getDefaultStateImageUri(RenderingContext, boolean)
     */
    public String getDefaultStateImageUri(RenderingContext rc, boolean selected) {
        return ClientObjects.getServiceUri(rc.getConnection(), 
                selected ? SERVICE_CHECK_BOX_ON : SERVICE_CHECK_BOX_OFF);
    }
    
    /**
     * @see nextapp.echoservlet.ui.AbstractButtonUI#getScriptAction(RenderingContext)
     */
    public String getScriptAction(RenderingContext rc) {
        CheckBox checkBox = (CheckBox) getComponent();
        
        if (checkBox.isEnabled()) {
            rc.getDocument().addScriptInclude(SERVICE_TOGGLE_BUTTON_SCRIPT);

            StringBuffer sb = new StringBuffer(ClientObjects.STD_PREFIX + "checkBoxAction(\'");
            sb.append(getId().toString());
            sb.append(checkBox.isSelected() ? "\', true, " : "\', false, ");
            sb.append(checkBox.hasActionListeners() ? "true, \'" : "false, \'");
            sb.append(getStateImageUri(rc, false));
            sb.append("\', \'");
            sb.append(getStateImageUri(rc, true));
            sb.append("\');");
            return sb.toString();
        } else {
            return ";";
        }
    }
}
