/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.echoservlet.ui;

import nextapp.echo.Filler;

import nextapp.echoservlet.ComponentPeer;
import nextapp.echoservlet.LayoutStrut;
import nextapp.echoservlet.html.Element;
import nextapp.echoservlet.html.ElementNames;
import nextapp.echoservlet.RenderingContext;

/**
 * A peer for <code>Filler</code> (strut) components.
 * This peer does not listen for <code>PropertyChangeEvent</code>s.
 */
public class FillerUI extends ComponentPeer {

    private static final Element ELEMENT_BR = new Element(ElementNames.BR, false);
    static {
        ELEMENT_BR.setSticky(true);
    }

    /**
     * @see nextapp.echoservlet.ComponentPeer#render(RenderingContext, Element)
     */
    public void render(RenderingContext rc, Element parent) {
        Filler filler = (Filler) getComponent();
        int width = filler.getWidth();
        int height = filler.getHeight();
        
        if (width >= 1) {
            parent.add(LayoutStrut.createElement(rc.getConnection(), width ,1));
            rc.getDocument().setCursorOnNewLine(false);
        } else if (height >= 0) {
            if (!rc.getDocument().isCursorOnNewLine()) {
                parent.add(ELEMENT_BR);
                rc.getDocument().setCursorOnNewLine(true);
            }
            if (height != 0) {
                parent.add(LayoutStrut.createElement(rc.getConnection(), 1, height));
                parent.add(ELEMENT_BR);
            }
        }
    }
}
