/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.echoservlet.ui;

import java.net.URLEncoder;

import nextapp.echoservlet.ClientObjects;
import nextapp.echoservlet.Connection;
import nextapp.echoservlet.EchoServer;
import nextapp.echoservlet.Id;
import nextapp.echoservlet.Service;
import nextapp.echoservlet.StaticText;
import nextapp.echoservlet.resource.ResourceNames;

/**
 * A utility class that wraps JavaScript code required to swap images in HTML 
 * pages on the client without server interaction.
 */
public class ImageSwapScript {

    /**
     * A service containing JavaScript code used to swap images on the client.
     */
    public static final Service SERVICE_IMAGE_SWAP_SCRIPT 
            = StaticText.createFromResource(ClientObjects.STD_PREFIX + "imgsw", ResourceNames.IMAGE_SWAP_SCRIPT);

    static {
        EchoServer.addGlobalService(SERVICE_IMAGE_SWAP_SCRIPT);
    }

    /**
     * Returns the JavaScript necessary to dynamically change an image that
     * exists in the client browser to the one specified in 
     * <code>newImageUri</code>.  This method is used by buttons to generate
     * rollover effects and by checkboxes and radio buttons to toggle their
     * state indicators without server interaction.<br>
     * <br>
     * This method makes use of a method of java.net.URLEncoder that has been
     * deprecated as of JDK 1.4.  There is no comparable non-deprecated method
     * that provides this functionality that is available with JDK 1.3.
     *
     * @param conn The connection whose response the generated script will be
     *             written to.
     * @param id The identifier of the image to be modified.
     * @param newImageUri The URI of the replacement image.
     * @return A JavaScript method call that should be invoked when the image is
     *         to be swapped.
     */
    public static String getScriptImageSwap(Connection conn, Id id, String newImageUri) {
        return ClientObjects.STD_PREFIX + "imageSwap(\'" + ClientObjects.IMAGE_NAME_PREFIX + id + "\', \'" 
                + URLEncoder.encode(newImageUri) + "\');";
    }
    
    /** Non-instantiable class. */
    private ImageSwapScript() { }
}
