/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.echoservlet.ui;

import nextapp.echo.TextArea;
import nextapp.echoservlet.ClientObjects;
import nextapp.echoservlet.ComponentStyle;
import nextapp.echoservlet.ContentPaneUI;
import nextapp.echoservlet.RenderingContext;
import nextapp.echoservlet.html.Element;
import nextapp.echoservlet.html.ElementNames;
import nextapp.echoservlet.html.Html;

/**
 * A peer for <code>TextArea</code> components.
 */
public class TextAreaUI extends TextComponentUI {

    /**
     * @see nextapp.echoservlet.ComponentPeer#render(RenderingContext, Element)
     */
    public void render(RenderingContext rc, Element parent) {
        TextArea textArea = (TextArea) getComponent();
        Element element = new Element(ElementNames.TEXTAREA);
        element.addAttribute(ElementNames.Attributes.ID, getId().toString());
        element.setWhitespaceRelevant(true);
        
        renderedActive = textArea.isEditable() && textArea.isEnabled();

        ComponentStyle style = getStyle();
        style.addElementType(ElementNames.TEXTAREA);

        element.addAttribute("type", "text");
        switch (textArea.getColumnUnits()) {
        case TextArea.CHARACTER_UNITS:
            element.addAttribute("cols", textArea.getColumns());
            break;
        case TextArea.PIXEL_UNITS:
            style.addAttribute("width", textArea.getColumns(), ComponentStyle.PIXEL_UNITS);
            break;
        case TextArea.PERCENT_UNITS:
            style.addAttribute("width", textArea.getColumns(), ComponentStyle.PERCENT_UNITS);
            break;
        default:
            throw new IllegalStateException("Unsupported column units.");
        }
        switch (textArea.getRowUnits()) {
        case TextArea.CHARACTER_UNITS:
            element.addAttribute("rows", textArea.getRows());
            break;
        case TextArea.PIXEL_UNITS:
            style.addAttribute("height", textArea.getRows(), ComponentStyle.PIXEL_UNITS);
            break;
        case TextArea.PERCENT_UNITS:
            style.addAttribute("height", textArea.getRows(), ComponentStyle.PERCENT_UNITS);
            break;
        default:
            throw new IllegalStateException("Unsupported row units.");
        }
        element.addAttribute("name", ClientObjects.getObjectName(getId()));
        element.addAttribute("tabIndex", getTabIndex());
        element.addAttribute("wrap", textArea.getLineWrap() ? "soft" : "off");
        element.addAttribute("onblur", ContentPaneUI.getScriptSetParameter("\'" + getId() + "\'", "this.value"));
        if (!textArea.isEditable()) {
            element.addAttribute("readonly");
        }
        if (!textArea.isEnabled()) {
            element.addAttribute("disabled");
        }
        if (textArea.getToolTipText() != null) {
            element.addAttribute("title", Html.encode(textArea.getToolTipText(), Html.NEWLINE_TO_SPACE));
        }

        String styleName = rc.getDocument().addStyle(style);
        element.addAttribute(ElementNames.Attributes.CLASS, styleName);

        element.addText(textArea.getText(), false);
        
        parent.add(element);
        rc.getDocument().setCursorOnNewLine(false);
    }
}
