/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.echoservlet.util;

import java.util.Collection;
import java.util.Iterator;

/** 
 * Converts arrays to <code>Strings</code>, adding a specified delimiter between 
 * elements.
 */
public class Delimiter {
    
    /**
     * Returns the contents of an array as a <code>String</code>, adding the 
     * specified delimiter between elements.
     *
     * @param array The array to be converted.
     * @param delimiter The delimiter to be added between array elements.
     * @return A <code>String</code> containing the elements of the array 
     *         delimited by the specified delimiter.
     */
    public static String toString(Object[] array, String delimiter) {
        StringBuffer sb = new StringBuffer();
        
        for (int index = 0; index < array.length - 1; ++index) {
            sb.append(array[index]);
            sb.append(delimiter);
        }
        
        if (array.length > 0) {
            sb.append(array[array.length - 1]);
        }
        
        return sb.toString();
    }
    
    /**
     * Returns the contents of an <code>Collection</code> as a 
     * <code>String</code>, adding the specified delimiter between elements.
     *
     * @param collection The collection to be converted.
     * @param delimiter The delimiter to be added between objects in the 
     *        <code>Collection</code>.
     * @return A <code>String</code> containing the elements of the 
     *         <code>Collection</code> delimited by the specified delimiter.
     */
    public static String toString(Collection collection, String delimiter) {
        StringBuffer sb = new StringBuffer();

        for (Iterator it = collection.iterator(); it.hasNext();) {
            sb.append(it.next());
            if (it.hasNext()) {
                sb.append(delimiter);
            }
        }
        
        return sb.toString();
    }
    
    /** Non-instantiable class. */
    private Delimiter() { }
}
