/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.echoservlet.util;

/**
 * A utility class for working with <code>String</code>s.
 */
public class StringUtil {

    /**
     * Searches for specified text within a string and replaces occurrences
     * with new text.
     *
     * @param in The string to search and modify.
     * @param find The text to be found and replaced.
     * @param replace The text with which to replace instances of the text 
     *        specified by the <code>find</code> parameter.
     * @return A new string with instances of <code>find</code> having been
     *         replaced with <code>replace</code>.
     */
    public static String replace(String in, String find, String replace) {
        int end = in.indexOf(find);
        String out = null;
        
        if (end == -1) {
            out = in;
        } else {
            int findLength = find.length();
            int start = 0;
            StringBuffer sb = new StringBuffer();
            while(end != -1) {
                sb.append(in.substring(start, end));
                sb.append(replace);
                start = end + findLength;
                end = in.indexOf(find, start);
            }
            sb.append(in.substring(start));
            out = sb.toString();
        }
        
        return out;
        
    }
    
    /** Non-instantiable class. */
    private StringUtil() { }
}
