/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

import nextapp.echo.*;
import nextapp.echo.event.*;

import nextapp.echoservlet.EchoServer;

public class WinTestServlet extends EchoServer {

    public EchoInstance newInstance() {
        return new WinTestInstance();
    }
}

class WinTestInstance extends EchoInstance {

    public Window init() {
        return new TestWindow(this);
    }
}

class TestWindow extends Window {
    private WinTestInstance wti;

    public TestWindow(WinTestInstance wti) {
        super();
        
        this.wti = wti;
        setContent(new AlphaContentPane(this));
    }
    
    public WinTestInstance getInstance() {
        return wti;
    }
}

class TestContentPane extends ContentPane 
implements ActionListener {
    private TestWindow testWin;
    private Button alphaButton;
    private Button betaButton;
    private Button newWindowButton;
    private Button closeWindowButton;

    public TestContentPane(TestWindow testWin) {
        super();
        
        this.testWin = testWin;
        setForeground(Color.WHITE);
        
        newWindowButton = new Button("Add Window");
        newWindowButton.addActionListener(this);
        add(newWindowButton);
        closeWindowButton = new Button("Close Window");
        closeWindowButton.addActionListener(this);
        add(closeWindowButton);
        add(Filler.createVerticalStrut(0));
        
        alphaButton = new Button("Change to ALPHA");
        alphaButton.setBackground(AlphaContentPane.BG);
        alphaButton.addActionListener(this);
        add(alphaButton);
        add(Filler.createVerticalStrut(0));
        betaButton = new Button("Change to BETA");
        betaButton.setBackground(BetaContentPane.BG);
        betaButton.addActionListener(this);
        add(betaButton);
    }
    
    public void actionPerformed(ActionEvent e) {
        if (e.getSource() == alphaButton) {
            testWin.setContent(new AlphaContentPane(testWin));
        } else if (e.getSource() == betaButton) {
            testWin.setContent(new BetaContentPane(testWin));
        } else if (e.getSource() == newWindowButton) {
            Window newWindow = new TestWindow(testWin.getInstance());
            testWin.getInstance().addWindow(newWindow);
        } else if (e.getSource() == closeWindowButton) {
            testWin.dispose();
        }
    }
}

class AlphaContentPane extends TestContentPane {
    public static final Color BG = new Color(0x00, 0x3f, 0x1f);

    public AlphaContentPane(TestWindow testWin) {
        super(testWin);
        
        setBackground(BG);
    }
}

class BetaContentPane extends TestContentPane {
    public static final Color BG = new Color(0x00, 0x00, 0x3f);

    public BetaContentPane(TestWindow testWin) {
        super(testWin);
        
        setBackground(BG);
    }
}
