/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.testforecho;

import nextapp.echo.AbstractButton;
import nextapp.echo.Button;
import nextapp.echo.ButtonGroup;
import nextapp.echo.CheckBox;
import nextapp.echo.Color;
import nextapp.echo.ContentPane;
import nextapp.echo.ContainerPane;
import nextapp.echo.EchoConstants;
import nextapp.echo.Filler;
import nextapp.echo.Font;
import nextapp.echo.HttpImageReference;
import nextapp.echo.ImageReference;
import nextapp.echo.Label;
import nextapp.echo.Panel;
import nextapp.echo.RadioButton;
import nextapp.echo.SelectField;
import nextapp.echo.TextArea;
import nextapp.echo.ToggleButton;
import nextapp.echo.event.ActionEvent;
import nextapp.echo.event.ActionListener;
import nextapp.echo.event.ChangeEvent;
import nextapp.echo.event.ChangeListener;
import nextapp.echo.event.ItemEvent;
import nextapp.echo.event.ItemListener;

public class ButtonTest extends ContainerPane 
implements ActionListener, ChangeListener, ItemListener {
    
    private static final ImageReference ICON_MESSAGE = new HttpImageReference("images/icon_message.gif", 24, 24);
    private static final ImageReference ICON_HIGHLIGHT = new HttpImageReference("images/icon_message_highlight.gif", 24, 24);
    private static final ImageReference ICON_STATE_OFF = new HttpImageReference("images/togglebutton_off.gif", 32, 32);
    private static final ImageReference ICON_STATE_ON = new HttpImageReference("images/togglebutton_on.gif", 32, 32);
    private static final ImageReference ICON_STATE_OFF_HIGHLIGHT
            = new HttpImageReference("images/togglebutton_off_highlight.gif", 32, 32);
    private static final ImageReference ICON_STATE_ON_HIGHLIGHT
            = new HttpImageReference("images/togglebutton_on_highlight.gif", 32, 32);
            
    private ControlPane controlPane;
    private ButtonPane buttonPane;
    private HelpPanel helpPanel = new HelpPanel("Button Test", 
                    "Use the options in the lower pane to configure the buttons in the upper pane.  When you are finished, click "
                    + "the \"Apply Changes\" button at the bottom of the lower pane.");

    private class ButtonPane extends ContentPane {

        public AbstractButton[] testButton;
        
        public static final int MODE_BUTTON = 0;
        public static final int MODE_CHECKBOX = 1;
        public static final int MODE_RADIOBUTTON = 2;
        public static final int MODE_RADIOBUTTON_GROUPED = 3;
        
        public static final int MODEL_DEFAULT = 0;
        public static final int MODEL_CUSTOM_WITHOUT_DO_ACTION = 1;
        public static final int MODEL_CUSTOM_WITH_DO_ACTION = 2;
        
        private ButtonGroup buttonGroup = null;

        public ButtonPane(String text, ImageReference icon, int mode) {
            this.setResizable(true);
            testButton = new AbstractButton[4];
            
            switch (mode) {
            case MODE_BUTTON:
                testButton[0] = new Button();
                testButton[1] = new Button(text);
                testButton[2] = new Button(icon);
                testButton[3] = new Button(text, icon);
                break;
            case MODE_CHECKBOX:
                testButton[0] = new CheckBox();
                testButton[1] = new CheckBox(text);
                testButton[2] = new CheckBox(icon);
                testButton[3] = new CheckBox(text, icon, false);
                break;
            case MODE_RADIOBUTTON:
            case MODE_RADIOBUTTON_GROUPED:
                testButton[0] = new RadioButton();
                testButton[1] = new RadioButton(text);
                testButton[2] = new RadioButton(icon);
                testButton[3] = new RadioButton(text, icon, false);
                if (mode == MODE_RADIOBUTTON_GROUPED) {
                    buttonGroup = new ButtonGroup();
                    for (int index = 0; index < testButton.length; ++index) {
                        buttonGroup.add(testButton[index]);
                    }
                }
                break;
            default:
                throw new IllegalArgumentException("illegal mode");
            }
            
            this.add(helpPanel);
            this.add(Filler.createVerticalStrut(20));
        
            TestPanel testPanel = new TestPanel();

            testPanel.addHeader("Test Buttons");
            testPanel.add("Button()", testButton[0]);
            testPanel.add("Button(text)", testButton[1]);
            testPanel.add("Button(icon)", testButton[2]);
            testPanel.add("Button(text, icon)", testButton[3]);

            this.add(testPanel);
        }
    }
    
    private class ControlPane extends ContentPane 
    implements ActionListener {
    
        private SelectField testType;
        private CheckBox actionCommand;
        private CheckBox actionListener, changeListener, itemListener;
        private CheckBox modelActionListener, modelChangeListener, modelItemListener;
        private CheckBox background;
        private CheckBox foreground;
        private CheckBox rolloverEnabled;
        private CheckBox rolloverBackground;
        private CheckBox rolloverFont;
        private CheckBox rolloverForeground;
        private CheckBox rolloverIcon;
        private CheckBox customStateIconOff;
        private CheckBox customStateIconOn;
        private CheckBox customStateIconOffHighlighted;
        private CheckBox customStateIconOnHighlighted;
        private CheckBox[] enabledState;
        private CheckBox[] selectedState;
        private SelectField iconTextMargin;
        private SelectField stateMargin;
        private SelectField horizontalAlignment;
        private SelectField verticalAlignment;
        private SelectField horizontalTextPosition;
        private SelectField verticalTextPosition;
        private SelectField horizontalStateAlignment;
        private SelectField verticalStateAlignment;
        private SelectField horizontalStatePosition;
        private SelectField verticalStatePosition;
        private TextArea text;
        private TextArea toolTipText;
        
        private Button applyButton;
        
        public ControlPane() {
            this.setResizable(true);
        
            TestPanel testPanel = new TestPanel();

            testType = new SelectField(new Object[]{
                    new ListElement(new Integer(ButtonPane.MODE_BUTTON),              "Pushbuttons"),
                    new ListElement(new Integer(ButtonPane.MODE_CHECKBOX),            "Checkboxes"),
                    new ListElement(new Integer(ButtonPane.MODE_RADIOBUTTON),         "Radiobuttons (independent)"),
                    new ListElement(new Integer(ButtonPane.MODE_RADIOBUTTON_GROUPED), "Radiobuttons (grouped)")
            });
            testPanel.add("Test Type", testType);
            
            testPanel.addHeader("General Properties");
            
            actionListener = new CheckBox();
            testPanel.add("Action Listener", actionListener);
            
            actionCommand = new CheckBox();
            testPanel.add("Action Command", actionCommand);
            
            changeListener = new CheckBox();
            testPanel.add("Change Listener", changeListener);
            
            itemListener = new CheckBox();
            testPanel.add("Item Listener", itemListener);
            
            modelActionListener = new CheckBox();
            testPanel.add("Action Listener (on model)", modelActionListener);
            
            modelChangeListener = new CheckBox();
            testPanel.add("Change Listener (on model)", modelChangeListener);
            
            modelItemListener = new CheckBox();
            testPanel.add("Item Listener (on model)", modelItemListener);
            
            text = new TextArea("Button", 40, 3);
            testPanel.add("Text", text);
            
            toolTipText = new TextArea(40, 3);
            testPanel.add("Tool Tip", toolTipText);
            
            background = new CheckBox();
            testPanel.add("Background", background);
        
            foreground = new CheckBox();
            testPanel.add("Foreground", foreground);

            rolloverEnabled = new CheckBox();
            testPanel.add("Rollover Enabled", rolloverEnabled);

            rolloverBackground = new CheckBox();
            testPanel.add("Rollover Background", rolloverBackground);

            rolloverForeground = new CheckBox();
            testPanel.add("Rollover Foreground", rolloverForeground);

            rolloverFont = new CheckBox();
            testPanel.add("Rollover Font", rolloverFont);

            rolloverIcon = new CheckBox();
            testPanel.add("Rollover Icon", rolloverIcon);

            iconTextMargin = new SelectField(new Object[]{new ListElement(null, "default"), 
                    "0", "1", "2", "3", "4", "5", "10", "15", "20"});
            testPanel.add("Icon/Text Margin", iconTextMargin);
        
            horizontalTextPosition = new SelectField(new Object[]{
                new ListElement(null, "default"),
                new ListElement(new Integer(EchoConstants.LEFT), "Left"),
                new ListElement(new Integer(EchoConstants.CENTER), "Center"),
                new ListElement(new Integer(EchoConstants.RIGHT), "Right"),
            });
            testPanel.add("Horizontal Text Position", horizontalTextPosition);

            verticalTextPosition = new SelectField(new Object[]{
                new ListElement(null, "default"),
                new ListElement(new Integer(EchoConstants.TOP), "Top"),
                new ListElement(new Integer(EchoConstants.CENTER), "Center"),
                new ListElement(new Integer(EchoConstants.BOTTOM), "Bottom"),
            });
            testPanel.add("Vertical Text Position", verticalTextPosition);

            horizontalAlignment = new SelectField(new Object[]{
                new ListElement(null, "default"),
                new ListElement(new Integer(EchoConstants.LEFT), "Left"),
                new ListElement(new Integer(EchoConstants.CENTER), "Center"),
                new ListElement(new Integer(EchoConstants.RIGHT), "Right"),
            });
            testPanel.add("Horizontal Alignment", horizontalAlignment);

            verticalAlignment = new SelectField(new Object[]{
                new ListElement(null, "default"),
                new ListElement(new Integer(EchoConstants.TOP), "Top"),
                new ListElement(new Integer(EchoConstants.CENTER), "Center"),
                new ListElement(new Integer(EchoConstants.BOTTOM), "Bottom"),
            });
            testPanel.add("Vertical Alignment", verticalAlignment);
            
            Panel panel = new Panel();
            enabledState = new CheckBox[4];
            for (int index = 0; index < enabledState.length; ++index) {
                enabledState[index] = new CheckBox();
                enabledState[index].setSelected(true);
                panel.add(new Label(Integer.toString(index)));
                panel.add(enabledState[index]);
                panel.add(Filler.createHorizontalStrut(20));
            }
            testPanel.add("Enabled", panel);
            
            panel = new Panel();
            selectedState = new CheckBox[4];
            for (int index = 0; index < selectedState.length; ++index) {
                selectedState[index] = new CheckBox();
                panel.add(new Label(Integer.toString(index)));
                panel.add(selectedState[index]);
                panel.add(Filler.createHorizontalStrut(20));
            }
            testPanel.add("Selected", panel);

            testPanel.addHeader("ToggleButton-Specific Properties");

            customStateIconOff = new CheckBox();
            testPanel.add("Custom State Icon (Off)\n[setIcon()]", customStateIconOff);

            customStateIconOn = new CheckBox();
            testPanel.add("Custom State Icon (On)\n[setSelectedIcon()]", customStateIconOn);

            customStateIconOffHighlighted = new CheckBox();
            testPanel.add("Custom State Icon (Off, Highlighted)\n[setRolloverIcon()]", customStateIconOffHighlighted);

            customStateIconOnHighlighted = new CheckBox();
            testPanel.add("Custom State Icon (On, Highlighted)\n[setRolloverSelectedIcon()]", customStateIconOnHighlighted);

            stateMargin = new SelectField(new Object[]{new ListElement(null, "default"), 
                    "0", "1", "2", "3", "4", "5", "10", "15", "20"});
            testPanel.add("State Margin", stateMargin);
        
            horizontalStatePosition = new SelectField(new Object[]{
                new ListElement(null, "default"),
                new ListElement(new Integer(EchoConstants.LEFT), "Left"),
                new ListElement(new Integer(EchoConstants.CENTER), "Center"),
                new ListElement(new Integer(EchoConstants.RIGHT), "Right"),
            });
            testPanel.add("Horizontal State Position", horizontalStatePosition);

            verticalStatePosition = new SelectField(new Object[]{
                new ListElement(null, "default"),
                new ListElement(new Integer(EchoConstants.TOP), "Top"),
                new ListElement(new Integer(EchoConstants.CENTER), "Center"),
                new ListElement(new Integer(EchoConstants.BOTTOM), "Bottom"),
            });
            testPanel.add("Vertical State Position", verticalStatePosition);

            horizontalStateAlignment = new SelectField(new Object[]{
                new ListElement(null, "default"),
                new ListElement(new Integer(EchoConstants.LEFT), "Left"),
                new ListElement(new Integer(EchoConstants.CENTER), "Center"),
                new ListElement(new Integer(EchoConstants.RIGHT), "Right"),
            });
            testPanel.add("Horizontal State Alignment", horizontalStateAlignment);

            verticalStateAlignment = new SelectField(new Object[]{
                new ListElement(null, "default"),
                new ListElement(new Integer(EchoConstants.TOP), "Top"),
                new ListElement(new Integer(EchoConstants.CENTER), "Center"),
                new ListElement(new Integer(EchoConstants.BOTTOM), "Bottom"),
            });
            testPanel.add("Vertical State Alignment", verticalStateAlignment);

            this.add(testPanel);

            this.add(Filler.createVerticalStrut(10));
            applyButton = new Button("Apply Changes");
            applyButton.addActionListener(ControlPane.this);
            this.add(applyButton);
            
        }

        public void actionPerformed(ActionEvent e) {
            ButtonPane newButtonPane;
            if (testType.getSelectedItem() == null) {
                newButtonPane = new ButtonPane(text.getText(), ICON_MESSAGE, ButtonPane.MODE_BUTTON);
            } else {
                newButtonPane = new ButtonPane(text.getText(), ICON_MESSAGE, 
                        ((Integer) ((ListElement) testType.getSelectedItem()).getObject()).intValue());
            }
            
            for (int index = 0; index < buttonPane.testButton.length; ++index) {
                if (actionListener.isSelected()) {
                    newButtonPane.testButton[index].addActionListener(ButtonTest.this);
                }
                if (actionCommand.isSelected()) {
                    newButtonPane.testButton[index].setActionCommand("Action Command");
                }
                if (changeListener.isSelected()) {
                    newButtonPane.testButton[index].addChangeListener(ButtonTest.this);
                }
                if (itemListener.isSelected()) {
                    newButtonPane.testButton[index].addItemListener(ButtonTest.this);
                }
                if (modelActionListener.isSelected()) {
                    newButtonPane.testButton[index].getModel().addActionListener(ButtonTest.this);
                }
                if (modelChangeListener.isSelected()) {
                    newButtonPane.testButton[index].getModel().addChangeListener(ButtonTest.this);
                }
                if (modelItemListener.isSelected()) {
                    newButtonPane.testButton[index].getModel().addItemListener(ButtonTest.this);
                }
                if (toolTipText.getText() != null && toolTipText.getText().trim().length() > 0) {
                    newButtonPane.testButton[index].setToolTipText(toolTipText.getText());
                }
                if (foreground.isSelected()) {
                    newButtonPane.testButton[index].setForeground(Color.BLUE);
                }
                if (background.isSelected()) {
                    newButtonPane.testButton[index].setBackground(Color.CYAN);
                }
                if (rolloverEnabled.isSelected()) {
                    newButtonPane.testButton[index].setRolloverEnabled(true);
                }
                if (rolloverFont.isSelected()) {
                    newButtonPane.testButton[index].setRolloverFont(new Font(Font.TIMES_NEW_ROMAN, 
                            Font.BOLD | Font.ITALIC | Font.UNDERLINE, 16));
                }
                if (rolloverForeground.isSelected()) {
                    newButtonPane.testButton[index].setRolloverForeground(Color.RED);
                }
                if (rolloverBackground.isSelected()) {
                    newButtonPane.testButton[index].setRolloverBackground(Color.YELLOW);
                }
                if (rolloverIcon.isSelected()) {
                    newButtonPane.testButton[index].setRolloverIcon(ICON_HIGHLIGHT);
                }
                if (iconTextMargin.getSelectedItem() != null) {
                    try {
                        int margin = Integer.parseInt(iconTextMargin.getSelectedItem().toString());
                        newButtonPane.testButton[index].setIconTextMargin(margin);
                    } catch (NumberFormatException ex) { }
                } 
                if (horizontalAlignment.getSelectedItem() != null 
                        && ((ListElement) horizontalAlignment.getSelectedItem()).getObject() != null) {
                    newButtonPane.testButton[index].setHorizontalAlignment(
                            ((Integer) (((ListElement) horizontalAlignment.getSelectedItem()).getObject())).intValue());
                }
                if (verticalAlignment.getSelectedItem() != null 
                        && ((ListElement) verticalAlignment.getSelectedItem()).getObject() != null) {
                    newButtonPane.testButton[index].setVerticalAlignment(
                            ((Integer) (((ListElement) verticalAlignment.getSelectedItem()).getObject())).intValue());
                }
                if (horizontalTextPosition.getSelectedItem() != null 
                        && ((ListElement) horizontalTextPosition.getSelectedItem()).getObject() != null) {
                    newButtonPane.testButton[index].setHorizontalTextPosition(
                            ((Integer) (((ListElement) horizontalTextPosition.getSelectedItem()).getObject())).intValue());
                }
                if (verticalTextPosition.getSelectedItem() != null 
                        && ((ListElement) verticalTextPosition.getSelectedItem()).getObject() != null) {
                    newButtonPane.testButton[index].setVerticalTextPosition(
                            ((Integer) (((ListElement) verticalTextPosition.getSelectedItem()).getObject())).intValue());
                }
                if (customStateIconOff.isSelected()) {
                    newButtonPane.testButton[index].setIcon(ICON_STATE_OFF);
                }
                if (customStateIconOn.isSelected()) {
                    newButtonPane.testButton[index].setSelectedIcon(ICON_STATE_ON);
                }
                if (customStateIconOffHighlighted.isSelected()) {
                    newButtonPane.testButton[index].setRolloverIcon(ICON_STATE_OFF_HIGHLIGHT);
                }
                if (customStateIconOnHighlighted.isSelected()) {
                    newButtonPane.testButton[index].setRolloverSelectedIcon(ICON_STATE_ON_HIGHLIGHT);
                }
                newButtonPane.testButton[index].setEnabled(enabledState[index].isSelected());
                newButtonPane.testButton[index].setSelected(selectedState[index].isSelected());
                if (newButtonPane.testButton[index] instanceof ToggleButton) {
                    ToggleButton toggleButton = (ToggleButton) newButtonPane.testButton[index];
                    if (stateMargin.getSelectedItem() != null) {
                        try {
                            int margin = Integer.parseInt(stateMargin.getSelectedItem().toString());
                            toggleButton.setStateMargin(margin);
                        } catch (NumberFormatException ex) { }
                    } 
                    if (horizontalStateAlignment.getSelectedItem() != null 
                            && ((ListElement) horizontalStateAlignment.getSelectedItem()).getObject() != null) {
                        toggleButton.setHorizontalStateAlignment(
                                ((Integer) (((ListElement) horizontalStateAlignment.getSelectedItem()).getObject())).intValue());
                    }
                    if (verticalStateAlignment.getSelectedItem() != null 
                            && ((ListElement) verticalStateAlignment.getSelectedItem()).getObject() != null) {
                        toggleButton.setVerticalStateAlignment(
                                ((Integer) (((ListElement) verticalStateAlignment.getSelectedItem()).getObject())).intValue());
                    }
                    if (horizontalStatePosition.getSelectedItem() != null 
                            && ((ListElement) horizontalStatePosition.getSelectedItem()).getObject() != null) {
                        toggleButton.setHorizontalStatePosition(
                                ((Integer) (((ListElement) horizontalStatePosition.getSelectedItem()).getObject())).intValue());
                    }
                    if (verticalStatePosition.getSelectedItem() != null 
                            && ((ListElement) verticalStatePosition.getSelectedItem()).getObject() != null) {
                        toggleButton.setVerticalStatePosition(
                                ((Integer) (((ListElement) verticalStatePosition.getSelectedItem()).getObject())).intValue());
                    }
                }
            }
            
            ButtonTest.this.remove(buttonPane);
            
            buttonPane = newButtonPane;
            
            ButtonTest.this.add(buttonPane, 0);
        }
    }

    public ButtonTest() {
        setOrientation(ORIENTATION_VERTICAL);

        controlPane = new ControlPane();
        buttonPane = new ButtonPane("Button", ICON_MESSAGE, ButtonPane.MODE_BUTTON);
        
        add(buttonPane);
        add(controlPane);
    }
    
    public void actionPerformed(ActionEvent e) {
        TestForEcho.getApplicationInstance().getLogger().log("Button pressed: source=\"" 
                + e.getSource() + "\" command=\"" + e.getActionCommand() + "\"");
    }
    
    public void stateChanged(ChangeEvent e) {
        TestForEcho.getApplicationInstance().getLogger().log("State changed: source=\"" + e.getSource() + "\"");
    }
    
    public void itemStateChanged(ItemEvent e) {
        String stateChange;
        switch (e.getStateChange()) {
            case ItemEvent.SELECTED:
                stateChange = "SELECTED";
                break;
            case ItemEvent.DESELECTED:
                stateChange = "DESELECTED";
                break;
            default:
                stateChange = "Undefined, should not happen";
        }
        TestForEcho.getApplicationInstance().getLogger().log("Item state changed: source=\"" 
                + e.getSource() + "\" item=\"" + e.getItem() + "\" state change=\"" + stateChange + "\"");
    }
}
