/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.testforecho;

import nextapp.echo.ContentPane;
import nextapp.echo.Filler;
import nextapp.echo.Table;
import nextapp.echo.table.AbstractTableModel;
import nextapp.echoservlet.ClientProperties;

public class ClientPropertiesTest extends ContentPane {

    private class ClientPropertiesModel extends AbstractTableModel {
        
        private final String[] PROPERTIES = new String[]{
                ClientProperties.REMOTE_ADDR,   
                ClientProperties.REMOTE_HOST,   
                ClientProperties.ACCEPT,        
                ClientProperties.ACCEPT_CHARSET,
                ClientProperties.ACCEPT_ENCODING,
                ClientProperties.ACCEPT_LANGUAGE,
                ClientProperties.HOST,
                ClientProperties.REFERRER,      
                ClientProperties.USER_AGENT,    
                ClientProperties.APP_NAME,      
                ClientProperties.APP_VERSION,   
                ClientProperties.CHROME_HEIGHT, 
                ClientProperties.CHROME_WIDTH,  
                ClientProperties.COLOR_DEPTH,   
                ClientProperties.SCREEN_HEIGHT, 
                ClientProperties.SCREEN_WIDTH,  
                ClientProperties.INITIAL_WINDOW_HAS_MENU_BAR, 
                ClientProperties.INITIAL_WINDOW_HAS_STATUS_BAR, 
                ClientProperties.INITIAL_WINDOW_HAS_TOOL_BAR, 
                ClientProperties.INITIAL_WINDOW_HEIGHT, 
                ClientProperties.INITIAL_WINDOW_WIDTH,  
                ClientProperties.JS_VERSION,
                ClientProperties.EXCEPTION_SUPPORT,
                ClientProperties.TIME_ZONE_OFFSET,
                ClientProperties.BACK_BUTTON_DISABLE_SUPPORT,
                ClientProperties.CSS_MODIFICATION_SUPPORT};
        
        public int getColumnCount() {
            return 2;
        }
    
        public int getRowCount() {
            return PROPERTIES.length;
        }
        
        public Object getValueAt(int column, int row) {
            String value;
            
            if (column == 0) {
                value = PROPERTIES[row];
            } else if (column == 1) {
                value = TestForEcho.getApplicationInstance().getClientProperties().get(PROPERTIES[row]);
            } else {
                throw new IllegalArgumentException();
            }
            
            return value;
        }
    }

    public ClientPropertiesTest() {
        add(new HelpPanel("Client Properties Test",
                "The purpose of this test is to evaluate the Echo Application Container's browser client detection system. "
                + "The table below shows information about the browser client in which it is displayed."));
        add(Filler.createVerticalStrut(20));
        Table cpTable = new Table(new ClientPropertiesModel());
        cpTable.getColumnModel().getColumn(0).setHeaderValue("Attribute");
        cpTable.getColumnModel().getColumn(1).setHeaderValue("Value");
        add(cpTable);
    }
}
