/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.testforecho;

import nextapp.echo.Button;
import nextapp.echo.CheckBox;
import nextapp.echo.Color;
import nextapp.echo.Component;
import nextapp.echo.Container;
import nextapp.echo.ContainerPane;
import nextapp.echo.ContentPane;
import nextapp.echo.Filler;
import nextapp.echo.Label;
import nextapp.echo.Panel;
import nextapp.echo.event.ActionEvent;
import nextapp.echo.event.ActionListener;
import nextapp.echo.event.HierarchyEvent;
import nextapp.echo.event.HierarchyListener;
import nextapp.echo.event.ItemEvent;
import nextapp.echo.event.ItemListener;

public class ComponentHierarchyTestOne extends ContainerPane 
implements HierarchyListener {
    
    private ContentPane redPane, greenPane, bluePane, yellowPane, cyanPane;
    private ContainerPane containerOne, containerTwo, containerThree;
    private Panel orangePanel, magentaPanel;
    private Label labelOne = new Label("Label One");
    private Label labelTwo = new Label("Label Two");
    
    private class TestPane extends ContentPane 
    implements ActionListener {
        
        private String name;
    
        public TestPane(String name) {
            super();
            this.name = name;
            Button addButton = new Button("Add Component");
            addButton.addActionListener(TestPane.this);
            TestPane.this.add(addButton);
        }
    
        public void actionPerformed(ActionEvent e) {
            TestPane.this.add(new Label("X"));
        }    
        
        public String toString() {
            return name;
        }
    }
    
    private class HierarchyTester extends Container 
    implements ActionListener {

        private Component component;
        private Component parent;
        
        public HierarchyTester(Component component, Component parent) {
            super();
            
            this.component = component;
            this.parent = parent;
            this.add(new VisibilityToggle(component));
            
            Button addButton = new Button("[add]");
            addButton.setActionCommand("add");
            addButton.addActionListener(this);
            this.add(addButton);
            
            Button removeButton = new Button("[remove]");
            removeButton.setActionCommand("remove");
            removeButton.addActionListener(this);
            this.add(removeButton);
        }
        
        public void actionPerformed(ActionEvent e) {
            if ("add".equals(e.getActionCommand())) {
                if (parent instanceof ContainerPane) {
                    parent.add(component);
                } else {
                    parent.add(component);
                }
            } else {
                if (parent instanceof ContainerPane) {
                    parent.remove(component);
                } else {
                    parent.remove(component);
                }
            }
            
        }
    }
    
    private class VisibilityToggle extends CheckBox 
    implements ItemListener {
    
        private Component component;
    
        public VisibilityToggle(Component component) {
            super("Visible");
            
            setSelected(component.isVisible());
            this.component = component;
            
            this.addItemListener(this);
        }

        public void itemStateChanged(ItemEvent e) {
            component.setVisible(isSelected());
        }
    }

    private class ControlPane extends ContentPane {
    
        public ControlPane() {
            super();
            
            this.add(new HelpPanel("Component Hierarchy Test (#1)",
                    "The purpose of this test is to evaluate various features related to the component hierarchy. "
                    + "This test allows you to interactively show and hide the various components displayed.  To "
                    + "update the components displayed, modify the states of the checkboxes below and then click "
                    + "the \"Action Button\" near the bottom of the leftmost frame on this page."));
            this.add(Filler.createVerticalStrut(20));

            TestPanel testPanel = new TestPanel();
            
            testPanel.addHeader("ContainerPane Visibility");
            testPanel.add("Container One", new VisibilityToggle(containerOne));
            testPanel.add("Container Two", new HierarchyTester(containerTwo, containerOne));
            testPanel.add("Container Three", new HierarchyTester(containerThree, containerTwo));
            
            testPanel.addHeader("ContentPane Visibility");
            testPanel.add("Red Pane", new HierarchyTester(redPane, containerThree));
            testPanel.add("Green Pane", new HierarchyTester(greenPane, containerTwo));
            testPanel.add("Blue Pane", new HierarchyTester(bluePane, containerOne));
            testPanel.add("Yellow Pane", new HierarchyTester(yellowPane, containerTwo));
            testPanel.add("Cyan Pane", new HierarchyTester(cyanPane, containerThree));
            
            testPanel.addHeader("Panel Visibility");
            testPanel.add("Orange Panel", new HierarchyTester(orangePanel, bluePane));
            testPanel.add("Magenta Panel", new HierarchyTester(magentaPanel, bluePane));

            testPanel.addHeader("Label Visibility");
            testPanel.add("Label One", new HierarchyTester(labelOne, magentaPanel));
            testPanel.add("Label Two", new HierarchyTester(labelTwo, orangePanel));

            this.add(testPanel);
        }
    }
    
    public ComponentHierarchyTestOne() {
        containerThree = new ContainerPane();
        containerThree.setOrientation(ContainerPane.ORIENTATION_HORIZONTAL);
        containerThree.addHierarchyListener(this);
        redPane = new TestPane("red");
        redPane.setBackground(Color.RED);
        redPane.addHierarchyListener(this);
        containerThree.add(redPane);
        cyanPane = new TestPane("cyan");
        cyanPane.setBackground(Color.CYAN);
        cyanPane.addHierarchyListener(this);
        containerThree.add(cyanPane);
        
        containerTwo = new ContainerPane();
        containerTwo.setOrientation(ContainerPane.ORIENTATION_VERTICAL);
        containerTwo.addHierarchyListener(this);
        yellowPane = new TestPane("yellow");
        yellowPane.setBackground(Color.YELLOW);
        yellowPane.addHierarchyListener(this);
        containerTwo.add(yellowPane);
        containerTwo.add(containerThree);
        greenPane = new TestPane("green");
        greenPane.setBackground(Color.GREEN);
        greenPane.addHierarchyListener(this);
        containerTwo.add(greenPane);
        
        containerOne = new ContainerPane();
        containerOne.setOrientation(ContainerPane.ORIENTATION_HORIZONTAL);
        containerOne.addHierarchyListener(this);
        bluePane = new TestPane("blue");
        bluePane.setBackground(Color.BLUE);
        bluePane.addHierarchyListener(this);
        containerOne.add(containerTwo);
        containerOne.add(bluePane);
        
        magentaPanel = new Panel();
        magentaPanel.setBackground(Color.MAGENTA);
        magentaPanel.addHierarchyListener(this);
        magentaPanel.add(Filler.createVerticalStrut(20));
        magentaPanel.add(labelOne);
        magentaPanel.add(Filler.createVerticalStrut(20));
        
        orangePanel = new Panel();
        orangePanel.setBackground(Color.ORANGE);
        orangePanel.addHierarchyListener(this);
        orangePanel.add(Filler.createVerticalStrut(20));
        orangePanel.add(magentaPanel);
        orangePanel.add(Filler.createVerticalStrut(20));
        orangePanel.add(labelTwo);
        orangePanel.add(Filler.createVerticalStrut(20));
        
        bluePane.add(orangePanel);

        setOrientation(ContainerPane.ORIENTATION_VERTICAL);
        add(containerOne);
        add(new ControlPane());
    }
    
    private String displayFlags(long flags) {
        StringBuffer sb = new StringBuffer();
        if ((flags & HierarchyEvent.PARENT_CHANGED) != 0) {
            sb.append("[parent]");
        }
        if ((flags & HierarchyEvent.SHOWING_CHANGED) != 0) {
            sb.append("[showing]");
        }
        if ((flags & HierarchyEvent.REGISTRATION_CHANGED) != 0) {
            sb.append("[registration]");
        }
        if (sb.length() == 0) {
            sb.append("[none]");
        }
        return sb.toString();
    }
    
    public void hierarchyChanged(HierarchyEvent e) {
        TestForEcho.getApplicationInstance().getLogger().log("HierarchyEvent: source=" 
                + e.getComponent() + ", flags=" + displayFlags(e.getChangeFlags())
                + ", component=" + e.getChanged() + ", parent=" + e.getChangedParent()
                + ", registered=" + e.getChanged().isRegistered() + ", visible=" + e.getChanged().isVisible());
    }
}
