/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.testforecho;

import nextapp.echo.ContentPane;
import nextapp.echo.Filler;
import nextapp.echo.TextField;
import nextapp.echo.text.Document;
import nextapp.echo.event.DocumentEvent;
import nextapp.echo.event.DocumentListener;

/**
 * Test to make certain that removing one component 
 */
public class ComponentRemovalAnomalyTest extends ContentPane 
implements DocumentListener {

    private TextField[] fields = new TextField[]{new TextField("One"), new TextField("Two"), new TextField("Three")};
    
    public void documentUpdate(DocumentEvent e) {
        for (int index = 0; index < fields.length; ++index) {
            if (indexOf(fields[index]) != -1) {
                remove(fields[index]);
            }
        }
        Document doc = (Document) e.getSource();
        TestForEcho.getApplicationInstance().getLogger().log("Received doc event from: " + doc + ", text=" + doc.getText());
    }

    public ComponentRemovalAnomalyTest() {
        add(new HelpPanel("Component Removal Anomaly Test",
                "This test is in place to test for a very specific issue that was fixed quite a while ago. "
                + "When any of the three text fields below are modified, a DocumentEvent will be generated "
                + "that will cause all of them to be hidden.  (This test is now essentially irrelevant)."));
        add(Filler.createVerticalStrut(20));

        for (int index = 0; index < fields.length; ++index) {
            fields[index].getDocument().addDocumentListener(this);
            add(fields[index]);
        }
    }
    
}
