/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.testforecho;

import java.io.Serializable;

import nextapp.echo.event.ActionEvent;
import nextapp.echo.event.ActionListener;
import nextapp.echo.ContentPane;

public class Controller 
implements ActionListener, Serializable {
    
    public static final String COMMAND_BUTTON_TEST = "Button Test";
    public static final String COMMAND_CLIENT_PROPERTIES_TEST = "Client Properties";
    public static final String COMMAND_COMPONENT_HIERARCHY_TEST_ONE = "Component Hierarchy Test #1";
    public static final String COMMAND_COMPONENT_HIERARCHY_TEST_TWO = "Component Hierarchy Test #2";
    public static final String COMMAND_COMPONENT_REMOVAL_ANOMALY_TEST = "Component Removal Anomaly Test";
    public static final String COMMAND_COOKIE_TEST = "Cookie Test";
    public static final String COMMAND_CSS_TEST = "CSS Test";
    public static final String COMMAND_INITIAL_PARAMETERS_TEST = "Initial Parameters";
    public static final String COMMAND_DOUBLE_SUBMIT_TEST = "Double Submit Test";
    public static final String COMMAND_EVENT_LISTENER_LIST_TEST = "Event Listener List Test";
    public static final String COMMAND_FONT_TEST = "Font Test";
    public static final String COMMAND_FOCUS_TEST = "Focus Test";
    public static final String COMMAND_GRID_TEST = "Grid Test";
    public static final String COMMAND_HTTP_PANE_TEST = "HTTP Pane Test";
    public static final String COMMAND_IMAGE_TEST = "Image Test";
    public static final String COMMAND_IZATION_TEST = "I18N/L10N Test";
    public static final String COMMAND_LABEL_TEST = "Label Test";
    public static final String COMMAND_LIST_BOX_TEST = "List Box Test";
    public static final String COMMAND_PANE_EMBEDDING_TEST = "Pane Embedding Test";
    public static final String COMMAND_PANE_REPLACEMENT_TEST = "Pane Replacement Test";
    public static final String COMMAND_PROPERTY_CHANGE_MADNESS_TEST = "Property Change Madness Test";
    public static final String COMMAND_SELECT_FIELD_TEST = "Select Field Test";
    public static final String COMMAND_STACKED_PANE_TEST = "Stacked Pane Test";
    public static final String COMMAND_STYLE_TEST = "Style Test";
    public static final String COMMAND_TAB_INDEX_TEST = "Tab Index Test";
    public static final String COMMAND_TABLE_TEST = "Table Test";
    public static final String COMMAND_TERMINATION_TEST = "Termination Test";
    public static final String COMMAND_TEXT_TEST = "Text Component Test";
    public static final String COMMAND_UNCHECKED_EXCEPTION_TEST = "Unchecked Exception Test";
    public static final String COMMAND_WINDOW_TEST = "Window Test";
    
    private TestForEcho app;
    
    public Controller(TestForEcho app) {
        super();
        
        this.app = app;
    }
    
    public void actionPerformed(ActionEvent e) {
        app.doControllerDelay();

        app.getLogger().clear();
        app.getLogger().log("Controller: Starting \"" + e.getActionCommand() + "\"");
        
        if (COMMAND_BUTTON_TEST.equals(e.getActionCommand())) {
            app.setMainPane(new ButtonTest());
        } else if (COMMAND_CLIENT_PROPERTIES_TEST.equals(e.getActionCommand())) {
            app.setMainPane(new ClientPropertiesTest());
        } else if (COMMAND_COOKIE_TEST.equals(e.getActionCommand())) {
            app.setMainPane(new CookieTest());
        } else if (COMMAND_COMPONENT_HIERARCHY_TEST_ONE.equals(e.getActionCommand())) {
            app.setMainPane(new ComponentHierarchyTestOne());
        } else if (COMMAND_COMPONENT_HIERARCHY_TEST_TWO.equals(e.getActionCommand())) {
            app.setMainPane(new ComponentHierarchyTestTwo());
        } else if (COMMAND_COMPONENT_REMOVAL_ANOMALY_TEST.equals(e.getActionCommand())) {
            app.setMainPane(new ComponentRemovalAnomalyTest());
        } else if (COMMAND_DOUBLE_SUBMIT_TEST.equals(e.getActionCommand())) {
            app.setMainPane(new DoubleSubmitTest());
        } else if (COMMAND_EVENT_LISTENER_LIST_TEST.equals(e.getActionCommand())) {
            app.setMainPane(new EventListenerListTest());
        } else if (COMMAND_CSS_TEST.equals(e.getActionCommand())) {
            app.setMainPane(new CssTest());
        } else if (COMMAND_FONT_TEST.equals(e.getActionCommand())) {
            app.setMainPane(new FontTest());
        } else if (COMMAND_FOCUS_TEST.equals(e.getActionCommand())) {
            app.setMainPane(new FocusTest());
        } else if (COMMAND_GRID_TEST.equals(e.getActionCommand())) {
            app.setMainPane(new GridTest());
        } else if (COMMAND_HTTP_PANE_TEST.equals(e.getActionCommand())) {
            app.setMainPane(new HttpPaneTest());
        } else if (COMMAND_IMAGE_TEST.equals(e.getActionCommand())) {
            app.setMainPane(new ImageTest());
        } else if (COMMAND_INITIAL_PARAMETERS_TEST.equals(e.getActionCommand())) {
            app.setMainPane(new InitialParametersTest());
        } else if (COMMAND_IZATION_TEST.equals(e.getActionCommand())) {
            app.setMainPane(new IzationTest());
        } else if (COMMAND_LABEL_TEST.equals(e.getActionCommand())) {
            app.setMainPane(new LabelTest());
        } else if (COMMAND_LIST_BOX_TEST.equals(e.getActionCommand())) {
            app.setMainPane(new ListBoxTest());
        } else if (COMMAND_PANE_EMBEDDING_TEST.equals(e.getActionCommand())) {
            app.setMainPane(new PaneEmbeddingTest());
        } else if (COMMAND_PANE_REPLACEMENT_TEST.equals(e.getActionCommand())) {
            app.setMainPane(new PaneReplacementTest());
        } else if (COMMAND_PROPERTY_CHANGE_MADNESS_TEST.equals(e.getActionCommand())) {
            app.setMainPane(new PropertyChangeMadnessTest());
        } else if (COMMAND_SELECT_FIELD_TEST.equals(e.getActionCommand())) {
            app.setMainPane(new SelectFieldTest());
        } else if (COMMAND_STACKED_PANE_TEST.equals(e.getActionCommand())) {
            app.setMainPane(new StackedPaneTest());
        } else if (COMMAND_STYLE_TEST.equals(e.getActionCommand())) {
            app.setMainPane(new StyleTest());
        } else if (COMMAND_TAB_INDEX_TEST.equals(e.getActionCommand())) {
            app.setMainPane(new TabIndexTest());
        } else if (COMMAND_TABLE_TEST.equals(e.getActionCommand())) {
            app.setMainPane(new TableTest());
        } else if (COMMAND_TERMINATION_TEST.equals(e.getActionCommand())) {
            app.setMainPane(new TerminationTest());
        } else if (COMMAND_TEXT_TEST.equals(e.getActionCommand())) {
            app.setMainPane(new TextTest());
        } else if (COMMAND_UNCHECKED_EXCEPTION_TEST.equals(e.getActionCommand())) {
            app.setMainPane(new UncheckedExceptionTest());
        } else if (COMMAND_WINDOW_TEST.equals(e.getActionCommand())) {
            app.setMainPane(new WindowTest());
        } else {
            app.setMainPane(new ContentPane());
        }
    }
}
