/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.testforecho;

import java.util.Iterator;
import javax.servlet.http.Cookie;

import nextapp.echo.Button;
import nextapp.echo.Component;
import nextapp.echo.ContentPane;
import nextapp.echo.Filler;
import nextapp.echo.Label;
import nextapp.echo.Table;
import nextapp.echo.event.ActionEvent;
import nextapp.echo.event.ActionListener;
import nextapp.echo.table.AbstractTableModel;
import nextapp.echo.table.DefaultTableCellRenderer;
import nextapp.echoservlet.CookieManager;
import nextapp.echoservlet.ServerContext;

public class CookieTest extends ContentPane 
implements ActionListener {

    private static int value = 0;

    private class CookieCellRenderer extends DefaultTableCellRenderer {
        public Component getTableCellRendererComponent(Table table, Object value, int column, int row) {
            Component c;
        
            if (column == 0) {
                Button button = new Button("Remove");
                button.setActionCommand("remove" + row);
                button.addActionListener(CookieTest.this);
                c = button;
            } else {
                c = super.getTableCellRendererComponent(table, value, column, row);
            }
            
            return c;
        }
    }

    private class CookieTableModel extends AbstractTableModel {
    
        public int getColumnCount() {
            return 5;
        }

        public String getColumnName(int column) {
            switch(column) {
            case 0: return "";
            case 1: return "#";
            case 2: return "Cookie Name";
            case 3: return "Value";
            case 4: return "Maximum Age";
            default: throw new IndexOutOfBoundsException(Integer.toString(column));
            }
        }

        public int getRowCount() {
            return cookieManager.size();
        }
        
        public Object getValueAt(int column, int row) {
            Object o;
            
            switch (column) {
            case 0:
                o = "remove";
                break;
            case 1:
                o = Integer.toString(row + 1);
                break;
            case 2:
                o = getCookie(row).getName();
                break;
            case 3:
                o = getCookie(row).getValue();
                break;
            case 4:
                o = new Integer(getCookie(row).getMaxAge());
                break;
            default:
                throw new IndexOutOfBoundsException(Integer.toString(column));
            }
            
            return o;
        }
        
        public void update() {
            fireTableStructureChanged();
        }
    }
    
    private CookieManager cookieManager;
    private CookieTableModel cookieTableModel = new CookieTableModel();
    private Label countLabel;
    private Table table;

    public CookieTest() {
        cookieManager = ((ServerContext) TestForEcho.getApplicationInstance().getAttribute(ServerContext.ATTRIBUTE_NAME))
                .getCookieManager();

        add(new HelpPanel("Cookie Test",
                "The purpose of this test is to ensure the application container can properly set cookies.  All "
                + "available cookies are listed in the table below.  One of the cookies in the table will be the session "
                + "cookie used by this application, and therefore deleting it will result in the application restarting. "
                + "Clicking the \"Add Cookie\" button will generate a new cookie."));
        add(Filler.createVerticalStrut(20));
    
        table = new Table(cookieTableModel);
        table.setDefaultRenderer(Object.class, new CookieCellRenderer());
        add(table);

        add(Filler.createVerticalStrut(30));

        Button addButton = new Button("Add Cookie");
        addButton.setActionCommand("add");
        addButton.addActionListener(this);
        add(addButton);
        
        Button updateButton = new Button("Update Table");
        updateButton.setActionCommand("update");
        updateButton.addActionListener(this);
        add(updateButton);

        countLabel = new Label(cookieManager.size() + " cookie(s)");
        add(countLabel);
    }

    public void actionPerformed(ActionEvent e) {
        if (e.getActionCommand().startsWith("remove")) {
            int row = Integer.parseInt(e.getActionCommand().substring(6));
            cookieManager.remove(getCookie(row).getName());
            cookieTableModel.update();
        } else if (e.getActionCommand().equals("add")) {
            int cookieValue = value++;
            Cookie cookie = new Cookie("Cookie" + cookieValue, "Value#" + cookieValue);
            cookie.setMaxAge(1000000 + cookieValue);
            cookieManager.add(cookie);
            cookieTableModel.update();
        } else if (e.getActionCommand().equals("update")) {
            table.update();
        }
        
        countLabel.setText(cookieManager.size() + " cookie(s)");
    }

    private Cookie getCookie(int index) {
        Iterator it = cookieManager.iterator();
        for (int i = 0; i < index; ++i) {
            it.next();
        }

        return (Cookie) it.next();
    }
}
