/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.testforecho;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;

import nextapp.echo.Color;
import nextapp.echo.Component;
import nextapp.echo.ContentPane;
import nextapp.echo.Filler;

import nextapp.echoservlet.ComponentPeer;
import nextapp.echoservlet.ComponentStyle;
import nextapp.echoservlet.EchoServer;
import nextapp.echoservlet.RenderingContext;
import nextapp.echoservlet.html.Element;
import nextapp.echoservlet.html.ElementNames;

public class CssTest extends ContentPane {

    static {
        EchoServer.loadPeerBindings("nextapp.testforecho.CssTest");
    }

    static class NewWindowLink extends Component {
    
        private Color hoverBackground = null;
        private String uri;
        private String text;
    
        public NewWindowLink(String uri, String text) {
            super();
            
            this.uri = uri;
            this.text = text;
        }
        
        public String getText() {
            return text;
        }
        
        public String getUri() {
            return uri;
        }
        
        public Color getHoverBackground() {
            return hoverBackground;
        }
        
        public void setHoverBackground(Color newValue) {
            Color oldValue = hoverBackground;
            hoverBackground = newValue;
            firePropertyChange("hoverBackground", oldValue, newValue);
        }
    }
    
    public static class NewWindowLinkUI extends ComponentPeer 
    implements PropertyChangeListener {
    
        public void propertyChange(PropertyChangeEvent e) {
            redraw();
        }
        
        public void registered() {
            getComponent().addPropertyChangeListener(this);
        }
        
        public void render(RenderingContext rc, Element parent) {
            NewWindowLink newWindowLink = (NewWindowLink) getComponent();

            ComponentStyle style = ComponentStyle.forComponent(this, ComponentStyle.EXPLICIT_SET_BACKGROUND);
            if (newWindowLink.getHoverBackground() != null) {
                style.addPseudoAttribute("hover", "background-color",
                        ComponentStyle.getColorHexValue(newWindowLink.getHoverBackground()));
            }
            style.addElementType(ElementNames.A);
            String styleName = rc.getDocument().addStyle(style);

            Element anchor = new Element(ElementNames.A);
            anchor.setWhitespaceRelevant(true);
            anchor.addAttribute("class", styleName);
            anchor.addAttribute("href", newWindowLink.getUri());
            anchor.addAttribute("target", "_new");
            anchor.addText(newWindowLink.getText());

            parent.add(anchor);
            rc.getDocument().setCursorOnNewLine(false);
        }

        public void unregistered() {
            getComponent().removePropertyChangeListener(this);
        }
        
    }

    public CssTest() {
        add(new HelpPanel("CSS Style Test",
                "This test evaluates CSS style rendering capabilities.  The links displayed in this page are "
                + "custom rendered components."));
        add(Filler.createVerticalStrut(20));

        NewWindowLink nwl;
        
        nwl = new NewWindowLink("http://www.nextapp.com/products/echo", "BG=null, HoverBG=BLUE");
        nwl.setHoverBackground(Color.BLUE);
        add(nwl);
        add(Filler.createVerticalStrut(5));
        nwl = new NewWindowLink("http://www.nextapp.com/products/echo", "BG=null, HoverBG=BLUE");
        nwl.setHoverBackground(Color.BLUE);
        add(nwl);
        
        add(Filler.createVerticalStrut(20));

        nwl = new NewWindowLink("http://www.nextapp.com/products/echo", "BG=GREEN, HoverBG=null");
        nwl.setBackground(Color.GREEN);
        add(nwl);
        add(Filler.createVerticalStrut(5));
        nwl = new NewWindowLink("http://www.nextapp.com/products/echo", "BG=GREEN, HoverBG=null");
        nwl.setBackground(Color.GREEN);
        add(nwl);
        
        add(Filler.createVerticalStrut(20));

        nwl = new NewWindowLink("http://www.nextapp.com/products/echo", "BG=GREEN, HoverBG=BLUE");
        nwl.setBackground(Color.GREEN);
        nwl.setHoverBackground(Color.BLUE);
        add(nwl);
        add(Filler.createVerticalStrut(5));
        nwl = new NewWindowLink("http://www.nextapp.com/products/echo", "BG=GREEN, HoverBG=BLUE");
        nwl.setBackground(Color.GREEN);
        nwl.setHoverBackground(Color.BLUE);
        add(nwl);
        
        add(Filler.createVerticalStrut(20));

        nwl = new NewWindowLink("http://www.nextapp.com/products/echo", "BG=GREEN, HoverBG=YELLOW");
        nwl.setBackground(Color.GREEN);
        nwl.setHoverBackground(Color.YELLOW);
        add(nwl);
        add(Filler.createVerticalStrut(5));
        nwl = new NewWindowLink("http://www.nextapp.com/products/echo", "BG=GREEN, HoverBG=YELLOW");
        nwl.setBackground(Color.GREEN);
        nwl.setHoverBackground(Color.YELLOW);
        add(nwl);
    }
}
