/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.testforecho;

import nextapp.echo.ContentPane;
import nextapp.echo.Filler;
import nextapp.echo.Button;
import nextapp.echo.event.ActionEvent;
import nextapp.echo.event.ActionListener;

public class DoubleSubmitTest extends ContentPane 
implements ActionListener {

    private Button disablingSubmitButton;
    private Button hidingSubmitButton;
    private Button resetButton;
    
    public DoubleSubmitTest() {
        add(new HelpPanel("Double Submit Test",
                "The purpose of this test is to ensure that \"double submits\" cannot occur."));
        add(Filler.createVerticalStrut(20));
        
        disablingSubmitButton = new Button("Disabling Submit");
        disablingSubmitButton.addActionListener(this);
        add(disablingSubmitButton);
        add(Filler.createHorizontalStrut(20));
        hidingSubmitButton = new Button("Hiding Submit");
        hidingSubmitButton.addActionListener(this);
        add(hidingSubmitButton);
        add(Filler.createHorizontalStrut(20));
        resetButton = new Button("Reset");
        resetButton.addActionListener(this);
        add(resetButton);
    }
    
    public void actionPerformed(ActionEvent e) {
        if (e.getSource() == disablingSubmitButton) {
            if (disablingSubmitButton.isEnabled()) {
                TestForEcho.getApplicationInstance().getLogger().log("Submit occurred (disabling button)");
                disablingSubmitButton.setEnabled(false);
            } else {
                TestForEcho.getApplicationInstance().getLogger().log("Double-submit occurred (disabling button)");
            }
        } else if (e.getSource() == hidingSubmitButton) {
            if (hidingSubmitButton.isVisible()) {
                TestForEcho.getApplicationInstance().getLogger().log("Submit occurred (hiding button)");
                hidingSubmitButton.setVisible(false);
            } else {
                TestForEcho.getApplicationInstance().getLogger().log("Double-submit occurred (hiding button)");
            }
        } else if (e.getSource() == resetButton) {
            TestForEcho.getApplicationInstance().getLogger().log("Reset");
            disablingSubmitButton.setEnabled(true);
            hidingSubmitButton.setVisible(true);
        }
    }
}
