/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.testforecho;

import java.util.EventListener;

import nextapp.echo.Button;
import nextapp.echo.Component;
import nextapp.echo.ContentPane;
import nextapp.echo.Filler;
import nextapp.echo.Label;
import nextapp.echo.Table;
import nextapp.echo.event.ActionEvent;
import nextapp.echo.event.ActionListener;
import nextapp.echo.event.EventListenerList;
import nextapp.echo.table.AbstractTableModel;
import nextapp.echo.table.TableCellRenderer;

public class EventListenerListTest extends ContentPane 
implements ActionListener {
        
    private interface AlphaListener extends EventListener {
        public void alpha();
    }
    
    private interface BetaListener extends EventListener {
        public void beta();
    }
    
    private class AlphaImpl1 
    implements AlphaListener {
        
        public void alpha() { }
    }
    
    private class AlphaImpl2
    implements AlphaListener {
        
        public void alpha() { }
    }
    
    private class BetaImpl
    implements BetaListener {
        
        public void beta() { }
    }
    
    private class AlphaBetaImpl
    implements AlphaListener, BetaListener {
        
        public void alpha() { }
        
        public void beta() { }
    }
    
    private class ListenerTableModel extends AbstractTableModel 
    implements ActionListener, TableCellRenderer {
        
        private Class listenerClass;
        
        public ListenerTableModel(Class listenerClass) {
            super();
            this.listenerClass = listenerClass;
        }
        
        public void actionPerformed(ActionEvent e) {
            int row = Integer.parseInt(e.getActionCommand());
            EventListener l = testListenerList.getListeners(listenerClass)[row];
            TestForEcho.getApplicationInstance().getLogger().log("Removing " + listenerClass + ": l");
            testListenerList.removeListener(listenerClass, l);
            fireTableDataChanged();
        }
        
        public String getColumnName(int column) {
            return listenerClass.getName();
        }
        
        public int getRowCount() {
            return testListenerList.getListenerCount(listenerClass);
        }
        
        public int getColumnCount() {
            return 1;
        }
        
        public Object getValueAt(int column, int row) {
            // Horribly inefficent, but its just a test.
            return testListenerList.getListeners(listenerClass)[row];
        }
        
        public Component getTableCellRendererComponent(Table table, Object value, int column, int row) {
            Button button = new Button(value.toString());
            button.setActionCommand(Integer.toString(row));
            button.addActionListener(ListenerTableModel.this);
            return button;
        }
    }
    
    private EventListenerList testListenerList = new EventListenerList();
    private Button alphaImpl1Button, alphaImpl2Button, betaImplButton, 
           alphaBetaImplAsAlphaButton, alphaBetaImplAsBetaButton;
    private ListenerTableModel alphaTableModel, betaTableModel;

    public EventListenerListTest() {
        add(new HelpPanel("Event Listener List Test",
                "This test evaluates the operation of an EventListenerList."));
        add(Filler.createVerticalStrut(20));

        alphaTableModel = new ListenerTableModel(AlphaListener.class);
        Table alphaTable = new Table(alphaTableModel);
        alphaTable.setDefaultRenderer(Object.class, alphaTableModel);
        add(alphaTable);
        
        add(Filler.createVerticalStrut(10));
        
        betaTableModel = new ListenerTableModel(BetaListener.class);
        Table betaTable = new Table(betaTableModel);
        betaTable.setDefaultRenderer(Object.class, betaTableModel);
        add(betaTable);
        
        add(Filler.createVerticalStrut(20));
        add(new Label("Add Listeners: "));
        alphaImpl1Button = new Button("Alpha-Impl-1");
        alphaImpl1Button.addActionListener(this);
        add(alphaImpl1Button);
        alphaImpl2Button = new Button("Alpha-Impl-2");
        alphaImpl2Button.addActionListener(this);
        add(alphaImpl2Button);
        betaImplButton = new Button("Beta-Impl");
        betaImplButton.addActionListener(this);
        add(betaImplButton);
        alphaBetaImplAsAlphaButton = new Button("(Alpha)Alpha-Beta-Impl");
        alphaBetaImplAsAlphaButton.addActionListener(this);
        add(alphaBetaImplAsAlphaButton);
        alphaBetaImplAsBetaButton = new Button("(Beta)Alpha-Beta-Impl");
        alphaBetaImplAsBetaButton.addActionListener(this);
        add(alphaBetaImplAsBetaButton);
    }
    
    public void actionPerformed(ActionEvent e) {
        TestForEcho app = TestForEcho.getApplicationInstance();
        if (e.getSource() == alphaImpl1Button) {
            app.getLogger().log("testListenerList.addListener(AlphaListener.class, new AlphaImpl1());"); 
            testListenerList.addListener(AlphaListener.class, new AlphaImpl1());
        } else if (e.getSource() == alphaImpl2Button) {
            app.getLogger().log("testListenerList.addListener(AlphaListener.class, new AlphaImpl2());"); 
            testListenerList.addListener(AlphaListener.class, new AlphaImpl2());
        } else if (e.getSource() == betaImplButton) {
            app.getLogger().log("testListenerList.addListener(BetaListener.class, new BetaImpl());"); 
            testListenerList.addListener(BetaListener.class, new BetaImpl());
        } else if (e.getSource() == alphaBetaImplAsAlphaButton) {
            app.getLogger().log("testListenerList.addListener(AlphaListener.class, new AlphaBetaImpl());"); 
            testListenerList.addListener(AlphaListener.class, new AlphaBetaImpl());
        } else if (e.getSource() == alphaBetaImplAsBetaButton) {
            app.getLogger().log("testListenerList.addListener(BetaListener.class, new AlphaBetaImpl());"); 
            testListenerList.addListener(BetaListener.class, new AlphaBetaImpl());
        }
        alphaTableModel.fireTableDataChanged();
        betaTableModel.fireTableDataChanged();
    }
}
