/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.testforecho;

import nextapp.echo.Button;
import nextapp.echo.Component;
import nextapp.echo.Container;
import nextapp.echo.ContentPane;
import nextapp.echo.Filler;
import nextapp.echo.ListBox;
import nextapp.echo.PasswordField;
import nextapp.echo.SelectField;
import nextapp.echo.TextArea;
import nextapp.echo.TextField;
import nextapp.echo.event.ActionEvent;
import nextapp.echo.event.ActionListener;

public class FocusTest extends ContentPane {
    
    private class Tester extends Container {
        
        private Component component;
        
        public Tester(Component component) {
            this.component = component;
            add(component);
            Button button = new Button("focus");
            add(button);
            button.addActionListener(new ActionListener() {
                public void actionPerformed(ActionEvent e) {
                    Tester.this.component.setFocused(true);
                }
            });
        }
    }
    
    public FocusTest() {
        add(new HelpPanel("Focus Test", 
                "This test evaluates the capability of an Echo application to control component focus."));
        add(Filler.createVerticalStrut(20));

        TestPanel testPanel = new TestPanel();        
        add(testPanel);

        TextField textField = new TextField(40);
        testPanel.add("Text Field", new Tester(textField));
        TextArea textArea = new TextArea(40, 5);
        testPanel.add("Text Area", new Tester(textArea));
        PasswordField passwordField = new PasswordField(40);
        testPanel.add("Password Field", new Tester(passwordField));
        ListBox listBox = new ListBox(new String[]{"Alpha", "Bravo", "Charlie"});
        testPanel.add("List Box", new Tester(listBox));
        SelectField selectField = new SelectField(new String[]{"Alpha", "Bravo", "Charlie"});
        testPanel.add("Select Field", new Tester(selectField));
    }    
}
