/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.testforecho;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.io.Serializable;

import nextapp.echo.AbstractSelectFieldModel;
import nextapp.echo.Button;
import nextapp.echo.CheckBox;
import nextapp.echo.Color;
import nextapp.echo.Component;
import nextapp.echo.Container;
import nextapp.echo.ContainerPane;
import nextapp.echo.ContentPane;
import nextapp.echo.DefaultSelectFieldModel;
import nextapp.echo.EchoConstants;
import nextapp.echo.Filler;
import nextapp.echo.Font;
import nextapp.echo.HttpImageReference;
import nextapp.echo.Insets;
import nextapp.echo.Label;
import nextapp.echo.Grid;
import nextapp.echo.Panel;
import nextapp.echo.SelectField;
import nextapp.echo.Table;
import nextapp.echo.event.ActionEvent;
import nextapp.echo.event.ActionListener;
import nextapp.echo.table.AbstractTableModel;
import nextapp.echo.table.TableCellRenderer;

public class GridTest extends ContainerPane {

    private TestForEcho app;
    private GridPane gridPane;
    private ControlPane controlPane;
    private ContainerPane gridContainer;
    private CellEditorPane cellEditor;
    
    private class CellEditorPane extends ContentPane 
    implements ActionListener {
        
        private TestCell cell;
        private Button removeButton;
        private CheckBox flowLeft;
        private CheckBox flowRight;
        private CheckBox flowUp;
        private CheckBox flowDown;
        private SelectField columnSelect;
        private SelectField rowSelect;
        private SelectField columnSpanSelect;
        private SelectField rowSpanSelect;
        private SelectField horizontalAlignmentSelect;
        private SelectField verticalAlignmentSelect;
        private Button applyButton;
        private CheckBox visible;
        
        public CellEditorPane(TestCell cell) {
            super();
            
            this.setWidth(250);
            this.setBackground(new Color(0xdf, 0xe3, 0xff));
            this.cell = cell;

            this.setInsets(new Insets(0));
            Panel panel = new Panel();
            panel.setInsets(new Insets(5));
            panel.add(new Label(cell.getLabel()));
            panel.setHorizontalAlignment(EchoConstants.CENTER);
            panel.setBackground(Color.BLUE);
            panel.setForeground(Color.WHITE);
            this.add(panel);
            
            TestPanel testPanel = new TestPanel();
            
            columnSelect = new SelectField(new NumericSelectFieldModel(0, 24));
            columnSelect.setSelectedIndex(cell.getColumn());
            testPanel.add(("Column"), columnSelect);
            
            rowSelect = new SelectField(new NumericSelectFieldModel(0, 24));
            rowSelect.setSelectedIndex(cell.getRow());
            testPanel.add(("Row"), rowSelect);
            
            columnSpanSelect = new SelectField(new NumericSelectFieldModel(1, 10));
            columnSpanSelect.setSelectedIndex(cell.getColumnSpan() - 1);
            testPanel.add("Column Span", columnSpanSelect);
            
            rowSpanSelect = new SelectField(new NumericSelectFieldModel(1, 10));
            rowSpanSelect.setSelectedIndex(cell.getRowSpan() - 1);
            testPanel.add("Row Span", rowSpanSelect);
            
            horizontalAlignmentSelect = new SelectField(new DefaultSelectFieldModel(new ListElement[]{
                    new ListElement(new Integer(0), "Default"),
                    new ListElement(new Integer(EchoConstants.LEFT), "Left"),
                    new ListElement(new Integer(EchoConstants.CENTER), "Center"),
                    new ListElement(new Integer(EchoConstants.RIGHT), "Right")}));
            testPanel.add("H-Align", horizontalAlignmentSelect);

            verticalAlignmentSelect = new SelectField(new DefaultSelectFieldModel(new ListElement[]{
                    new ListElement(new Integer(0), "Default"),
                    new ListElement(new Integer(EchoConstants.TOP), "Top"),
                    new ListElement(new Integer(EchoConstants.CENTER), "Center"),
                    new ListElement(new Integer(EchoConstants.BOTTOM), "Bottom")}));
            testPanel.add("V-Align", verticalAlignmentSelect);
            
            Grid flowButtonLayoutGrid = new Grid();
            flowUp = new CheckBox("Up", (cell.getFlow() & Grid.Cell.FLOW_UP) != 0);
            flowLeft = new CheckBox("Left", (cell.getFlow() & Grid.Cell.FLOW_LEFT) != 0);
            flowRight = new CheckBox("Right", (cell.getFlow() & Grid.Cell.FLOW_RIGHT) != 0);
            flowDown = new CheckBox("Down", (cell.getFlow() & Grid.Cell.FLOW_DOWN) != 0);
            flowButtonLayoutGrid.add(1, 0, flowUp);
            flowButtonLayoutGrid.add(0, 1, flowLeft);
            flowButtonLayoutGrid.add(2, 1, flowRight);
            flowButtonLayoutGrid.add(1, 2, flowDown);
            testPanel.add("Flow", flowButtonLayoutGrid);
            
            visible = new CheckBox();
            visible.setSelected(cell.isVisible());
            testPanel.add("Visible", visible);
            
            panel.add(testPanel);
            panel.add(Filler.createVerticalStrut(5));
            applyButton = new Button("Apply Changes");
            applyButton.addActionListener(this);
            panel.add(applyButton);
            panel.add(Filler.createVerticalStrut(5));
            removeButton = new Button("Remove Cell");
            removeButton.addActionListener(this);
            panel.add(removeButton);

            this.add(panel);
        }
        
        public void actionPerformed(ActionEvent e) {
            if (e.getSource() == removeButton) {
                TestGrid testGrid = (TestGrid) cell.getParent();
                testGrid.removeCell(cell);
            } else if (e.getSource() == applyButton) {
                int flow = 0;
                flow |= flowLeft.isSelected() ? Grid.Cell.FLOW_LEFT : 0;
                flow |= flowRight.isSelected() ? Grid.Cell.FLOW_RIGHT : 0;
                flow |= flowUp.isSelected() ? Grid.Cell.FLOW_UP : 0;
                flow |= flowDown.isSelected() ? Grid.Cell.FLOW_DOWN : 0;
                cell.setFlow(flow);
                
                cell.setColumnSpan(((Integer) columnSpanSelect.getSelectedItem()).intValue());
                cell.setRowSpan(((Integer) rowSpanSelect.getSelectedItem()).intValue());

                cell.setHorizontalAlignment(
                        ((Integer) ((ListElement) horizontalAlignmentSelect.getSelectedItem()).getObject()).intValue());
                cell.setVerticalAlignment(
                        ((Integer) ((ListElement) verticalAlignmentSelect.getSelectedItem()).getObject()).intValue());
                cell.setVisible(visible.isSelected());
                
                int column = ((Integer) columnSelect.getSelectedItem()).intValue();
                int row = ((Integer) rowSelect.getSelectedItem()).intValue();
                if (column != cell.getColumn() || row != cell.getRow()) {
                    gridPane.getGrid().remove(cell);
                    gridPane.getGrid().add(column, row, cell);
                }
            }
        }
    }

    private class ControlPane extends ContentPane 
    implements ActionListener {
    
        private String INTERESTING_GRID = "Interesting Grid";
        private String EMPTY_GRID = "Empty Grid";
        
        private static final int X = EchoConstants.UNDEFINED_SIZE;
        private static final int PX = Grid.PIXEL_UNITS;
        private static final int PER = Grid.PERCENT_UNITS;
        private static final int PIPT = Grid.PERCENT_INDIVIDUAL_PIXEL_TOTAL_UNITS;
        
        private ListElement[] sizeOptions = new ListElement[] {
                new ListElement(new int[]{PX,     X,   X,   X,   X,   X,   X}, "All UNK total=UNK"),
                new ListElement(new int[]{PX,   600,   X,   X,   X,   X,   X}, "All UNK total=600"),
                new ListElement(new int[]{PER,   80,   X,   X,   X,   X,   X}, "All UNK total=80%"),
                new ListElement(new int[]{PER,  100,   X,   X,   X,   X,   X}, "All UNK total=100%"),
                new ListElement(new int[]{PX,     X,  80,  60,  40,  90, 120}, "80,60,40,90,120 total=UNK"),
                new ListElement(new int[]{PX,   600,  80,  60,  40,  90, 120}, "80,60,40,90,120 total=600"),
                new ListElement(new int[]{PX,     X,  80,   X,  40,   X, 120}, "80,UNK,40,UNK,120 total=UNK"),
                new ListElement(new int[]{PX,   600,  80,   X,  40,   X, 120}, "80,UNK,40,UNK,120 total=600"),
                new ListElement(new int[]{PER,    X,  10,   5,  20,  40,  25}, "10%,5%,20%,40%,25% total=UNK"),
                new ListElement(new int[]{PIPT, 600,  10,   5,  20,  40,  25}, "10%,5%,20%,40%,25% total=600"),
                new ListElement(new int[]{PER,   80,  10,   5,  20,  40,  25}, "10%,5%,20%,40%,25% total=80%"),
                new ListElement(new int[]{PER,  100,  10,   5,  20,  40,  25}, "10%,5%,20%,40%,25% total=100%"),
                new ListElement(new int[]{PER,    X,  10,   5,   X,  40,  25}, "10%,5%,UNK,40%,25% total=UNK"),
                new ListElement(new int[]{PIPT, 600,  10,   5,   X,  40,  25}, "10%,5%,UNK,40%,25% total=600"),
                new ListElement(new int[]{PER,   80,  10,   5,   X,  40,  25}, "10%,5%,UNK,40%,25% total=80%"),
                new ListElement(new int[]{PER,  100,  10,   5,   X,  40,  25}, "10%,5%,UNK,40%,25% total=100%")};
                
        private ListElement[] colors = new ListElement[] {
                new ListElement(null, "(null)"),
                new ListElement(Color.BLUE, "Blue"),
                new ListElement(Color.GREEN, "Green"),
                new ListElement(Color.RED, "Red"),
                new ListElement(Color.WHITE, "White"),
                new ListElement(Color.BLACK, "Black")};
        
        private ListElement[] fonts = new ListElement[] {
            new ListElement(null, "(null)"),
            new ListElement(new Font(Font.SERIF, Font.ITALIC, 30), "Times 30 Bold")};
        
        private SelectField gridSelect;
        private SelectField gridBorderColorSelect;
        private SelectField gridBorderSizeSelect;
        private SelectField gridCellMarginSelect;
        private SelectField columnWidthSelect;
        private SelectField rowHeightSelect;
        private SelectField rowDeleteSelect;
        private SelectField columnDeleteSelect;
        private SelectField rowInsertSelect;
        private SelectField columnInsertSelect;
        private SelectField gridBackgroundSelect;
        private SelectField gridForegroundSelect;
        private SelectField gridFontSelect;
        private SelectField contentPaneBackgroundSelect;
        private SelectField contentPaneForegroundSelect;
        private SelectField contentPaneFontSelect;
        private Button rowDeleteButton;
        private Button columnDeleteButton;
        private Button rowInsertButton;
        private Button columnInsertButton;
    
        public ControlPane() {
            super();
            
            TestPanel testPanel = new TestPanel();

            gridSelect = new SelectField(new Object[]{EMPTY_GRID, INTERESTING_GRID});
            gridSelect.addActionListener(this);
            testPanel.add("Grid", gridSelect);

            testPanel.addHeader("Basic Properties");
            
            gridBackgroundSelect = new SelectField(colors);
            gridBackgroundSelect.addActionListener(this);
            testPanel.add("Grid Background", gridBackgroundSelect);

            gridForegroundSelect = new SelectField(colors);
            gridForegroundSelect.addActionListener(this);
            testPanel.add("Grid Foreground", gridForegroundSelect);

            gridFontSelect = new SelectField(fonts);
            gridFontSelect.addActionListener(this);
            testPanel.add("Grid Font", gridFontSelect);

            gridBorderColorSelect = new SelectField(colors);
            gridBorderColorSelect.addActionListener(this);
            testPanel.add("Grid Border Color", gridBorderColorSelect);
            
            gridBorderSizeSelect = new SelectField(new NumericSelectFieldModel(0, 15));
            gridBorderSizeSelect.addActionListener(this);
            testPanel.add("Grid Border Size", gridBorderSizeSelect);
            
            gridCellMarginSelect = new SelectField(new NumericSelectFieldModel(0, 15));
            gridCellMarginSelect.addActionListener(this);
            testPanel.add("Grid Cell Margin", gridCellMarginSelect);

            contentPaneBackgroundSelect = new SelectField(colors);
            contentPaneBackgroundSelect.addActionListener(this);
            testPanel.add("ContentPane Background", contentPaneBackgroundSelect);

            contentPaneForegroundSelect = new SelectField(colors);
            contentPaneForegroundSelect.addActionListener(this);
            testPanel.add("ContentPane Foreground", contentPaneForegroundSelect);

            contentPaneFontSelect = new SelectField(fonts);
            contentPaneFontSelect.addActionListener(this);
            testPanel.add("ContentPane Fonts", contentPaneFontSelect);

            testPanel.addHeader("Margins");
            
            columnWidthSelect = new SelectField(sizeOptions);
            columnWidthSelect.addActionListener(this);
            testPanel.add("Column Widths", columnWidthSelect);

            rowHeightSelect = new SelectField(sizeOptions);
            rowHeightSelect.addActionListener(this);
            testPanel.add("Row Heights", rowHeightSelect);
            
            testPanel.addHeader("Insert/Delete Rows/Columns");
            
            Panel columnDeletePanel = new Panel();
            columnDeleteSelect = new SelectField(new NumericSelectFieldModel(0, 15));
            columnDeletePanel.add(columnDeleteSelect);
            columnDeleteButton = new Button("Delete");
            columnDeleteButton.addActionListener(this);
            columnDeletePanel.add(columnDeleteButton);
            testPanel.add("Delete Column", columnDeletePanel);
            
            Panel rowDeletePanel = new Panel();
            rowDeleteSelect = new SelectField(new NumericSelectFieldModel(0, 15));
            rowDeletePanel.add(rowDeleteSelect);
            rowDeleteButton = new Button("Delete");
            rowDeleteButton.addActionListener(this);
            rowDeletePanel.add(rowDeleteButton);
            testPanel.add("Delete Row", rowDeletePanel);
            
            Panel columnInsertPanel = new Panel();
            columnInsertSelect = new SelectField(new NumericSelectFieldModel(0, 15));
            columnInsertPanel.add(columnInsertSelect);
            columnInsertButton = new Button("Insert");
            columnInsertButton.addActionListener(this);
            columnInsertPanel.add(columnInsertButton);
            testPanel.add("Insert Column", columnInsertPanel);
            
            Panel rowInsertPanel = new Panel();
            rowInsertSelect = new SelectField(new NumericSelectFieldModel(0, 15));
            rowInsertPanel.add(rowInsertSelect);
            rowInsertButton = new Button("Insert");
            rowInsertButton.addActionListener(this);
            rowInsertPanel.add(rowInsertButton);
            testPanel.add("Insert Row", rowInsertPanel);
            
            this.add(testPanel);
        }
        
        public void actionPerformed(ActionEvent e) {
            if (e.getSource() == gridSelect) {
                if (gridSelect.getSelectedItem() == INTERESTING_GRID) {
                    gridPane.setGrid(createInterestingGrid());
                } else if (gridSelect.getSelectedItem() == EMPTY_GRID) {
                    gridPane.setGrid(new TestGrid());
                }
            } else  if (e.getSource() == gridForegroundSelect) {
                gridPane.getGrid().setForeground((Color) ((ListElement) gridForegroundSelect.getSelectedItem()).getObject());
            } else  if (e.getSource() == gridBackgroundSelect) {
                gridPane.getGrid().setBackground((Color) ((ListElement) gridBackgroundSelect.getSelectedItem()).getObject());
            } else  if (e.getSource() == gridFontSelect) {
                gridPane.getGrid().setFont((Font) ((ListElement) gridFontSelect.getSelectedItem()).getObject());
            } else  if (e.getSource() == gridBorderColorSelect) {
                gridPane.getGrid().setBorderColor((Color) ((ListElement) gridBorderColorSelect.getSelectedItem()).getObject());
            } else  if (e.getSource() == gridBorderSizeSelect) {
                gridPane.getGrid().setBorderSize(Integer.parseInt(gridBorderSizeSelect.getSelectedItem().toString()));
            } else  if (e.getSource() == gridCellMarginSelect) {
                gridPane.getGrid().setCellMargin(Integer.parseInt(gridCellMarginSelect.getSelectedItem().toString()));
            } else  if (e.getSource() == contentPaneForegroundSelect) {
                gridPane.setForeground((Color) ((ListElement) contentPaneForegroundSelect.getSelectedItem()).getObject());
            } else  if (e.getSource() == contentPaneBackgroundSelect) {
                gridPane.setBackground((Color) ((ListElement) contentPaneBackgroundSelect.getSelectedItem()).getObject());
            } else  if (e.getSource() == contentPaneFontSelect) {
                gridPane.setFont((Font) ((ListElement) contentPaneFontSelect.getSelectedItem()).getObject());
            } else if (e.getSource() == columnWidthSelect) {
                Grid grid = gridPane.getGrid();
                if (grid != null) {
                    ListElement elem = (ListElement) columnWidthSelect.getSelectedItem();
                    int[] data = (int[]) elem.getObject();
                    grid.setWidthUnits(data[0]);
                    grid.setWidth(data[1]);
                    for (int index = 0; index < 5; ++index) {
                        grid.setColumnWidth(index, data[index + 2]);
                    }
                }
            } else if (e.getSource() == rowHeightSelect) {
                Grid grid = gridPane.getGrid();
                if (grid != null) {
                    ListElement elem = (ListElement) rowHeightSelect.getSelectedItem();
                    int[] data = (int[]) elem.getObject();
                    grid.setHeightUnits(data[0]);
                    grid.setHeight(data[1]);
                    for (int index = 0; index < 5; ++index) {
                        grid.setRowHeight(index, data[index + 2]);
                    }
                }
            } else if (e.getSource() == columnDeleteButton) {
                Grid grid = gridPane.getGrid();
                grid.deleteColumn(Integer.parseInt(columnDeleteSelect.getSelectedItem().toString()));
            } else if (e.getSource() == rowDeleteButton) {
                Grid grid = gridPane.getGrid();
                grid.deleteRow(Integer.parseInt(rowDeleteSelect.getSelectedItem().toString()));
            } else if (e.getSource() == columnInsertButton) {
                Grid grid = gridPane.getGrid();
                grid.insertColumn(Integer.parseInt(columnInsertSelect.getSelectedItem().toString()));
            } else if (e.getSource() == rowInsertButton) {
                Grid grid = gridPane.getGrid();
                grid.insertRow(Integer.parseInt(rowInsertSelect.getSelectedItem().toString()));
            }
        }
    }
    
    private class GridComponentListTable extends Table {
    
        private class GridComponentListTableCellRenderer 
        implements ActionListener, TableCellRenderer, Serializable {
        
            public void actionPerformed(ActionEvent e) {
                TestCell cell = (TestCell) grid.getComponent(Integer.parseInt(e.getActionCommand()));
                grid.selectCell(cell);
            }

            public Component getTableCellRendererComponent(Table table, Object value, int column, int row) {
                Button button = new Button((String) value);
                button.setActionCommand(Integer.toString(row));
                button.addActionListener(GridComponentListTableCellRenderer.this);
                return button;
            }
        }

        private class GridComponentListTableModel extends AbstractTableModel 
        implements PropertyChangeListener {

            public GridComponentListTableModel() {
                grid.addPropertyChangeListener(this);
            }

            public int getColumnCount() {
                return 4;
            }

            public String getColumnName(int column) {
                switch (column) {
                case 0: return "#";
                case 1: return "Content";
                case 2: return "Position";
                case 3: return "Dimension";
                default: throw new IndexOutOfBoundsException(Integer.toString(column));
                }
            }

            public int getRowCount() {
                return grid.getComponentCount();
            }

            public Object getValueAt(int column, int row) {
                Object value;
                TestCell cell;

                switch (column) {
                case 0:
                    value = Integer.toString(row);
                    break;
                case 1:
                    value = ((TestCell) grid.getComponent(row)).getLabel();
                    break;
                case 2:
                    cell = (TestCell) grid.getComponent(row);
                    value = "(" + cell.getColumn() + ", " + cell.getRow() + ")";
                    break;
                case 3:
                    cell = (TestCell) grid.getComponent(row);
                    value = cell.getColumnSpan() + "x" + cell.getRowSpan();
                    break;
                default:
                    throw new IllegalArgumentException();
                }

                return value;
            }

            public void propertyChange(PropertyChangeEvent e) {
                fireTableStructureChanged();
            }
        }
        
        private TestGrid grid;

        public GridComponentListTable() {
            super();
        }
        
        public void setGrid(TestGrid grid) {
            this.grid = grid;
            setModel(new GridComponentListTableModel());
            setDefaultRenderer(Object.class, new GridComponentListTableCellRenderer());
        }
    }
    
    private class GridPane extends ContentPane {
        
        private TestGrid grid = null;
        private GridComponentListTable gridComponentListTable;
        private Container gridContainer;

        public GridPane() {
            super();
            
            gridContainer = new Container();
            this.add(new HelpPanel("Grid Test", 
                    "This test evaluates the functionality of the Grid component.  Clicking on the content of a cell will "
                    + "allow you to move, resize, or alter other properties of the cell.   The table below the grid is a list "
                    + "of all of its cells.  Additional modifications may be made to the grid using the controls in the lower "
                    + "pane."));
            this.add(Filler.createVerticalStrut(20));
            this.add(gridContainer);
            this.add(Filler.createVerticalStrut(20));
            gridComponentListTable = new GridComponentListTable();
            this.add(gridComponentListTable);
            this.add(Filler.createVerticalStrut(20));
            this.add(new Label("non-grid-embedded label"));

        }
        
        public TestGrid getGrid() {
            return grid;
        }
        
        public void setGrid(TestGrid newValue) {
            if (grid != null) {
                grid.selectCell(null);
                gridContainer.remove(grid);
            }
            grid = newValue;
            gridComponentListTable.setGrid(grid);
            gridContainer.add(grid, 0);
        }
    }
    
    private class NumericSelectFieldModel extends AbstractSelectFieldModel {
    
        private int min, max;
     
        public NumericSelectFieldModel(int min, int max) {
            super();
            
            if (max < min) {
                throw new IllegalArgumentException("Max < Min");
            }
            
            this.min = min;
            this.max = max;
        }
        
        public Object get(int index) {
            return new Integer(min + index);
        }
        
        public int size() {
            return max - min + 1;
        }
    }
    
    private class TestCell extends Grid.Cell 
    implements ActionListener {
    
        private String label;
    
        public TestCell(String label) {
            super();
            
            this.label = label;
            
            Button button = new Button(label);
            button.addActionListener(this);
            
            this.add(button);
        }
        
        public void actionPerformed(ActionEvent e) {
            ((TestGrid) this.getParent()).selectCell(this);
        }
        
        public String getLabel() {
            return label;
        }
    }
    
    private class TestGrid extends Grid {
    
        private TestCell selectedCell = null;
        private Color selectedCellBackground = null;
    
        public TestGrid() {
            super();
        }
        
        public void removeCell(TestCell removeCell) {
            if (removeCell == selectedCell) {
                selectCell(null);
            }
            
            this.remove(removeCell);
        }
        
        public void selectCell(TestCell newValue) {
            if (selectedCell != null) {
                selectedCell.setBackground(selectedCellBackground);
                if (gridContainer.indexOf(cellEditor) != -1) {
                    gridContainer.remove(cellEditor);
                }
                cellEditor = null;
            }
            selectedCell = newValue;
            if (selectedCell != null) {
                selectedCellBackground = selectedCell.getBackground();
                selectedCell.setBackground(Color.YELLOW);
                cellEditor = new CellEditorPane(selectedCell);
                gridContainer.add(cellEditor);
            }
        }
        
        public void validate() {
            try {
                super.validate();
            } catch (Grid.GridCellOverlapException ex) {
                app.getLogger().log("Caught GridCellOverlapException: " + ex + "...*** RENDERING WILL BE FLAWED ***");
            }
        }
    }
    
    public GridTest() {
        setOrientation(ORIENTATION_VERTICAL);

        gridPane = new GridPane();
        gridPane.setGrid(createInterestingGrid());
        gridContainer = new ContainerPane();
        gridContainer.setOrientation(ORIENTATION_HORIZONTAL);
        gridContainer.add(gridPane);
        add(gridContainer);
        
        controlPane = new ControlPane();
        controlPane.setHeight(200);
        add(controlPane);
    }

    public TestGrid createInterestingGrid() {

        TestGrid grid = new TestGrid();
        Grid.Cell cell;
        
        grid.setCellMargin(4);
        grid.setBorderColor(Color.BLACK);
        grid.setBorderSize(1);
        
        cell = new TestCell("A normal Cell");
        grid.add(0, 0, cell);
        
        cell = new TestCell("A cell that spans two columns");
        cell.setColumnSpan(2);
        grid.add(1, 0, cell);
        
        cell = new TestCell("Button with custom font");
        cell.getComponent(0).setFont(new Font(Font.SERIF, Font.UNDERLINE, 24));
        grid.add(3, 0, cell);
        
        cell = new TestCell("Just another cell");
        grid.add(4, 0, cell);
        
        cell = new TestCell("A cell that spans two rows");
        cell.setRowSpan(2);
        grid.add(0, 1, cell);
        
        cell = new TestCell("Cell with a custom font");
        cell.setFont(new Font(Font.SERIF, Font.UNDERLINE, 24));
        grid.add(1, 1, cell);
        
        cell = new TestCell("A cell with insets");
        cell.setInsets(new Insets(50));
        grid.add(2, 1, cell);
        
        cell = new TestCell("A cell that spans four rows");
        cell.setRowSpan(4);
        grid.add(4, 1, cell);

        cell = new TestCell("Another cell with insets");
        cell.setInsets(new Insets(0, 10, 40, 20));
        grid.add(1, 2, cell);
        
        cell = new TestCell("A cell that spans two columns and two rows");
        cell.setColumnSpan(2);
        cell.setRowSpan(2);
        grid.add(2, 2, cell);
        
        cell = new TestCell("A cell that flows down into empty cells");
        cell.setFlow(Grid.Cell.FLOW_DOWN);
        grid.add(0, 3, cell);
        
        cell = new TestCell("With a background");
        cell.setBackgroundImage(new HttpImageReference("images/ImageTestHttpImage.png"));
        grid.add(1, 3, cell);
        
        cell = new TestCell("A cell that flows to the right into empty cell");
        cell.setFlow(Grid.Cell.FLOW_RIGHT);
        grid.add(1, 4, cell);
        
        cell = new TestCell("Yet another normal cell");
        grid.add(3, 4, cell);
        
        return grid;
    }
}
