/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.testforecho;

import nextapp.echo.CheckBox;
import nextapp.echo.Color;
import nextapp.echo.Container;
import nextapp.echo.EchoConstants;
import nextapp.echo.Font;
import nextapp.echo.Grid;
import nextapp.echo.Label;
import nextapp.echo.event.ActionEvent;
import nextapp.echo.event.ActionListener;

public class HelpPanel extends Container 
implements ActionListener {

    private CheckBox visibilityCheckBox;
    private Grid.Cell descriptionCell;

    public HelpPanel(String title, String description) {
        super();
        
        Grid grid = new Grid();
        grid.setBorderColor(new Color(0xafbfef));
        grid.setBackground(new Color(0xbfcfff));
        grid.setForeground(Color.BLACK);        
        grid.setBorderSize(1);
        grid.setCellMargin(5);
        grid.setWidthUnits(Grid.PERCENT_UNITS);
        grid.setWidth(100);
        grid.setColumnWidth(0, 70);
        grid.setColumnWidth(1, 30);

        Grid.Cell titleCell = new Grid.Cell();
        titleCell.setFont(new Font(Font.SANS_SERIF, 0, 14));
        titleCell.add(new Label(title));
        grid.add(0, 0, titleCell);

        Grid.Cell visibilityCell = new Grid.Cell();
        visibilityCell.setHorizontalAlignment(EchoConstants.RIGHT);
        visibilityCheckBox = new CheckBox("Display Help", true);
        visibilityCheckBox.addActionListener(this);
        visibilityCell.add(visibilityCheckBox);
        grid.add(1, 0, visibilityCell);
        
        descriptionCell = new Grid.Cell();
        descriptionCell.add(new Label(description));
        descriptionCell.setFlow(Grid.Cell.FLOW_RIGHT);
        grid.add(0, 1, descriptionCell);
        
        add(grid);
    }
    
    public void actionPerformed(ActionEvent e) {
        descriptionCell.setVisible(visibilityCheckBox.isSelected());    
    }
}
