/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.testforecho;

import java.awt.Graphics2D;
import java.awt.image.BufferedImage;
import java.io.IOException;
import java.io.OutputStream;

import nextapp.echo.AwtImageReference;
import nextapp.echo.BackgroundImageProperties;
import nextapp.echo.Button;
import nextapp.echo.CheckBox;
import nextapp.echo.Component;
import nextapp.echo.ContentPane;
import nextapp.echo.Extent;
import nextapp.echo.Filler;
import nextapp.echo.Label;
import nextapp.echo.HttpImageReference;
import nextapp.echo.ImageReference;
import nextapp.echo.ResourceImageReference;
import nextapp.echo.SelectField;
import nextapp.echo.StreamImageReference;
import nextapp.echo.event.ItemEvent;
import nextapp.echo.event.ItemListener;

public class ImageTest extends ContentPane {

    private static class TestStreamImage extends StreamImageReference {
    
        private static final byte[] data = new byte[]{
                (byte) 0x89, (byte) 0x50, (byte) 0x4e, (byte) 0x47, (byte) 0x0d, (byte) 0x0a, (byte) 0x1a, (byte) 0x0a,
                (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x0d, (byte) 0x49, (byte) 0x48, (byte) 0x44, (byte) 0x52,
                (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x64, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x64, 
                (byte) 0x08, (byte) 0x02, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0xff, (byte) 0x80, (byte) 0x02,
                (byte) 0x03, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0xad, (byte) 0x49, (byte) 0x44, (byte) 0x41,
                (byte) 0x54, (byte) 0x78, (byte) 0xda, (byte) 0xed, (byte) 0xd3, (byte) 0x41, (byte) 0x0d, (byte) 0xc0,
                (byte) 0x20, (byte) 0x10, (byte) 0x45, (byte) 0x41, (byte) 0xa8, (byte) 0x18, (byte) 0x48, (byte) 0x5a,
                (byte) 0x47, (byte) 0xf8, (byte) 0x03, (byte) 0x47, (byte) 0x1c, (byte) 0x50, (byte) 0xb3, (byte) 0xb5,
                (byte) 0xd0, (byte) 0xe3, (byte) 0x36, (byte) 0x99, (byte) 0xa7, (byte) 0xe0, (byte) 0x67, (byte) 0xb2,
                (byte) 0x5b, (byte) 0x23, (byte) 0xa2, (byte) 0xe4, (byte) 0xeb, (byte) 0x59, (byte) 0x3d, (byte) 0xe1,
                (byte) 0xaa, (byte) 0xab, (byte) 0x08, (byte) 0x16, (byte) 0x2c, (byte) 0x58, (byte) 0xb0, (byte) 0x60,
                (byte) 0xc1, (byte) 0x12, (byte) 0x2c, (byte) 0x58, (byte) 0xb0, (byte) 0x60, (byte) 0xc1, (byte) 0x82,
                (byte) 0x25, (byte) 0x58, (byte) 0xb0, (byte) 0x60, (byte) 0xc1, (byte) 0x82, (byte) 0x05, (byte) 0x4b,
                (byte) 0xb0, (byte) 0x60, (byte) 0xc1, (byte) 0x82, (byte) 0x05, (byte) 0x0b, (byte) 0x96, (byte) 0x60,
                (byte) 0xc1, (byte) 0x82, (byte) 0x05, (byte) 0x0b, (byte) 0x16, (byte) 0x2c, (byte) 0xc1, (byte) 0x82,
                (byte) 0x05, (byte) 0x0b, (byte) 0x16, (byte) 0x2c, (byte) 0x58, (byte) 0x82, (byte) 0x05, (byte) 0x0b,
                (byte) 0x16, (byte) 0x2c, (byte) 0x58, (byte) 0xb0, (byte) 0x04, (byte) 0x0b, (byte) 0x16, (byte) 0x2c,
                (byte) 0x58, (byte) 0xb0, (byte) 0x60, (byte) 0xe9, (byte) 0x73, (byte) 0xf5, (byte) 0x9e, (byte) 0x2d,
                (byte) 0xe1, (byte) 0xac, (byte) 0x3d, (byte) 0x8e, (byte) 0xcb, (byte) 0xf2, (byte) 0x86, (byte) 0xb0,
                (byte) 0x04, (byte) 0x0b, (byte) 0x16, (byte) 0x2c, (byte) 0x58, (byte) 0xb0, (byte) 0x60, (byte) 0x09,
                (byte) 0x16, (byte) 0x2c, (byte) 0x58, (byte) 0xb0, (byte) 0x60, (byte) 0xc1, (byte) 0x12, (byte) 0x2c,
                (byte) 0x58, (byte) 0xb0, (byte) 0x60, (byte) 0xc1, (byte) 0x82, (byte) 0x25, (byte) 0x58, (byte) 0xb0,
                (byte) 0x60, (byte) 0xc1, (byte) 0x82, (byte) 0x05, (byte) 0x4b, (byte) 0xb0, (byte) 0x60, (byte) 0xc1,
                (byte) 0x82, (byte) 0x05, (byte) 0x0b, (byte) 0x96, (byte) 0x60, (byte) 0xc1, (byte) 0x82, (byte) 0x05,
                (byte) 0x0b, (byte) 0x16, (byte) 0x2c, (byte) 0xc1, (byte) 0x82, (byte) 0x05, (byte) 0x0b, (byte) 0x16,
                (byte) 0x2c, (byte) 0x58, (byte) 0x82, (byte) 0x05, (byte) 0x0b, (byte) 0x16, (byte) 0xac, (byte) 0x7f,
                (byte) 0xf7, (byte) 0x02, (byte) 0x71, (byte) 0x23, (byte) 0x07, (byte) 0xb9, (byte) 0x30, (byte) 0xc2,
                (byte) 0x0f, (byte) 0xb4, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x49, (byte) 0x45,
                (byte) 0x4e, (byte) 0x44, (byte) 0xae, (byte) 0x42, (byte) 0x60, (byte) 0x82};

        public void render(OutputStream out) 
        throws IOException {
            out.write(data);
        }

        public String getContentType() {
            return "image/png";
        }
        
        public int getWidth() {
            return 100;
        }
        
        public int getHeight() {
            return 100;
        }
    }

    private static final ImageReference sharedAwtImage = new AwtImageReference(createBufferedImage());
    private static final ImageReference sharedHttpImage = new HttpImageReference("images/ImageTestHttpImage.png", 100, 100);
    private static final ImageReference sharedStreamImage = new TestStreamImage();
    private static final ImageReference sharedResourceImage 
            = new ResourceImageReference("/nextapp/testforecho/ImageTestResourceImage.png");
    
    private static final BufferedImage createBufferedImage() {
        BufferedImage image = new BufferedImage(100, 100, BufferedImage.TYPE_INT_RGB);
        Graphics2D graphics = (Graphics2D) image.getGraphics();
        graphics.setColor(java.awt.Color.red);
        graphics.fillRect(0, 0, 100, 100);
        graphics.setColor(java.awt.Color.blue);
        graphics.fillRect(25, 25, 50, 50);
        graphics.dispose();
        return image;
    }
    
    private abstract class ImageTypeSelectField extends SelectField 
    implements ItemListener {

        public ImageTypeSelectField() {
            super(new Object[]{
                    new ListElement(null, "None"),
                    new ListElement(awtImage, "AWT Image"),
                    new ListElement(httpImage, "HTTP Image"),
                    new ListElement(streamImage, "Stream Image"),
                    new ListElement(resourceImage, "Resource Image"),
                    new ListElement(sharedAwtImage, "AWT Image (SHARED)"),
                    new ListElement(sharedHttpImage, "HTTP Image (SHARED)"),
                    new ListElement(sharedStreamImage, "Stream Image (SHARED)"),
                    new ListElement(sharedResourceImage, "Resource Image (SHARED)")});
            addItemListener(this);
        }
        
        public void itemStateChanged(ItemEvent e) {
            if (e.getStateChange() == ItemEvent.SELECTED) {
                TestForEcho.getApplicationInstance().getLogger().log("Setting image: image=\"" 
                        + ((ListElement) getSelectedItem()).getObject() + "\"");
                setImage((ImageReference) ((ListElement) getSelectedItem()).getObject());
            }
        }

        public abstract void setImage(ImageReference newValue);
    }
    
    private class BackgroundRepeatSelectField extends SelectField
    implements ItemListener {
    
        public BackgroundRepeatSelectField() {
            super(new Object[] {
                    new ListElement(new Integer(BackgroundImageProperties.REPEAT), "Repeat"),
                    new ListElement(new Integer(BackgroundImageProperties.REPEAT_HORIZONTAL), "Horizontal Repeat"),
                    new ListElement(new Integer(BackgroundImageProperties.REPEAT_VERTICAL), "Vertical Repeat"),
                    new ListElement(new Integer(BackgroundImageProperties.NO_REPEAT), "No Repeat")});
            addItemListener(this);
        }

        public void itemStateChanged(ItemEvent e) {
            if (e.getStateChange() == ItemEvent.SELECTED) {
                bgProperties.setRepeat(((Integer) ((ListElement) getSelectedItem()).getObject()).intValue());
            }
        }
    }
    
    private class BackgroundAttachmentSelectField extends SelectField
    implements ItemListener {
    
        public BackgroundAttachmentSelectField() {
            super(new Object[] {
                    new ListElement(new Integer(BackgroundImageProperties.ATTACHMENT_FIXED), "Fixed"),
                    new ListElement(new Integer(BackgroundImageProperties.ATTACHMENT_SCROLL), "Scroll")});
            addItemListener(this);
        }

        public void itemStateChanged(ItemEvent e) {
            if (e.getStateChange() == ItemEvent.SELECTED) {
                bgProperties.setAttachment(((Integer) ((ListElement) getSelectedItem()).getObject()).intValue());
            }
        }
    }
    
    private class PositionSelectField extends SelectField
    implements ItemListener {
    
        boolean vertical;
    
        public PositionSelectField(boolean vertical) {
            super(new Object[] {
                    new ListElement(new Integer(0), "0"),
                    new ListElement(new Integer(50), "50"),
                    new ListElement(new Integer(100), "100"),
                    new ListElement(new Integer(115), "115"),
                    new ListElement(new Integer(-15), "-15")});
            this.vertical = vertical;
            addItemListener(this);
        }

        public void itemStateChanged(ItemEvent e) {
            if (e.getStateChange() == ItemEvent.SELECTED) {
                if (vertical) {
                    bgProperties.setVerticalPosition(((Integer) ((ListElement) getSelectedItem()).getObject()).intValue());
                } else {
                    bgProperties.setHorizontalPosition(((Integer) ((ListElement) getSelectedItem()).getObject()).intValue());
                }
            }
        }
    }
    
    private class PositionUnitsSelectField extends SelectField
    implements ItemListener {
    
        boolean vertical;
    
        public PositionUnitsSelectField(boolean vertical) {
            super(new Object[] {
                    new ListElement(new Integer(Extent.PERCENT), "Percent"),
                    new ListElement(new Integer(Extent.PX), "Pixels"),
                    new ListElement(new Integer(Extent.CM), "Centimeters"),
                    new ListElement(new Integer(Extent.MM), "Millimteres"),
                    new ListElement(new Integer(Extent.PC), "Picas"),
                    new ListElement(new Integer(Extent.PT), "Points"),
                    new ListElement(new Integer(Extent.IN), "Inches"),
                    new ListElement(new Integer(Extent.EM), "Em"),
                    new ListElement(new Integer(Extent.EX), "Ex")
            });
            this.vertical = vertical;
            addItemListener(this);
        }

        public void itemStateChanged(ItemEvent e) {
            if (e.getStateChange() == ItemEvent.SELECTED) {
                if (vertical) {
                    bgProperties.setVerticalPositionUnits(((Integer) ((ListElement) getSelectedItem()).getObject()).intValue());
                } else {
                    bgProperties.setHorizontalPositionUnits(((Integer) ((ListElement) getSelectedItem()).getObject()).intValue());
                }
            }
        }
    }
    
    private class VisibilityState extends CheckBox 
    implements ItemListener {

        private Component managedComponent = null;

        public VisibilityState(Component managedComponent) {
            super((String) null, managedComponent.isVisible());
            this.managedComponent = managedComponent;
            addItemListener(this);
        }
        
        public void itemStateChanged(ItemEvent e) {
            managedComponent.setVisible(e.getStateChange() == ItemEvent.SELECTED);
        }
    }
    
    private ImageReference httpImage = new HttpImageReference("images/ImageTestHttpImage.png", 100, 100);
    private ImageReference awtImage = new AwtImageReference(createBufferedImage());
    private ImageReference streamImage = new TestStreamImage();
    private ImageReference resourceImage = new ResourceImageReference("/nextapp/testforecho/ImageTestResourceImage.png");
    
    private Button testButton = new Button();
    private Label testLabel = new Label();
    
    private VisibilityState testButtonVisible = new VisibilityState(testButton);
    private VisibilityState testLabelVisible = new VisibilityState(testLabel);
    
    private SelectField labelImageSelect = new ImageTypeSelectField() {
        public void setImage(ImageReference newValue) {
            testLabel.setIcon(newValue);
        }
    };

    private SelectField buttonImageSelect = new ImageTypeSelectField() {
        public void setImage(ImageReference newValue) {
            testButton.setIcon(newValue);
        }
    };

    private SelectField contentPaneImageSelect = new ImageTypeSelectField() {
        public void setImage(ImageReference newValue) {
            bgProperties.setImage(newValue);
        }
    };
    
    private BackgroundImageProperties bgProperties = new BackgroundImageProperties(null);

    public ImageTest() {
        setBackgroundImageProperties(bgProperties);
        
        add(new HelpPanel("Image Test",
                "This test evaluates various image capabilities.  Manipulate the various options below and then click the"
                + "\"Action Button\" near the bottom of the leftmost pane to apply your changes."));
        add(Filler.createVerticalStrut(20));
        
        TestPanel testPanel;
        
        testPanel = new TestPanel();
        testPanel.addHeader("Label Output");
        testPanel.add("Label", testLabel);
        testPanel.addHeader("Label Settings");
        testPanel.add("Image Source", labelImageSelect);
        testPanel.add("Visible", testLabelVisible);
        add(testPanel);
        
        add(Filler.createVerticalStrut(10));
        
        testPanel = new TestPanel();
        testPanel.addHeader("Button Output");
        testPanel.add("Button", testButton);
        testPanel.addHeader("Button Settings");
        testPanel.add("Image Source", buttonImageSelect);
        testPanel.add("Visible", testButtonVisible);
        add(testPanel);

        add(Filler.createVerticalStrut(10));
        
        testPanel = new TestPanel();
        testPanel.addHeader("ContentPane Settings");
        testPanel.add("Background Image Source", contentPaneImageSelect);
        testPanel.add("Background Image Repeat", new BackgroundRepeatSelectField());
        testPanel.add("Background Image Attachment", new BackgroundAttachmentSelectField());
        testPanel.add("Horizontal Background Position", new PositionSelectField(false));
        testPanel.add("Horizontal Background Position Units", new PositionUnitsSelectField(false));
        testPanel.add("Vertical Background Position", new PositionSelectField(true));
        testPanel.add("Vertical Background Position Units", new PositionUnitsSelectField(true));
        
        add(testPanel);
    }
}
