/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.testforecho;

import java.util.Locale;
import java.util.ResourceBundle;

import nextapp.echo.Button;
import nextapp.echo.ContentPane;
import nextapp.echo.Color;
import nextapp.echo.Filler;
import nextapp.echo.Insets;
import nextapp.echo.Label;
import nextapp.echo.Panel;
import nextapp.echo.SelectField;
import nextapp.echo.event.ActionEvent;
import nextapp.echo.event.ActionListener;
import nextapp.echoservlet.ServerContext;

public class IzationTest extends ContentPane 
implements ActionListener {

    private static final Insets PANEL_INSETS = new Insets(20, 21, 22, 23);
    
    private class IzationPanel extends Panel 
    implements ActionListener {
        private SelectField selectField = new SelectField(new Object[]{"default", Locale.ENGLISH, Locale.FRENCH, Locale.GERMAN});
        private Label label = new Label();
        
        public IzationPanel(IzationPanel parent, Color color) {
            super();
            
            this.setInsets(PANEL_INSETS);
            this.setBackground(color);
            
            this.add(label);
            
            this.add(selectField);
            
            Button updateButton = new Button("Update");
            updateButton.addActionListener(this);
            this.add(updateButton);
            
            if (parent != null) {
                parent.add(this);
            }
            update();
        }

        public void actionPerformed(ActionEvent e) {
            if (selectField.getSelectedItem() instanceof Locale) {
                this.setLocale((Locale) selectField.getSelectedItem());
            } else {
                this.setLocale(null);
            }
        
            update();
        }

        public void update() {
            Locale locale = this.getLocale();
            ResourceBundle res;
            
            if (locale == null) {
                res = ResourceBundle.getBundle("nextapp.testforecho.Messages");    
            } else {
                res = ResourceBundle.getBundle("nextapp.testforecho.Messages", locale); 
            }
            label.setText(res.getString("helloWorld"));
        }
    }

    private SelectField characterEncodingSelect;
    
    public IzationTest() {
        add(new HelpPanel("I18N/L10N Test",
                "This test evaluates internationalization and localization capabilities.  Changing the application's character "
                + "encoding will result in an application restart (Try using the Window test to open a few windows and then "
                + "changing the character encoding)."));
        add(Filler.createVerticalStrut(20));
        
        TestPanel testPanel = new TestPanel();
        
        Label localeLabel = new Label();
        if (TestForEcho.getApplicationInstance().getLocale() == null) {
            localeLabel.setText("no locale");
        } else {
            localeLabel.setText(TestForEcho.getApplicationInstance().getLocale().toString());
        }
        testPanel.add("Application Locale", localeLabel);
        
        characterEncodingSelect = new SelectField(
                new String[]{"utf-8", "iso-8859-1", "iso-8859-2",  "iso-8859-3",  "iso-8859-4", "iso-8859-5"});
        characterEncodingSelect.addActionListener(this);
        testPanel.add("Character Encoding", characterEncodingSelect);
        
        add(testPanel);
        
        add(Filler.createVerticalStrut(20));
        
        IzationPanel alpha = new IzationPanel(null, Color.YELLOW);
        IzationPanel bravo = new IzationPanel(alpha, Color.GREEN);
        IzationPanel charlie = new IzationPanel(bravo, Color.CYAN);
        new IzationPanel(charlie, Color.BLUE);
        
        add(alpha);
    }
    
    public void actionPerformed(ActionEvent e) {
        if (e.getSource() == characterEncodingSelect) {
            ServerContext serverContext 
                    = (ServerContext) TestForEcho.getApplicationInstance().getAttribute(ServerContext.ATTRIBUTE_NAME);
            serverContext.setCharacterEncoding((String) characterEncodingSelect.getSelectedItem());
        }
    }
}
