/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.testforecho;

import nextapp.echo.Color;
import nextapp.echo.ContentPane;
import nextapp.echo.Filler;
import nextapp.echo.Font;
import nextapp.echo.ImageReference;
import nextapp.echo.Label;
import nextapp.echo.ResourceImageReference;

public class LabelTest extends ContentPane {

    private static final ImageReference TEST_IMAGE 
            = new ResourceImageReference("/nextapp/testforecho/ImageTestResourceImage.png");

    public LabelTest() {
        add(new HelpPanel("Label Test",
                "This test evaluates functionality of the Label component."));
        add(Filler.createVerticalStrut(20));
        
        TestPanel testPanel = new TestPanel();
        add(testPanel);
        
        Label label;
        
        testPanel.addHeader("Text only");
        
        label = new Label("Text Label");
        testPanel.add("Plain Label", label);
        
        label = new Label("Text Label");
        label.setForeground(Color.RED);
        testPanel.add("Red Foreground", label);
        
        label = new Label("Text Label");
        label.setBackground(Color.RED);
        testPanel.add("Red Background", label);
        
        label = new Label("Text Label");
        label.setFont(new Font(new String[]{"Verdana","Arial"}, Font.BOLD, 20));
        testPanel.add("Font", label);
        
        testPanel.addHeader("With images");
        
        label = new Label("Text Label", TEST_IMAGE);
        testPanel.add("Plain Label", label);
        
        label = new Label("Text Label", TEST_IMAGE);
        label.setForeground(Color.RED);
        testPanel.add("Red Foreground", label);
        
        label = new Label("Text Label", TEST_IMAGE);
        label.setBackground(Color.RED);
        testPanel.add("Red Background", label);
        
        label = new Label("Text Label", TEST_IMAGE);
        label.setFont(new Font(new String[]{"Verdana","Arial"}, Font.BOLD, 20));
        testPanel.add("Font", label);
    }
}
