/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.testforecho;

import nextapp.echo.Button;
import nextapp.echo.ContentPane;
import nextapp.echo.DefaultListModel;
import nextapp.echo.Filler;
import nextapp.echo.Label;
import nextapp.echo.ListBox;
import nextapp.echo.ListSelectionModel;
import nextapp.echo.Panel;
import nextapp.echo.TextField;
import nextapp.echo.event.ActionEvent;
import nextapp.echo.event.ActionListener;
import nextapp.echo.event.ListDataEvent;
import nextapp.echo.event.ListDataListener;
import nextapp.echo.event.ListSelectionEvent;
import nextapp.echo.event.ListSelectionListener;

public class ListBoxTest extends ContentPane 
implements ActionListener, ListDataListener, ListSelectionListener {

    private static String[] numbers = new String[]{"one", "two", "three", "four", "five", "six", "seven", "eight", "nine", "ten"};
    private DefaultListModel defaultModel; 
    private TextField indexField;
    private TextField valueField;
    private Button addToModelButton;
    private Button removeFromModelButton;

    public ListBoxTest() {
        add(new HelpPanel("List Box Test", "This test evaluates the functionality of the ListBox component."));
        add(Filler.createVerticalStrut(20));

        TestPanel testPanel = new TestPanel();
        ListBox listBox;
        
        testPanel.addHeader("Default Model (Array of Strings Constructor) Multiple-select");
        
        listBox = new ListBox(numbers);
        testPanel.add("Generic", listBox);
        
        listBox = new ListBox(numbers);
        listBox.setWidthUnits(ListBox.PERCENT_UNITS);
        listBox.setWidth(50);
        testPanel.add("50% width", listBox);

        listBox = new ListBox(numbers);
        listBox.setWidth(300);
        testPanel.add("300 pixel width", listBox);

        listBox = new ListBox(numbers);
        listBox.getSelectionModel().addListSelectionListener(this); 
        testPanel.add("w/ ListSelectionListener", listBox);
        
        listBox = new ListBox(numbers);
        listBox.setToolTipText("Tool Tip Text");
        listBox.getSelectionModel().addListSelectionListener(this); 
        testPanel.add("w/ ListSelectionListener, Tool Tip", listBox);
        
        listBox = new ListBox(numbers);
        listBox.setCellRenderer(new ColorfulListCellRenderer());
        testPanel.add("w/ ListCellRenderer", listBox);

        listBox = new ListBox(numbers);
        listBox.setEnabled(false);
        testPanel.add("Disabled", listBox);
        
        testPanel.addHeader("Default Model (Array of Strings Constructor) Single-select");
        
        listBox = new ListBox(numbers);
        listBox.getSelectionModel().setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
        testPanel.add("Generic", listBox);
        
        listBox = new ListBox(numbers);
        listBox.getSelectionModel().setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
        listBox.getSelectionModel().addListSelectionListener(this); 
        testPanel.add("w/ ListSelectionListener", listBox);
        
        testPanel.addHeader("Default Model (Mutable)");

        defaultModel = new DefaultListModel(new String[]{"one", "two", "three"});
        defaultModel.addListDataListener(this);
        listBox = new ListBox(defaultModel);
        testPanel.add("List Box", listBox);
        
        Panel panel = new Panel();
        
        panel.add(new Label("Value:"));
        valueField = new TextField("x");
        panel.add(valueField);
        
        panel.add(Filler.createHorizontalStrut(25));
        
        panel.add(new Label("Index:"));
        
        indexField = new TextField("0");
        panel.add(indexField);

        panel.add(Filler.createHorizontalStrut(25));

        addToModelButton = new Button("[Add]");
        addToModelButton.addActionListener(this);
        panel.add(addToModelButton);
        
        removeFromModelButton = new Button("[Remove]");
        removeFromModelButton.addActionListener(this);
        panel.add(removeFromModelButton);
        
        testPanel.add("Model Controls", panel);
        
        add(testPanel);
    }
    
    public void actionPerformed(ActionEvent e) {
        TestForEcho app = TestForEcho.getApplicationInstance();
        int index;
        try {
            index = Integer.parseInt(indexField.getText());
        } catch (NumberFormatException ex) {
            app.getLogger().log("Invalid entry: " + indexField.getText());
            return;
        }
        
        if (e.getSource() == removeFromModelButton) {
            Object o = defaultModel.get(index);
            if (o == null) {
                app.getLogger().log("Returned null");
            } else {
                defaultModel.remove(o);
                app.getLogger().log("Removed: " + o);
            }
        } else if (e.getSource() == addToModelButton) {
            try {
                defaultModel.add(index, valueField.getText());
            } catch (IndexOutOfBoundsException ex) {
                app.getLogger().log("Execption attempting to add element: " + ex.toString());
            }
        }
    }
    
    public void contentsChanged(ListDataEvent e) {
        TestForEcho app = TestForEcho.getApplicationInstance();
        app.getLogger().log("ListDataListener (contents changed): source=" + e.getSource() + ", type=" + e.getType() 
                + ", index0=" + e.getIndex0() + ", index1=" + e.getIndex1());
    }

    public void intervalAdded(ListDataEvent e) {
        TestForEcho app = TestForEcho.getApplicationInstance();
        app.getLogger().log("ListDataListener (interval added): source=" + e.getSource() + ", type=" + e.getType() 
                + ", index0=" + e.getIndex0() + ", index1=" + e.getIndex1());
    }

    public void intervalRemoved(ListDataEvent e) {
        TestForEcho app = TestForEcho.getApplicationInstance();
        app.getLogger().log("ListDataListener (interval removed): source=" + e.getSource() + ", type=" + e.getType() 
                + ", index0=" + e.getIndex0() + ", index1=" + e.getIndex1());
    }
    
    public void valueChanged(ListSelectionEvent e) {
        TestForEcho app = TestForEcho.getApplicationInstance();
        app.getLogger().log("ListSelectionListener: source=" + e.getSource());
    }
}
