/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.testforecho;

import nextapp.echo.Color;
import nextapp.echo.ContentPane;
import nextapp.echo.Font;
import nextapp.echo.Label;

public class Logger extends ContentPane {

    private static final Color LOG_PANE_BG = Color.BLACK;
    private static final Color LOG_PANE_FG = new Color(0x00ff3f);
    private static final Font LOG_PANE_FONT = new Font(Font.MONOSPACE, Font.PLAIN, 11);

    private class Data extends Label {
        private StringBuffer log = new StringBuffer();
        private int eventCount = 0;
    
        public void clear() {
            log.delete(0, log.length());
            eventCount = 0;
            
            this.firePropertyChange(TEXT_CHANGED_PROPERTY, null, null);
        }

        public String getText() {
            return log.toString();
        }

        public void log(String event) {
            if (log.length() > 0) {
                log.insert(0, "\n");
            }
        
            log.insert(0, event);
            log.insert(0, " ");
            log.insert(0, ++eventCount);
        
            this.firePropertyChange(TEXT_CHANGED_PROPERTY, null, null);
        }
        
    }
    
    private Data data = new Data();

    public Logger() {
        super();
    
        setBackground(LOG_PANE_BG);
        setForeground(LOG_PANE_FG);
        setFont(LOG_PANE_FONT);
        
        add(data);
    }
    
    public void clear() {
        data.clear();
    }
    
    public void log(String message) {
        data.log(message);
    }
}
