/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.testforecho;

import nextapp.echo.Button;
import nextapp.echo.Color;
import nextapp.echo.Container;
import nextapp.echo.ContentPane;
import nextapp.echo.Filler;
import nextapp.echo.Grid;
import nextapp.echo.Label;
import nextapp.echo.SelectField;
import nextapp.echo.TextField;
import nextapp.echo.event.ActionEvent;
import nextapp.echo.event.ActionListener;
import nextapp.echo.event.DocumentEvent;
import nextapp.echo.event.DocumentListener;
import nextapp.echo.text.Document;

public class MenuPane extends ContentPane 
implements ActionListener, DocumentListener {

    private static final Color MENU_PANE_BG = new Color(60, 119, 139);
    private static final Color MENU_OPTION_BG = new Color(30, 59, 79);
    private static final Color MENU_OPTION_FG = Color.WHITE;
    
    private static final String COMMAND_ACTION_BUTTON = "actionButton";
    private static final String COMMAND_TEST_SELECT = "testSelect";
    private static final String COMMAND_CLEAR_LOG = "clearLog";
    private static final String COMMAND_ADJUST_LOG_SIZE = "adjustLogSize";
    
    private class OptionGrid extends Grid {
        public OptionGrid() {
            super();
            setCellMargin(3);
            setBorderSize(3);
        }
        
        public void addOption(String label, String command) {
            Button button = new Button(label);
            button.setActionCommand(command);
            button.addActionListener(TestForEcho.getApplicationInstance().getController());
            Grid.Cell cell = add(0, getSize().getHeight(), button);
            cell.setBackground(MENU_OPTION_BG);
            cell.setForeground(MENU_OPTION_FG);
        }
    }
    
    private TextField controllerDelayField;
    private SelectField testSelect;
    private Container optionGridContainer = new Container();
    
    public MenuPane() {
        super();
        
        setForeground(Color.WHITE);
        setBackground(MENU_PANE_BG);
        
        testSelect = new SelectField(new String[]{"Standard Tests", "Vestigial Tests"});
        testSelect.setActionCommand(COMMAND_TEST_SELECT);
        testSelect.addActionListener(this);
        add(testSelect);
        add(Filler.createVerticalStrut(10));
        
        optionGridContainer = new Container();
        displayStandardTestMenu();
        add(optionGridContainer);
        
        add(Filler.createVerticalStrut(20));
        
        Button actionButton = new Button("Action Button");
        actionButton.setActionCommand(COMMAND_ACTION_BUTTON);
        actionButton.addActionListener(this);
        add(actionButton);
        
        add(Filler.createVerticalStrut(0));

        Button clearLogButton = new Button("Clear Log");
        clearLogButton.setActionCommand(COMMAND_CLEAR_LOG);
        clearLogButton.addActionListener(this);
        add(clearLogButton);

        add(Filler.createVerticalStrut(0));

        Button adjustLogSizeButton = new Button("Adjust Log Size");
        adjustLogSizeButton.setActionCommand(COMMAND_ADJUST_LOG_SIZE);
        adjustLogSizeButton.addActionListener(this);
        add(adjustLogSizeButton);

        add(Filler.createVerticalStrut(20));
                
        controllerDelayField = new TextField("0", 5);
        controllerDelayField.getDocument().addDocumentListener(this);
        add(new Label("ctrlDelay"));
        add(Filler.createVerticalStrut(0));
        add(controllerDelayField);
        add(new Label("ms"));

        add(Filler.createVerticalStrut(10));
    }
    
    public void actionPerformed(ActionEvent e) {
        TestForEcho app = TestForEcho.getApplicationInstance();
        app.doControllerDelay();
        if (COMMAND_TEST_SELECT.equals(e.getActionCommand())) {
            switch (testSelect.getSelectedIndex()) {
            case 0:
                displayStandardTestMenu();
                break;
            case 1:
                displayVestigialTestMenu();
                break;
            }
        } else if (COMMAND_ACTION_BUTTON.equals(e.getActionCommand())) {
            app.getLogger().log("Received ActionEvent from \"Action Button\"");
        } else if (COMMAND_CLEAR_LOG.equals(e.getActionCommand())) {
            app.getLogger().clear();
        } else if (COMMAND_ADJUST_LOG_SIZE.equals(e.getActionCommand())) {
            app.getLogger().setHeight(app.getLogger().getHeight() == 80 ? 250 : 80);
        }
    }
    
    public void displayStandardTestMenu() {
        optionGridContainer.removeAll();
        OptionGrid optionGrid = new OptionGrid();
        optionGrid.addOption("Buttons", Controller.COMMAND_BUTTON_TEST);
        optionGrid.addOption("Client Properties", Controller.COMMAND_CLIENT_PROPERTIES_TEST);
        optionGrid.addOption("Component Hierarchy #1", Controller.COMMAND_COMPONENT_HIERARCHY_TEST_ONE);
        optionGrid.addOption("Cookies", Controller.COMMAND_COOKIE_TEST);
        optionGrid.addOption("CSS Styles", Controller.COMMAND_CSS_TEST);
        optionGrid.addOption("Font", Controller.COMMAND_FONT_TEST);
        optionGrid.addOption("Focus", Controller.COMMAND_FOCUS_TEST);
        optionGrid.addOption("Grids", Controller.COMMAND_GRID_TEST);
        optionGrid.addOption("Http Panes", Controller.COMMAND_HTTP_PANE_TEST);
        optionGrid.addOption("I18N/L10N", Controller.COMMAND_IZATION_TEST);
        optionGrid.addOption("Images", Controller.COMMAND_IMAGE_TEST);
        optionGrid.addOption("Iniitial Parameters", Controller.COMMAND_INITIAL_PARAMETERS_TEST);
        optionGrid.addOption("Labels", Controller.COMMAND_LABEL_TEST);
        optionGrid.addOption("ListBoxes", Controller.COMMAND_LIST_BOX_TEST);
        optionGrid.addOption("Pane Embedding", Controller.COMMAND_PANE_EMBEDDING_TEST);
        optionGrid.addOption("SelectFields", Controller.COMMAND_SELECT_FIELD_TEST);
        optionGrid.addOption("Stacked Panes", Controller.COMMAND_STACKED_PANE_TEST);
        optionGrid.addOption("Styles", Controller.COMMAND_STYLE_TEST);
        optionGrid.addOption("Tab Index", Controller.COMMAND_TAB_INDEX_TEST);
        optionGrid.addOption("Tables", Controller.COMMAND_TABLE_TEST);
        optionGrid.addOption("Termination", Controller.COMMAND_TERMINATION_TEST);
        optionGrid.addOption("Text Components", Controller.COMMAND_TEXT_TEST);
        optionGrid.addOption("Unchecked Exceptions", Controller.COMMAND_UNCHECKED_EXCEPTION_TEST);
        optionGrid.addOption("Windows", Controller.COMMAND_WINDOW_TEST);
        optionGridContainer.add(optionGrid);
    }
    
    public void displayVestigialTestMenu() {
        optionGridContainer.removeAll();
        OptionGrid optionGrid = new OptionGrid();
        optionGrid.addOption("Component Hierarchy #2", Controller.COMMAND_COMPONENT_HIERARCHY_TEST_TWO);
        optionGrid.addOption("Component Removal Anomaly", Controller.COMMAND_COMPONENT_REMOVAL_ANOMALY_TEST);
        optionGrid.addOption("Double Submit", Controller.COMMAND_DOUBLE_SUBMIT_TEST);
        optionGrid.addOption("Event Listener List", Controller.COMMAND_EVENT_LISTENER_LIST_TEST);
        optionGrid.addOption("Pane Replacement", Controller.COMMAND_PANE_REPLACEMENT_TEST);
        optionGrid.addOption("Property Change Madness", Controller.COMMAND_PROPERTY_CHANGE_MADNESS_TEST);
        optionGridContainer.add(optionGrid);
    }

    public void documentUpdate(DocumentEvent e) {
        try {
            if (e.getSource() == controllerDelayField.getDocument()) {
                TestForEcho.getApplicationInstance().setControllerDelay(Integer.parseInt(((Document) e.getSource()).getText()));
            }
        } catch (NumberFormatException ex) { }
    }
}        
