/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.testforecho;

import nextapp.echo.Button;
import nextapp.echo.Color;
import nextapp.echo.ContainerPane;
import nextapp.echo.ContentPane;
import nextapp.echo.Extent;
import nextapp.echo.Filler;
import nextapp.echo.Label;
import nextapp.echo.event.ActionEvent;
import nextapp.echo.event.ActionListener;

public class PaneEmbeddingTest extends ContentPane 
implements ActionListener {

    private ContainerPane alpha, bravo;
    private ContentPane xray, yankee, zulu;
    
    public PaneEmbeddingTest() {
        super();
        alpha = new ContainerPane();
        bravo = new ContainerPane(ContainerPane.ORIENTATION_VERTICAL);
        xray = new ContentPane();
        xray.setBackground(Color.GREEN);
        yankee = new ContentPane();
        yankee.setBackground(Color.CYAN);
        
        zulu = new ContentPane();
        zulu.setBackground(Color.BLUE);
        
        alpha.setPreferredWidthExtent(new Extent(640, Extent.PX));
        alpha.setPreferredHeightExtent(new Extent(480, Extent.PX));
        
        alpha.add(bravo);
        alpha.add(xray);
        bravo.add(yankee);
        bravo.add(zulu);
        
        xray.add(new Label("xray"));

        yankee.add(new Label("yankee"));
        yankee.add(Filler.createVerticalStrut(5));
        Button yankeeTestButton = new Button("Test");
        yankeeTestButton.setActionCommand("Yankee");
        yankeeTestButton.addActionListener(this);
        yankee.add(yankeeTestButton);
        
        zulu.add(new Label("zulu"));
        
        add(new Label("Pane Embedding / IFRAME test"));
        add(Filler.createVerticalStrut(20));
        add(alpha);
        
        add(Filler.createVerticalStrut(20));
        
        Button button;
        
        button= new Button("Add to Yankee");
        button.setActionCommand("yankeeAdd");
        button.addActionListener(this);
        add(button);
        
        add(Filler.createVerticalStrut(0));

        button = new Button("Change Yankee Background");
        button.setActionCommand("yankeeBackground");
        button.addActionListener(this);
        add(button);

        add(Filler.createVerticalStrut(0));
        
        button = new Button("Yankee Scroll Always");
        button.setActionCommand("yankeeScrollAlways");
        button.addActionListener(this);
        add(button);
        
        button = new Button("Yankee Scroll Never");
        button.setActionCommand("yankeeScrollNever");
        button.addActionListener(this);
        add(button);
        
        button = new Button("Yankee Scroll Auto");
        button.setActionCommand("yankeeScrollAuto");
        button.addActionListener(this);
        add(button);
    }
    
    public void actionPerformed(ActionEvent e) {
        if ("yankeeAdd".equals(e.getActionCommand())) {
            yankee.add(Filler.createVerticalStrut(20));
            yankee.add(new Label("X"));
        } else if ("yankeeBackground".equals(e.getActionCommand())) {
            yankee.setBackground(new Color((int) (Math.random() * 256 * 256 * 256)));
        } else if ("yankeeScrollNever".equals(e.getActionCommand())) {
            yankee.setScrollBarPolicy(ContentPane.SCROLL_BAR_NEVER);
        } else if ("yankeeScrollAlways".equals(e.getActionCommand())) {
            yankee.setScrollBarPolicy(ContentPane.SCROLL_BAR_ALWAYS);
        } else if ("yankeeScrollAuto".equals(e.getActionCommand())) {
            yankee.setScrollBarPolicy(ContentPane.SCROLL_BAR_AUTO);
        } else {
            TestForEcho app = (TestForEcho) TestForEcho.getEchoInstance();
            app.getLogger().log(e.getActionCommand());
        }
    }
}
