/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.testforecho;

import nextapp.echo.Button;
import nextapp.echo.ContainerPane;
import nextapp.echo.ContentPane;
import nextapp.echo.Filler;
import nextapp.echo.Label;
import nextapp.echo.Window;
import nextapp.echo.event.ActionListener;
import nextapp.echo.event.ActionEvent;

public class PaneReplacementTest extends ContainerPane 
implements ActionListener {

    private Button clearButton;
    private Button containerButton;
    private Button nonScrollingContentButton;
    private Button scrollingContentButton;
    private Button changeContentPaneScrollingButton;
    private Button newWindowButton;
    private ContainerPane container;
    private ContentPane lastContentPane;

    public PaneReplacementTest() {
        super(ORIENTATION_VERTICAL);
        ContentPane controlPane = new ContentPane();
        
        controlPane.add(new HelpPanel("Pane Replacement Test",
                "This test was created to ensure a specific problem in Echo has been corrected.  In previous versions, changing "
                + "the content of a ContainerPane which only had one item would cause odd behavior with scrollbars."));
        controlPane.add(Filler.createVerticalStrut(20));
        
        newWindowButton = new Button("New Window");
        newWindowButton.addActionListener(this);
        controlPane.add(newWindowButton);
        
        controlPane.add(Filler.createHorizontalStrut(25));
        
        clearButton = new Button("Clear");
        clearButton.addActionListener(this);
        controlPane.add(clearButton);
        
        controlPane.add(Filler.createHorizontalStrut(25));
        
        containerButton = new Button("Container");
        containerButton.addActionListener(this);
        controlPane.add(containerButton);
        
        controlPane.add(Filler.createHorizontalStrut(25));
        
        nonScrollingContentButton = new Button("Non-Scrolling Content Pane");
        nonScrollingContentButton.addActionListener(this);
        controlPane.add(nonScrollingContentButton);
        
        controlPane.add(Filler.createHorizontalStrut(25));
        
        scrollingContentButton = new Button("Scrolling Content Pane");
        scrollingContentButton.addActionListener(this);
        controlPane.add(scrollingContentButton);
        
        controlPane.add(Filler.createHorizontalStrut(25));
        
        changeContentPaneScrollingButton = new Button("Change Content Pane Scrolling");
        changeContentPaneScrollingButton.addActionListener(this);
        controlPane.add(changeContentPaneScrollingButton);
        
        controlPane.setHeight(180);
        
        add(controlPane);
        
        container = new ContainerPane();
        add(container);
    }
    
    public void actionPerformed(ActionEvent e) {
        if (e.getSource() == clearButton) {
            container.removeAll();
        } else if (e.getSource() == containerButton) {
            container.removeAll();
            ContainerPane pane = new ContainerPane();
            pane.add(createContentPane());
            pane.add(createContentPane());
            container.add(pane);
        } else if (e.getSource() == nonScrollingContentButton) {
            container.removeAll();
            ContentPane pane = createContentPane();
            pane.setScrollBarPolicy(ContentPane.SCROLL_BAR_NEVER);
            container.add(pane);
        } else if (e.getSource() == scrollingContentButton) {
            container.removeAll();
            ContentPane pane = createContentPane();
            pane.setScrollBarPolicy(ContentPane.SCROLL_BAR_AUTO);
            container.add(pane);
        } else if (e.getSource() == changeContentPaneScrollingButton) {
            if (lastContentPane != null) {
                if (lastContentPane.getScrollBarPolicy() == ContentPane.SCROLL_BAR_NEVER) {
                    lastContentPane.setScrollBarPolicy(ContentPane.SCROLL_BAR_AUTO);
                } else {
                    lastContentPane.setScrollBarPolicy(ContentPane.SCROLL_BAR_NEVER);
                }
            }
        } else if (e.getSource() == newWindowButton) {
            Window w = new Window("Pane Replacement Test");
            w.setContent(new PaneReplacementTest());
            w.setDefaultCloseOperation(Window.DISPOSE_ON_CLOSE);
            w.setWidth(600);
            w.setHeight(400);
            TestForEcho.getApplicationInstance().addWindow(w);
        }
    }

    private ContentPane createContentPane() {
        ContentPane pane = new ContentPane();
        for (int index = 0; index < 30; ++index) {
            pane.add(new Label("Scroll Test"));
            pane.add(Filler.createVerticalStrut(20));
        }
        lastContentPane = pane;
        return pane;
    }
}
