/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.testforecho;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;

import nextapp.echo.Button;
import nextapp.echo.Color;
import nextapp.echo.Component;
import nextapp.echo.ContentPane;
import nextapp.echo.Container;
import nextapp.echo.Filler;
import nextapp.echo.Grid;
import nextapp.echo.Label;
import nextapp.echo.event.ActionEvent;
import nextapp.echo.event.ActionListener;

public class PropertyChangeMadnessTest extends ContentPane 
implements ActionListener, PropertyChangeListener {

    private Button initButton;
    private Label label1, label2, label3, label4, label5, label6;
    private Grid visibilityTestGrid;
    private Container testContainer;
    
    public PropertyChangeMadnessTest() {
        add(new HelpPanel("Property Change Madness",
                "The purpose of this test is to investigate component framework - application container behavior"
                + " when attempting to deliberately cause confusion in registration"));
        add(Filler.createVerticalStrut(20));
        
        initButton = new Button("do test");
        initButton.addActionListener(this);
        add(initButton);
        
        add(Filler.createVerticalStrut(20));
        
        label1 = new Label("test label #1");
        label2 = new Label("test label #2");
        label3 = new Label("test label #3");
        label4 = new Label("test label #4");
        label4.setVisible(false);

        testContainer = new Container();
        testContainer.addPropertyChangeListener(this);
        add(testContainer);
        
        testContainer.add(label2);
        testContainer.add(label4);
        
        add(Filler.createVerticalStrut(20));
        visibilityTestGrid = new Grid();
        visibilityTestGrid.setBorderColor(Color.BLACK);
        visibilityTestGrid.setBorderSize(1);
        visibilityTestGrid.setCellMargin(4);
        label5 = new Label("test label #5");
        label5.addPropertyChangeListener(this);
        visibilityTestGrid.add(0, 0, label5);
        label6 = new Label("test label #6");
        label6.addPropertyChangeListener(this);
        visibilityTestGrid.add(1, 0, label6);
        add(visibilityTestGrid);
    }
    
    public void actionPerformed(ActionEvent e) {
        testContainer.add(label1);
        testContainer.remove(label2);
        testContainer.add(label3);
        testContainer.remove(label4);
        testContainer.removePropertyChangeListener(this);
        testContainer.add(label2);
        testContainer.add(label4);
        label3.setVisible(true);
        
        label5.setVisible(false);
        
        TestForEcho.getApplicationInstance().getLogger().log("Test successful.");
    }
    
    public void propertyChange(PropertyChangeEvent e) {
        if (e.getSource() == testContainer) {
            TestForEcho app = TestForEcho.getApplicationInstance();
            if (e.getPropertyName().equals(Component.CHILDREN_CHANGED_PROPERTY)) {
                if (label1.equals(e.getNewValue())) {
                    app.getLogger().log("add-removing label 1");
                    testContainer.remove(label1);
                } else if (label2.equals(e.getOldValue())) {
                    app.getLogger().log("remove-adding label 2");
                    testContainer.add(label2);
                } else if (label3.equals(e.getNewValue())) {
                    app.getLogger().log("add-hiding label 3");
                    label3.setVisible(false);
                } else if (label4.equals(e.getOldValue())) {
                    app.getLogger().log("remove-showing label 4");
                    label4.setVisible(true);
                }
            }
        } else if (e.getSource() == label5 || e.getSource() == label6) {
            Component c = (Component) e.getSource();
            if (e.getPropertyName().equals(Component.VISIBLE_CHANGED_PROPERTY)) {
                visibilityTestGrid.setVisible(c.isVisible());
            }
        }
    }
}
