/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.testforecho;

import nextapp.echo.AbstractSelectFieldModel;
import nextapp.echo.ContentPane;
import nextapp.echo.Filler;
import nextapp.echo.SelectField;

import nextapp.echo.event.ActionEvent;
import nextapp.echo.event.ActionListener;
import nextapp.echo.event.ItemEvent;
import nextapp.echo.event.ItemListener;

public class SelectFieldTest extends ContentPane 
implements ActionListener, ItemListener {

    private static String[] numbers = new String[]{"one", "two", "three", "four", "five", "six", "seven", "eight", "nine", "ten"};
    
    private class TestModel extends AbstractSelectFieldModel {
    
        public Object get(int index) {
            return Integer.toString(index, 20);
        }
    
        public int size() {
            return 20;
        }
    }
    
    public SelectFieldTest() {
        add(new HelpPanel("Select Field Test", "This test evaluates the functionality of the SelectField component."));
        add(Filler.createVerticalStrut(20));

        TestPanel testPanel = new TestPanel();
        SelectField selectField;
        
        testPanel.addHeader("Default Model");
        
        selectField = new SelectField(numbers);
        testPanel.add("Generic", selectField);

        selectField = new SelectField(numbers);
        selectField.setWidthUnits(SelectField.PERCENT_UNITS);
        selectField.setWidth(50);
        testPanel.add("50% width", selectField);

        selectField = new SelectField(numbers);
        selectField.setWidth(300);
        testPanel.add("300 pixel width", selectField);

        selectField = new SelectField(numbers);
        selectField.addItemListener(this);
        testPanel.add("w/ Item Listener", selectField);

        selectField = new SelectField(numbers);
        selectField.addActionListener(this);
        testPanel.add("w/ Action Listener", selectField);

        selectField = new SelectField(numbers);
        selectField.addActionListener(this);
        selectField.addItemListener(this);
        testPanel.add("w/ Item&Action Listeners", selectField);
        
        selectField = new SelectField(numbers);
        selectField.addActionListener(this);
        selectField.addItemListener(this);
        selectField.setToolTipText("Tool Tip Text");
        testPanel.add("w/ Item&Action Listeners, Tool Tip", selectField);

        selectField = new SelectField(numbers);
        selectField.setCellRenderer(new ColorfulListCellRenderer());
        testPanel.add("w/ ListCellRenderer", selectField);
       
        selectField = new SelectField(numbers);
        selectField.setEnabled(false);
        testPanel.add("Disabled", selectField);

        testPanel.addHeader("Custom Model");
        
        selectField = new SelectField(new TestModel());
        testPanel.add("Generic", selectField);

        selectField = new SelectField(new TestModel());
        selectField.addItemListener(this);
        testPanel.add("w/ Item Listener", selectField);

        selectField = new SelectField(new TestModel());
        selectField.addActionListener(this);
        testPanel.add("w/ Action Listener", selectField);

        selectField = new SelectField(new TestModel());
        selectField.addActionListener(this);
        selectField.addItemListener(this);
        testPanel.add("w/ Item&Action Listeners", selectField);
        
        TestModel sharedModel = new TestModel();
        
        testPanel.addHeader("Shared Custom Model");
        
        selectField = new SelectField(sharedModel);
        testPanel.add("Generic", selectField);

        selectField = new SelectField(sharedModel);
        selectField.addItemListener(this);
        testPanel.add("w/ Item Listener", selectField);

        selectField = new SelectField(sharedModel);
        selectField.addActionListener(this);
        testPanel.add("w/ Action Listener", selectField);

        selectField = new SelectField(sharedModel);
        selectField.addActionListener(this);
        selectField.addItemListener(this);
        testPanel.add("w/ Item&Action Listeners", selectField);

        add(testPanel);
    }
    
    public void actionPerformed(ActionEvent e) {
        TestForEcho app = TestForEcho.getApplicationInstance();
        app.getLogger().log("Received ActionEvent: source=" + e.getSource() + ", command=" + e.getActionCommand());
    }
    
    public void itemStateChanged(ItemEvent e) {
        TestForEcho app = TestForEcho.getApplicationInstance();
        app.getLogger().log("Received ItemEvent: source=" + e.getSource() + ", item=" + e.getItem() 
                + ", stateChange=" + e.getStateChange());
    }
}
