/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.testforecho;

import nextapp.echo.Button;
import nextapp.echo.Color;
import nextapp.echo.ContainerPane;
import nextapp.echo.ContentPane;
import nextapp.echo.Filler;
import nextapp.echo.Label;
import nextapp.echo.SelectField;
import nextapp.echo.TextField;
import nextapp.echo.StackedPane;
import nextapp.echo.event.ActionEvent;
import nextapp.echo.event.ActionListener;

public class StackedPaneTest extends ContainerPane {

    private static final String GREEN_CONTENT_PANE = "Green Content Pane";
    private static final String RED_BLUE_CONTAINER_PANE = "Red/Blue Content Pane";

    private class GreenContentPane extends ContentPane {
    
        public GreenContentPane() {
            super();
            this.setBackground(new Color(0x007f00));
            this.setForeground(Color.WHITE);
            this.add(new Label("Counter=" + counter++));
            this.add(new Label("Green Content Pane"));
            this.add(new TextField("Modify me"));
        }
    }
    
    private class RedBlueContainerPane extends ContainerPane {

        public RedBlueContainerPane() {
            super();
            this.setOrientation(ORIENTATION_HORIZONTAL);
            ContentPane redPane = new ContentPane();
            redPane.setBackground(new Color(0x7f0000));
            redPane.setForeground(Color.WHITE);
            redPane.add(new Label("Counter=" + counter++));
            redPane.add(new TextField("Modify me"));
            this.add(redPane);
            ContentPane bluePane = new ContentPane();
            bluePane.setBackground(new Color(0x00007f));
            bluePane.setForeground(Color.WHITE);
            bluePane.add(new TextField("Modify me"));
            this.add(bluePane);
        }
    }

    private class ControlPane extends ContentPane 
    implements ActionListener {
    
        private Button openButton, closeButton;
        private SelectField paneSelect;
        private Label sizeLabel;
    
        public ControlPane() {
            this.add(new HelpPanel("Stacked Pane Test", "This test evaluates the functionality of the StackedPane component."));
            this.add(Filler.createVerticalStrut(20));

            paneSelect = new SelectField(new String[]{GREEN_CONTENT_PANE, RED_BLUE_CONTAINER_PANE});
            this.add(paneSelect);
            openButton = new Button("Open Pane");
            openButton.addActionListener(this);
            this.add(openButton);
            closeButton = new Button("Close Pane");
            closeButton.addActionListener(this);
            this.add(closeButton);
            sizeLabel = new SizeLabel();
            this.add(sizeLabel);
        }
        
        public void actionPerformed(ActionEvent e) {
            if (e.getSource() == openButton) {
                if (GREEN_CONTENT_PANE.equals(paneSelect.getSelectedItem())) {
                    stackedPane.open(new GreenContentPane());
                } else if (RED_BLUE_CONTAINER_PANE.equals(paneSelect.getSelectedItem())) {
                    stackedPane.open(new RedBlueContainerPane());
                }
            } else if (e.getSource() == closeButton) {
                try {
                    stackedPane.close();
                } catch (IllegalStateException ex) {
                    TestForEcho.getApplicationInstance().getLogger().log(ex.toString());
                }
            }
            sizeLabel.update();
        }
    }
    
    private class SizeLabel extends Label {
        public String getText() {
            return "Stacked Pane Size: " + stackedPane.size();
        }
    }
    
    private StackedPane stackedPane;
    private ControlPane controlPane;
    private int counter = 0;
    
    public StackedPaneTest() {
        setOrientation(ORIENTATION_VERTICAL);
        
        stackedPane = new StackedPane();
        add(stackedPane);
        
        controlPane = new ControlPane();
        controlPane.setHeight(150);
        add(controlPane);
    }
}
