/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.testforecho;

import nextapp.echo.Button;
import nextapp.echo.Color;
import nextapp.echo.Component;
import nextapp.echo.ContentPane;
import nextapp.echo.Font;
import nextapp.echo.Filler;
import nextapp.echo.Style;
import nextapp.echo.TextArea;
import nextapp.echo.TextField;
import nextapp.echo.text.TextComponent;

public class StyleTest extends ContentPane {

    private static final Style TEXT_COMPONENT_STYLE_A = new Style();
    static {
        TEXT_COMPONENT_STYLE_A.setAttribute(Component.STYLE_BACKGROUND, new Color(0xff, 0xff, 0xaf));
        TEXT_COMPONENT_STYLE_A.setAttribute(Component.STYLE_FOREGROUND, Color.BLACK);
        TEXT_COMPONENT_STYLE_A.setAttribute(TextComponent.STYLE_COLUMNS, 40);
        TEXT_COMPONENT_STYLE_A.setAttribute(TextComponent.STYLE_ROWS, 4);
        TEXT_COMPONENT_STYLE_A.setAttribute(TextComponent.STYLE_LINE_WRAP, true);
        TEXT_COMPONENT_STYLE_A.setAttribute(TextComponent.STYLE_BORDER_SIZE, 1);
        TEXT_COMPONENT_STYLE_A.setAttribute(TextComponent.STYLE_BORDER_COLOR, Color.DARKGRAY);
        TEXT_COMPONENT_STYLE_A.setAttribute(TextComponent.STYLE_BORDER_STYLE, TextComponent.BORDER_SOLID);
        TEXT_COMPONENT_STYLE_A.setImmutable();
    }

    private static final Style TEXT_COMPONENT_STYLE_B = new Style();
    static {
        TEXT_COMPONENT_STYLE_B.setAttribute(Component.STYLE_FONT, new Font(Font.TIMES_NEW_ROMAN, Font.ITALIC, 24));
        TEXT_COMPONENT_STYLE_B.setAttribute(Component.STYLE_FOREGROUND, Color.BLACK);
        TEXT_COMPONENT_STYLE_B.setAttribute(TextComponent.STYLE_COLUMNS, 20);
        TEXT_COMPONENT_STYLE_B.setAttribute(TextComponent.STYLE_ROWS, 2);
        TEXT_COMPONENT_STYLE_B.setImmutable();
    }
    
    private static final Style BUTTON_STYLE_C = new Style();
    static {
        BUTTON_STYLE_C.setAttribute(Component.STYLE_FONT, new Font(Font.VERDANA, Font.BOLD | Font.UNDERLINE, 12));
        BUTTON_STYLE_C.setAttribute(Component.STYLE_FOREGROUND, new Color(0x0f, 0x2f, 0x4f));
        BUTTON_STYLE_C.setAttribute(Button.STYLE_ROLLOVER_FOREGROUND, new Color(0x0f, 0xaf, 0x7f));
        BUTTON_STYLE_C.setAttribute(Button.STYLE_ROLLOVER_ENABLED, true);
        BUTTON_STYLE_C.setImmutable();
    }

    public StyleTest() {
        add(new HelpPanel("Style Test", "This test evaluates the functionality of the Style object."));
        add(Filler.createVerticalStrut(20));

        TestPanel testPanel = new TestPanel();
        add(testPanel);
        
        TextArea textArea;
        TextField textField;
        
        textField = new TextField("Type some text here");
        textField.applyStyle(TEXT_COMPONENT_STYLE_A);
        testPanel.add("TextField, Style \"A\"", textField);
        
        textArea = new TextArea("Type some text here");
        textArea.applyStyle(TEXT_COMPONENT_STYLE_A);
        testPanel.add("TextArea, Style \"A\"", textArea);
        
        textField = new TextField("Type some text here");
        textField.applyStyle(TEXT_COMPONENT_STYLE_B);
        testPanel.add("TextField, Style \"B\"", textField);
        
        textArea = new TextArea("Type some text here");
        textArea.applyStyle(TEXT_COMPONENT_STYLE_B);
        testPanel.add("TextArea, Style \"B\"", textArea);
        
        Button button;

        button = new Button("Test Button");
        button.applyStyle(BUTTON_STYLE_C);
        testPanel.add("Button, Style \"C\"", button);
    }
}
