/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.testforecho;

import nextapp.echo.Button;
import nextapp.echo.ContentPane;
import nextapp.echo.Filler;
import nextapp.echo.Label;
import nextapp.echo.TextField;
import nextapp.echo.Window;
import nextapp.echo.event.ActionEvent;
import nextapp.echo.event.ActionListener;
import nextapp.echo.text.AbstractDocument;

import nextapp.echoservlet.ServerContext;

public class TerminationTest extends ContentPane
implements ActionListener {

    private Button suspendDefault;
    private Button suspendCustom;
    private Button exitDefault;
    private Button exitCustom;
    private Button addWindow;
    private TextField defaultUriField;
    private TextField customUriField;
    private ServerContext serverContext;
    
    private class DefaultExitUriDocument extends AbstractDocument {
        public String getText() {
            return serverContext.getDefaultExitUri();
        }
        
        public void setText(String text) {
            serverContext.setDefaultExitUri(text);
        }
    }

    public TerminationTest() {
        TestForEcho app = TestForEcho.getApplicationInstance();
        serverContext = (ServerContext) app.getAttribute(ServerContext.ATTRIBUTE_NAME);
        
        add(new HelpPanel("Termination Test", 
                "This test evaluates the capability of an Echo application to suspend or exit and transfer control "
                + "of the browser to another URI.  Any windows you open should disappear when the you exit the "
                + "application, and reappear if you revisit it after suspending.  Terminating the application will "
                + "result in your user session being terminated, and a subsequent visit to the application will have "
                + "a \"clean slate.\""));
        add(Filler.createVerticalStrut(20));

        TestPanel testPanel = new TestPanel();        
        
        defaultUriField = new TextField(40);
        defaultUriField.setDocument(new DefaultExitUriDocument());
        testPanel.add("Default URI", defaultUriField);

        customUriField = new TextField("http://sf.net/projects/echo", 40);
        testPanel.add("Custom URI", customUriField);
        
        add(testPanel);
        
        add(Filler.createVerticalStrut(30));
        
        add(new Label("Suspend:"));
        
        suspendDefault = new Button("DEFAULT");
        suspendDefault.addActionListener(this);
        suspendDefault.setBackground(TestForEcho.BUTTON_BG);
        add(suspendDefault);

        suspendCustom = new Button("CUSTOM");
        suspendCustom.addActionListener(this);
        suspendCustom.setBackground(TestForEcho.BUTTON_BG);
        add(suspendCustom);
        
        add(Filler.createVerticalStrut(10));

        add(new Label("Exit:"));
        
        exitDefault = new Button("DEFAULT");
        exitDefault.addActionListener(this);
        exitDefault.setBackground(TestForEcho.BUTTON_BG);
        add(exitDefault);

        exitCustom = new Button("CUSTOM");
        exitCustom.addActionListener(this);
        exitCustom.setBackground(TestForEcho.BUTTON_BG);
        add(exitCustom);
                
        add(Filler.createVerticalStrut(10));
        
        addWindow = new Button("Add Window");
        addWindow.addActionListener(this);
        addWindow.setBackground(TestForEcho.BUTTON_BG);
        add(addWindow);
    }
    
    public void actionPerformed(ActionEvent e) {
        if (e.getSource() == addWindow) {
            ContentPane cp = new ContentPane();
            cp.add(new Label("These windows should disappear/reappear when the application is suspended/resumed."));

            Window w = new Window("Termination Test");
            w.setContent(cp);
            w.setWidth(200);
            w.setDefaultCloseOperation(Window.DISPOSE_ON_CLOSE);

            TestForEcho.getApplicationInstance().addWindow(w);
        } else if (e.getSource() == suspendDefault) {
            serverContext.suspend();
        } else if (e.getSource() == suspendCustom) {
            serverContext.suspend(customUriField.getText());
        } else if (e.getSource() == exitDefault) {
            serverContext.exit();
        } else if (e.getSource() == exitCustom) {
            serverContext.exit(customUriField.getText());
        }
    }
}
