/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.testforecho;

import nextapp.echo.AbstractPane;
import nextapp.echo.Color;
import nextapp.echo.ContainerPane;
import nextapp.echo.ContentPane;
import nextapp.echo.EchoInstance;
import nextapp.echo.Window;
import nextapp.echoservlet.ClientProperties;
import nextapp.echoservlet.ServerContext;

public class TestForEcho extends EchoInstance {

    public static final Color BUTTON_BG = new Color(0xafbfef);

    public static TestForEcho getApplicationInstance() {
        return (TestForEcho) EchoInstance.getEchoInstance();
    }
    
    private AbstractPane mainPane;
    private ContainerPane inner;
    private Controller controller;
    private ClientProperties clientProperties;
    private Logger logger;
    private Window mainWindow;
    private int controllerDelay = 0;
    
    public void doControllerDelay() {
        if (controllerDelay > 0) {
            try {
                Thread.sleep(controllerDelay);
            } catch (InterruptedException ex) {
                throw new RuntimeException("Interrupted...shouldn't happen.");
            }
        }
    }
    
    public Window init() {
    
        ServerContext context = (ServerContext) getAttribute(ServerContext.ATTRIBUTE_NAME);
        if (context != null) {
            clientProperties = context.getClientProperties();
        }
    
        logger = new Logger();
        logger.setHeight(80);
        logger.setResizable(true);
        
        controller = new Controller(this);
    
        MenuPane menuPane = new MenuPane();
        menuPane.setWidth(160);
                
        inner = new ContainerPane();
        inner.setOrientation(ContainerPane.ORIENTATION_VERTICAL);
        inner.add(logger);
        setMainPane(new ComponentHierarchyTestOne());
        
        ContainerPane outer = new ContainerPane();
        outer.setOrientation(ContainerPane.ORIENTATION_HORIZONTAL);
        outer.add(menuPane);
        outer.add(inner);
        
        mainWindow = new Window("TestForEcho");
        mainWindow.setContent(outer);
        
        return mainWindow;
    }
    
    public ClientProperties getClientProperties() {
        return clientProperties;
    }
    
    public Controller getController() {
        return controller;
    }
    
    public Logger getLogger() {
        return logger;
    }
    
    public void setControllerDelay(int controllerDelay) {
        this.controllerDelay = controllerDelay;
    }
    
    public void setMainPane(AbstractPane newValue) {
        AbstractPane oldValue = mainPane;
        
        if (newValue == null) {
            newValue = new ContentPane();
        }
        newValue.setResizable(true);
        
        if (oldValue != null) {
            inner.remove(oldValue);
        }

        inner.add(newValue, 0);
        
        mainPane = newValue;
    }
    
    public void setMainWindowTitle(String windowTitle) {
        mainWindow.setTitle(windowTitle);
    }
}
