/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */
 
package nextapp.testforecho;

import nextapp.echo.Color;
import nextapp.echo.Component;
import nextapp.echo.EchoConstants;
import nextapp.echo.Grid;
import nextapp.echo.Label;
import nextapp.echo.Style;

public class TestPanel extends Grid {
    
    private Color LIGHT_YELLOW = new Color(0xff, 0xff, 0xcf);
    private Color DARK_BLUE = new Color(0x00, 0x00, 0x7f);
    
    private static final Style TEST_PANEL_STYLE = new Style();
    static {
        TEST_PANEL_STYLE.setAttribute(Grid.STYLE_FOREGROUND, Color.BLACK);
        TEST_PANEL_STYLE.setAttribute(Grid.STYLE_BORDER_COLOR, Color.BLACK);
        TEST_PANEL_STYLE.setAttribute(Grid.STYLE_BORDER_SIZE, 1);
        TEST_PANEL_STYLE.setAttribute(Grid.STYLE_CELL_MARGIN, 5);
        TEST_PANEL_STYLE.setAttribute(Grid.STYLE_COLUMN_WIDTHS, new int[]{25, 75});
        TEST_PANEL_STYLE.setAttribute(Grid.STYLE_WIDTH, 100);
        TEST_PANEL_STYLE.setAttribute(Grid.STYLE_WIDTH_UNITS, Grid.PERCENT_UNITS);
        TEST_PANEL_STYLE.setImmutable();
    }
 
    public TestPanel() {
        super();
        setColumns(2);
        applyStyle(TEST_PANEL_STYLE);
    }
    
    public void addHeader(String header) {
        Label headerLabel = new Label(header);
        Grid.Cell cell = new Grid.Cell(headerLabel);
        cell.setColumnSpan(2);
        cell.setBackground(DARK_BLUE);
        cell.setForeground(Color.WHITE);
        cell.setHorizontalAlignment(EchoConstants.CENTER);
        add(cell);
    }
    
    public void add(String name, Component c) {
        Label nameLabel = new Label(name);
        Grid.Cell cell;
        
        cell = new Cell(nameLabel);
        cell.setBackground(LIGHT_YELLOW);
        cell.setHorizontalAlignment(EchoConstants.RIGHT);
        add(cell);
        
        cell = new Grid.Cell(c);
        cell.setBackground(Color.WHITE);
        add(cell);
    }
}
