/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.testforecho;

import nextapp.echo.Color;
import nextapp.echo.ContentPane;
import nextapp.echo.Filler;
import nextapp.echo.PasswordField;
import nextapp.echo.TextArea;
import nextapp.echo.TextField;
import nextapp.echo.text.*;
import nextapp.echo.event.ActionEvent;
import nextapp.echo.event.ActionListener;
import nextapp.echo.event.DocumentEvent;
import nextapp.echo.event.DocumentListener;

public class TextTest extends ContentPane
implements ActionListener, DocumentListener {

    public TextTest() {
        add(new HelpPanel("Text Component Test", 
                "This test evaluates the functionality of various components derived from TextComponent, including TextField, "
                + "TextArea, and PasswordField."));
        add(Filler.createVerticalStrut(20));

        TestPanel testPanel = new TestPanel();
        add(testPanel);
        
        testPanel.addHeader("Text Fields");
        
        TextField textField;

        textField = new TextField();
        testPanel.add("Plain: TextField()", textField);

        textField = new TextField("text field");
        testPanel.add("Plain: TextField(\"text field\")", textField);

        textField = new TextField(30);
        testPanel.add("Plain: TextField(30)", textField);
        
        textField = new TextField("text field", 30);
        testPanel.add("Plain: TextField(\"text field\", 30)", textField);

        textField = new TextField();
        textField.getDocument().addDocumentListener(this);
        testPanel.add("Document Listener", textField);

        textField = new TextField();
        textField.setBorderStyle(TextField.BORDER_NONE);
        testPanel.add("No border", textField);

        textField = new TextField();
        textField.setBorderColor(Color.BLACK);
        textField.setBorderSize(1);
        textField.setBorderStyle(TextField.BORDER_SOLID);
        textField.setBackground(new Color(0xff, 0xff, 0xdf));
        textField.setForeground(new Color(0x00, 0x00, 0x7f));
        textField.setToolTipText("Tool Tip Text");
        testPanel.add("Solid black 1-pixel border, dark blue text, light yellow background, tooltip", textField);

        textField = new TextField("invalid\ninput\n(contains newlines)");
        testPanel.add("Invalid input: TextField(\"invalid\\ninput\\n(contains newlines)\")", textField);
        
        textField = new TextField("Test");
        textField.addActionListener(this);
        testPanel.add("With Action Listener", textField);

        textField = new TextField("Disabled");
        textField.setEnabled(false);
        testPanel.add("Disabled", textField);

        testPanel.addHeader("Text Areas");

        TextArea textArea;
        
        textArea = new TextArea();
        testPanel.add("Plain: TextArea()", textArea);

        textArea = new TextArea("text area");
        testPanel.add("Plain: TextArea(\"text area\")", textArea);

        textArea = new TextArea(30, 3);
        testPanel.add("Plain: TextArea(30, 3)", textArea);
        
        textArea = new TextArea("text area", 30, 3);
        testPanel.add("Plain: TextArea(\"text area\", 30, 3)", textArea);

        textArea = new TextArea();
        textArea.setBorderStyle(TextArea.BORDER_NONE);
        testPanel.add("No border", textArea);

        textArea = new TextArea();
        textArea.getDocument().addDocumentListener(this);
        testPanel.add("Document Listener", textArea);

        textArea = new TextArea();
        textArea.setBorderColor(Color.BLACK);
        textArea.setBorderSize(1);
        textArea.setBorderStyle(TextArea.BORDER_SOLID);
        textArea.setBackground(new Color(0xff, 0xff, 0xdf));
        textArea.setForeground(new Color(0x00, 0x00, 0x7f));
        textArea.setToolTipText("Tool Tip Text");
        testPanel.add("Solid black 1-pixel border, dark blue text, light yellow background, tooltip", textArea);

        textArea = new TextArea("multiple\nline\n\ninput");
        testPanel.add("Multiline input: TextArea();(\"multiple\\nline\\n\\ninput\")", textArea);
        
        textArea = new TextArea("Disabled");
        textArea.setEnabled(false);
        testPanel.add("Disabled", textArea);

        testPanel.addHeader("Password Fields");
        
        PasswordField passwordField;

        passwordField = new PasswordField();
        testPanel.add("Plain: PasswordField()", passwordField);

        passwordField = new PasswordField(30);
        testPanel.add("Plain: PasswordField(30)", passwordField);
        
        passwordField = new PasswordField();
        passwordField.getDocument().addDocumentListener(this);
        testPanel.add("Document Listener", passwordField);

        passwordField = new PasswordField();
        passwordField.setBorderStyle(PasswordField.BORDER_NONE);
        testPanel.add("No border", passwordField);

        passwordField = new PasswordField();
        passwordField.setBorderColor(Color.BLACK);
        passwordField.setBorderSize(1);
        passwordField.setBorderStyle(PasswordField.BORDER_SOLID);
        passwordField.setBackground(new Color(0xff, 0xff, 0xdf));
        passwordField.setForeground(new Color(0x00, 0x00, 0x7f));
        passwordField.setToolTipText("Tool Tip Text");
        testPanel.add("Solid black 1-pixel border, dark blue text, light yellow background, tooltip", passwordField);

        passwordField = new PasswordField();
        passwordField.setEnabled(false);
        testPanel.add("Disabled", passwordField);
    }
    
    public void actionPerformed(ActionEvent e) {
        TestForEcho app = TestForEcho.getApplicationInstance();
        app.getLogger().log("Action Performed: source=\"" + e.getSource() + "\" command=\"" + e.getActionCommand() + "\"");
    }
    
    public void documentUpdate(DocumentEvent e) {
        TestForEcho app = TestForEcho.getApplicationInstance();
        Document doc = (Document) e.getSource();
        app.getLogger().log("Document Update: source=\"" + e.getSource() + "\" text=\"" + doc.getText() + "\"");
    }
}
