/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.testforecho;

import nextapp.echo.Button;
import nextapp.echo.ContentPane;
import nextapp.echo.Filler;
import nextapp.echo.Label;
import nextapp.echo.TextField;
import nextapp.echo.Window;
import nextapp.echo.event.ActionEvent;
import nextapp.echo.event.ActionListener;
import nextapp.echoservlet.ServerContext;

public class UncheckedExceptionTest extends ContentPane 
implements ActionListener {

    public class JustATestException extends RuntimeException { }
    
    private Button addWindowButton;
    private Button exceptionButton;
    private TextField errorUriField;
    private Button errorUriUpdateButton;
    
    public UncheckedExceptionTest() {
        add(new HelpPanel("Text Component Test", 
                "This test evaluates Echo's capability to shutdown an application and redirect to an "
                + "\"Error URI\" when an unhandled exception occurs.  Clicking the \"Throw Unchecked Exception\" "
                + " button will cause the application to terminate."));
        add(Filler.createVerticalStrut(20));

        addWindowButton = new Button("Add Window");
        addWindowButton.setBackground(TestForEcho.BUTTON_BG);
        addWindowButton.addActionListener(this);
        add(addWindowButton);
        
        add(Filler.createVerticalStrut(10));
        
        exceptionButton = new Button("Throw Unchecked Exception");
        exceptionButton.setBackground(TestForEcho.BUTTON_BG);
        exceptionButton.addActionListener(this);
        add(exceptionButton);
        
        add(Filler.createVerticalStrut(20));
        
        add(new Label("ErrorUri: "));
        errorUriField = new TextField(50);
        add(errorUriField);
        errorUriUpdateButton = new Button("Update");
        errorUriUpdateButton.addActionListener(this);
        add(errorUriUpdateButton);
    }
    
    public void actionPerformed(ActionEvent e) {
        TestForEcho app = TestForEcho.getApplicationInstance();
        if (e.getSource() == addWindowButton) {
            ContentPane cp = new ContentPane();
            cp.add(new Label("These windows should disappear when the exception is thrown."));

            Window w = new Window("Exception Test");
            w.setContent(cp);
            w.setWidth(200);
            w.setDefaultCloseOperation(Window.DISPOSE_ON_CLOSE);

            app.addWindow(w);
        } else if (e.getSource() == exceptionButton) {
            throw new JustATestException();
        } else if (e.getSource() == errorUriUpdateButton) {
            ServerContext context = (ServerContext) app.getAttribute(ServerContext.ATTRIBUTE_NAME);
            context.setAbnormalExitUri(errorUriField.getText());
        }
    }
}
