/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

package nextapp.testforecho;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import nextapp.echo.Button;
import nextapp.echo.Color;
import nextapp.echo.Component;
import nextapp.echo.ContainerPane;
import nextapp.echo.ContentPane;
import nextapp.echo.Filler;
import nextapp.echo.Label;
import nextapp.echo.SelectField;
import nextapp.echo.Table;
import nextapp.echo.TextField;
import nextapp.echo.Window;
import nextapp.echo.event.ActionEvent;
import nextapp.echo.event.ActionListener;
import nextapp.echo.event.ItemEvent;
import nextapp.echo.event.ItemListener;
import nextapp.echo.event.WindowEvent;
import nextapp.echo.event.WindowListener;
import nextapp.echo.table.DefaultTableColumnModel;
import nextapp.echo.table.AbstractTableModel;
import nextapp.echo.table.TableColumn;
import nextapp.echo.table.TableColumnModel;
import nextapp.echo.table.TableCellRenderer;

public class WindowTest extends ContentPane 
implements ActionListener, WindowListener {
    
    private static int nextId = 0;
                        
    private static final String[] ACTION_OPTIONS = new String[] {"", "Add", "Remove", "Show", "Hide", "To Front", "To Back",
            "Show, To Front", "Show, To Back", "Hide, To Front", "Hide, To Back", "Add, To Front", "Content Replace", 
            "Reset Content", "Set Content To Shared ContentPane"};
    private static final Object[] CLOSE_POLICY_OPTIONS = new Object[] {
                    new ListElement(new Integer(Window.DO_NOTHING_ON_CLOSE), "Do nothing on close."),
                    new ListElement(new Integer(Window.HIDE_ON_CLOSE), "Hide on close."),
                    new ListElement(new Integer(Window.DISPOSE_ON_CLOSE), "Dipose on close.")};


    private class ActionColumnRenderer 
    implements ActionListener, Serializable, TableCellRenderer {
    
        public Component getTableCellRendererComponent(Table table, java.lang.Object value, int column, int row) {
            SelectField selectField = new SelectField(ACTION_OPTIONS);
            selectField.setActionCommand(Integer.toString(row));
            selectField.addActionListener(this);

            return selectField;
        }
        
        public void actionPerformed(ActionEvent e) {
            SelectField selectField = (SelectField) e.getSource();
            Window w = windowListing.getWindow(Integer.parseInt(e.getActionCommand()));
            if (selectField.getSelectedItem() == ACTION_OPTIONS[1]) {
                TestForEcho.getApplicationInstance().addWindow(w);
            } else if (selectField.getSelectedItem() == ACTION_OPTIONS[2]) {
                TestForEcho.getApplicationInstance().removeWindow(w);
            } else if (selectField.getSelectedItem() == ACTION_OPTIONS[3]) {
                w.setVisible(true);
            } else if (selectField.getSelectedItem() == ACTION_OPTIONS[4]) {
                w.setVisible(false);
            } else if (selectField.getSelectedItem() == ACTION_OPTIONS[5]) {
                w.toFront();
            } else if (selectField.getSelectedItem() == ACTION_OPTIONS[6]) {
                w.toBack();
            } else if (selectField.getSelectedItem() == ACTION_OPTIONS[7]) {
                w.setVisible(true);
                w.toFront();
            } else if (selectField.getSelectedItem() == ACTION_OPTIONS[8]) {
                w.setVisible(true);
                w.toBack();
            } else if (selectField.getSelectedItem() == ACTION_OPTIONS[9]) {
                w.setVisible(false);
                w.toFront();
            } else if (selectField.getSelectedItem() == ACTION_OPTIONS[10]) {
                w.setVisible(false);
                w.toBack();
            } else if (selectField.getSelectedItem() == ACTION_OPTIONS[11]) {
                TestForEcho.getApplicationInstance().addWindow(w);
                w.toFront();
            } else if (selectField.getSelectedItem() == ACTION_OPTIONS[12]) {
                ContentPane cp = new ContentPane();
                cp.add(new Label("Replacement Content Pane: " + ((int) (Math.random() * 1000))));
                w.setContent(cp);
            } else if (selectField.getSelectedItem() == ACTION_OPTIONS[13]) {
                w.setContent(w.getContent());
            } else if (selectField.getSelectedItem() == ACTION_OPTIONS[14]) {
                w.setContent(sharedContentPane);
            }
            windowListing.fireTableDataChanged();
        }
    }

    private class WindowListing extends AbstractTableModel
    implements WindowListener {
    
        private List windows = new ArrayList();
        
        public void add(Window w) {
            getEchoInstance().addWindow(w);
            windows.add(w);
            w.addWindowListener(WindowListing.this);
            fireTableRowsInserted(windows.size() - 1, windows.size() - 1);
        }

        public int getColumnCount() {
            return 3;
        }
        
        public int getRowCount() {
            return windows.size();
        }
        
        public Object getValueAt(int column, int row) {
            switch (column) {
            case 0:
                return ((Window) windows.get(row)).toString();
            case 1:
                return ((Window) windows.get(row)).isRegistered() ? "Registered" : "Not Registered";
            case 2:
                return ((Window) windows.get(row)).isVisible() ? "Visible" : "Hidden";
            case 3:
                return null;
            default:
                throw new IllegalArgumentException("Illegal column value.");
            }
        }
        
        public Window getWindow(int index) {
            return (Window) windows.get(index);
        }
        
        public void windowClosed(WindowEvent e) {
            int index = windows.indexOf(e.getSource());
        
            fireTableRowsUpdated(index, index);
        }

        public void windowClosing(WindowEvent e) {
            int index = windows.indexOf(e.getSource());
        
            fireTableRowsUpdated(index, index);
        }

        public void windowOpened(WindowEvent e) {
            int index = windows.indexOf(e.getSource());
        
            fireTableRowsUpdated(index, index);
        }
    }

    private class TestWindow extends Window 
    implements ActionListener, ItemListener {
        
        private int id = nextId++;
        private SelectField closePolicySelect;
        private SelectField additionalSelectField;
        
        public TestWindow() {
            super();
            setTitle("TestWindow #" + id);
            
            this.setWidth(300);
            this.setHeight(150);
            
            addWindowListener(WindowTest.this);
            
            ContentPane pane = new ContentPane();
            setContent(pane);
            
            pane.add(new Label("Window name: " + this));
            
            pane.add(Filler.createVerticalStrut(20));

            closePolicySelect = new SelectField(CLOSE_POLICY_OPTIONS);
            closePolicySelect.addActionListener(this);
            pane.add(closePolicySelect);
            
            pane.add(Filler.createVerticalStrut(20));
            
            additionalSelectField = new SelectField(
                    new String[]{"Just", "a", "dummy", "SelectField", "with", "an", "ItemListener", "for", "testing."});
            additionalSelectField.addItemListener(this);
            pane.add(additionalSelectField);
        }
        
        public void actionPerformed(ActionEvent e) {
            setDefaultCloseOperation(((Integer) ((ListElement) closePolicySelect.getSelectedItem()).getObject()).intValue());
            TestForEcho app = TestForEcho.getApplicationInstance();
            app.getLogger().log("Default close operation changed on window: " + this);
        }
    
        public void itemStateChanged(ItemEvent e) {
            TestForEcho app = TestForEcho.getApplicationInstance();
            app.getLogger().log("Item State Changed: " + additionalSelectField.getSelectedItem());
        }
        
        public String toString() {
            return "[Window " + id + "]";
        }
    }

    private WindowListing windowListing = new WindowListing();
    private Button addWindowButton;
    private Button addEmptyWindowButton;
    private Button addEmptyContainerWindowButton;
    private Button updateWindowTitleButton;
    private TextField windowTitleField;
    private ContentPane sharedContentPane;

    public WindowTest() {
        sharedContentPane = new ContentPane();
        sharedContentPane.add(new Label("Shared Content Pane."));
        
        add(new HelpPanel("Window Test", 
                "This test evalutes Echo's capability to manage multiple Windows.  Try opening several windows "
                + "and then closing them using the Window's frame's \"X\" button."));
        add(Filler.createVerticalStrut(20));

        addWindowButton = new Button("Add Window");
        addWindowButton.addActionListener(this);
        add(addWindowButton);
        
        add(Filler.createHorizontalStrut(20));
        
        addEmptyWindowButton = new Button("Add Empty Window");
        addEmptyWindowButton.addActionListener(this);
        add(addEmptyWindowButton);
        
        add(Filler.createHorizontalStrut(20));
        
        addEmptyContainerWindowButton = new Button("Add Window w/ empty ContainerPane");
        addEmptyContainerWindowButton.addActionListener(this);
        add(addEmptyContainerWindowButton);
        
        add(Filler.createVerticalStrut(20));
        
        TableColumnModel tcm = new DefaultTableColumnModel();
        TableColumn windowIdColumn = new TableColumn(0);
        windowIdColumn.setHeaderValue("Window ID");
        tcm.addColumn(windowIdColumn);
        TableColumn registrationColumn = new TableColumn(1);
        registrationColumn.setHeaderValue("Registration State");
        tcm.addColumn(registrationColumn);
        TableColumn visibilityColumn = new TableColumn(2);
        visibilityColumn.setHeaderValue("Visibility State");
        tcm.addColumn(visibilityColumn);
        TableColumn actionColumn = new TableColumn(3);
        actionColumn.setHeaderValue("Actions");
        tcm.addColumn(actionColumn);
        actionColumn.setCellRenderer(new ActionColumnRenderer());
        
        Table table = new Table(windowListing, tcm);
        table.setBorderColor(Color.BLACK);
        table.setBorderSize(1);
        add(table);
        
        add(Filler.createVerticalStrut(20));
        
        add(new Label("Window Title:"));
        windowTitleField = new TextField();
        add(windowTitleField);
        updateWindowTitleButton = new Button("Update Window Title");
        updateWindowTitleButton.addActionListener(this);
        add(updateWindowTitleButton);
    }
    
    public void actionPerformed(ActionEvent e) {
        TestForEcho app = TestForEcho.getApplicationInstance();
        if (e.getSource() == addWindowButton) {
            // Add a TestWindow (which contains content and has a selectable close operation).
            TestWindow w = new TestWindow();
            windowListing.add(w);
            app.getLogger().log("Added window: " + w);
        } else if (e.getSource() == addEmptyWindowButton) {
            // Add window without content.
            Window w = new Window("Empty Window");
            w.setDefaultCloseOperation(Window.DISPOSE_ON_CLOSE);
            windowListing.add(w);
            app.getLogger().log("Added window: " + w);
        } else if (e.getSource() == addEmptyContainerWindowButton) {
            // Add window with empty container pane as content.
            Window w = new Window("Window w/ empty ContainerPane");
            w.setDefaultCloseOperation(Window.DISPOSE_ON_CLOSE);
            w.setContent(new ContainerPane());
            windowListing.add(w);
            app.getLogger().log("Added window: " + w);
        } else if (e.getSource() == updateWindowTitleButton) {
            app.setMainWindowTitle(windowTitleField.getText());
        }
    }
    
    public void windowClosed(WindowEvent e) {
        TestForEcho app = TestForEcho.getApplicationInstance();
        app.getLogger().log("Window closed: " + e.getSource());
    }
    
    public void windowClosing(WindowEvent e) {
        TestForEcho app = TestForEcho.getApplicationInstance();
        app.getLogger().log("Window closing: " + e.getSource());
    }
    
    public void windowOpened(WindowEvent e) {
        TestForEcho app = TestForEcho.getApplicationInstance();
        app.getLogger().log("Window opened: " + e.getSource());
    }
}
