/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

import nextapp.echo.ContentPane;
import nextapp.echo.EchoInstance;
import nextapp.echo.Filler;
import nextapp.echo.Label;
import nextapp.echo.Window;
import nextapp.echoservlet.EchoServer;
import nextapp.echoservlet.ServerContext;

/**
 * Tests ServerContext's interface to authentication capabilities.
 * The servlet container must be set up with one or more users in
 * the &quot;role1&quot; role for this test to work properly.
 * With Tomcat 4.0, this servlet should work with the stock configuration
 * using the user name "role1" and password "tomcat".
 * ServletContext/ServletConfig tests are also available from this servlet.
 */
public class AuthenticationTestServlet extends EchoServer {

    public EchoInstance newInstance() {
        return new AuthenticationTest();
    }
}

class AuthenticationTest extends EchoInstance {
    
    private ServerContext serverContext;
    
    public Window init() {
        serverContext = (ServerContext) getAttribute(ServerContext.ATTRIBUTE_NAME);
    
        Window w = new Window("Authentication Test");
        ContentPane pane = new ContentPane();
        
        if (serverContext.getUserPrincipal() == null) {
            pane.add(new Label("User: null"));
        } else {
            pane.add(new Label("User: " + serverContext.getUserPrincipal().getName()));
        }
        pane.add(Filler.createVerticalStrut(5));
        pane.add(new Label("in \"Role1\"?: " + (serverContext.isUserInRole("role1") ? "yes" : "no")));
        pane.add(Filler.createVerticalStrut(25));
        pane.add(new Label("Servlet config parameter xyz=" + serverContext.getServletConfig().getInitParameter("xyz")));
        pane.add(Filler.createVerticalStrut(5));
        pane.add(new Label("Servlet context parameter xyz=" 
               + serverContext.getServletConfig().getServletContext().getInitParameter("xyz")));

        w.setContent(pane);
        
        return w;
    }
}
