/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

import java.io.IOException;
import java.io.PrintWriter;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

public class EncodingTestServlet extends HttpServlet {
    
    private static final byte[] EXAMPLE_CHAR = new byte[]{(byte) 0xe5, (byte) 0x86, (byte) 0x8c};
    
    private static String hexValue(byte[] data) {
        StringBuffer sb = new StringBuffer();
        for (int index = 0; index < data.length; ++index) {
            int value = data[index] & 0xff;
            if (value < 16) {
                sb.append("0");
            }
            sb.append(Integer.toString(value, 16));
        }
        return sb.toString();
    }
    
    public void service(HttpServletRequest request, HttpServletResponse response) 
    throws IOException, ServletException {
//        request.setCharacterEncoding("utf-8");
        response.setContentType("text/html; charset=utf-8");
        PrintWriter w = response.getWriter();
        String testValue = request.getParameter("testValue");
        if (testValue == null) {
            testValue = "";
        }
        byte[] testByteValue = testValue.getBytes("iso-8859-1");
        String hexValue = hexValue(testByteValue);
        String utf8Value = new String(testByteValue, "utf-8");
        w.write("<html>\n");
        w.write("<body>\n");
        w.write("example8859-1=" + new String(EXAMPLE_CHAR, "iso-8859-1") + "<br>\n");
        w.write("example8859-1hex=" + hexValue(new String(EXAMPLE_CHAR, "iso-8859-1").getBytes("iso-8859-1")) + "<br>\n");
        w.write("exampleUtf8=" + new String(EXAMPLE_CHAR, "utf-8") + "<br>\n");
        w.write("exampleUtf8hex=" + hexValue(new String(EXAMPLE_CHAR, "utf-8").getBytes()) + "<br>\n");
        w.write("testValue=" + testValue + "<br>\n");
        w.write("testValue.length=" + testValue.length() + "<br>\n");
        w.write("hex=" + hexValue + "<br>\n");
        w.write("byte length=" + testByteValue.length + "<br>\n");
        w.write("utf8value=" + utf8Value + "<br>\n");
        w.write("utf8value.length=" + utf8Value.length() + "<br>\n");
        w.write("<hr>\nGET form:<br>\n");
        w.write("<form action=\"encoding\" method=\"get\" accept-charset=\"utf8\">");
        w.write("<input type=\"text\" name=\"testValue\" value=\"" + testValue + "\">\n");
        w.write("<input type=\"submit\">\n");
        w.write("</form>");
        w.write("<hr>\nPOST form:<br>\n");
        w.write("<form action=\"encoding\" method=\"post\" accept-charset=\"utf8\">");
        w.write("<input type=\"text\" name=\"testValue\" value=\"" + testValue + "\">\n");
        w.write("<input type=\"submit\">\n");
        w.write("</form>");
        w.write("</body>\n");
        w.write("</html>\n");
    }
}
