/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

import nextapp.echo.Button;
import nextapp.echo.Color;
import nextapp.echo.ContentPane;
import nextapp.echo.EchoInstance;
import nextapp.echo.Window;
import nextapp.echo.event.ActionEvent;
import nextapp.echo.event.ActionListener;
import nextapp.echoservlet.EchoServer;

public class MultipleRootPaneUpdateTestServlet extends EchoServer {

    public EchoInstance newInstance() {
        return new MultipleRootPaneUpdateTest();
    }
}

class MultipleRootPaneUpdateTest extends EchoInstance 
implements ActionListener {

    private static final String NEW_WINDOW = "newWindow";
    private static final String UPDATE = "update";

    private class TestWindow extends Window 
    implements ActionListener {
    
        public TestWindow() {
            super();
            updateContentPane();
        }
        
        private Color randomColor(boolean light) {
            int red = ((int) Math.floor(Math.random() * 128)) 
                    + (light ? 128 : 0);
            int green = ((int) Math.floor(Math.random() * 128)) 
                    + (light ? 128 : 0);
            int blue = ((int) Math.floor(Math.random() * 128)) 
                    + (light ? 128 : 0);
            return new Color(red, green, blue);
        }

        public void updateContentPane() {
            ContentPane content = new ContentPane();
            content.setBackground(randomColor(true));
            
            Button newWindowButton = new Button("New Window");
            newWindowButton.setActionCommand(NEW_WINDOW);
            newWindowButton.addActionListener(MultipleRootPaneUpdateTest.this);
            content.add(newWindowButton);

            Button updateButton = new Button("Update");
            updateButton.setActionCommand(UPDATE);
            updateButton.addActionListener(MultipleRootPaneUpdateTest.this);
            content.add(updateButton);
            
            Button closeButton = new Button("Close");
            closeButton.addActionListener(TestWindow.this);
            content.add(closeButton);
            
            setContent(content);
        }
        
        public void actionPerformed(ActionEvent e) {
            this.dispose();
        }
    }

    public void actionPerformed(ActionEvent e) {
        if (e.getActionCommand() == NEW_WINDOW) {
            Window w = new TestWindow();
            addWindow(w);
        } else if (e.getActionCommand() == UPDATE) {
            Window[] windows = MultipleRootPaneUpdateTest.this.getWindows();
            for (int index = 0; index < windows.length; ++index) {
                ((TestWindow) windows[index]).updateContentPane();
            }
        }
    }

    public Window init() {
        Window w = new TestWindow();
        return w;
    }
}
