/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.util.Enumeration;
import java.util.List;
import java.util.ArrayList;
import javax.servlet.http.HttpSession;

import nextapp.echo.Button;
import nextapp.echo.ContainerPane;
import nextapp.echo.ContentPane;
import nextapp.echo.DefaultSelectFieldModel;
import nextapp.echo.EchoInstance;
import nextapp.echo.Filler;
import nextapp.echo.SelectField;
import nextapp.echo.Window;
import nextapp.echo.event.ActionEvent;
import nextapp.echo.event.ActionListener;
import nextapp.echoservlet.EchoServer;
import nextapp.echoservlet.InstancePeer;
import nextapp.echoservlet.ServerContext;

import nextapp.testforecho.Logger;

public class SerializationTestServlet extends EchoServer {

    public EchoInstance newInstance() {
        
        return new SerializationTest();
    }
}

class SerializationTest extends EchoInstance 
implements ActionListener {
    
    private ServerContext serverContext;
    private HttpSession session;

    private Logger logger;
    private SelectField sessionSelect;
    
	/**
	 * @see nextapp.echo.EchoInstance#init()
	 */
    public Window init() {
        serverContext = (ServerContext) getAttribute(ServerContext.ATTRIBUTE_NAME);
        session = serverContext.getSession();

        Window w = new Window("Serialization Test");
        
        ContainerPane container = new ContainerPane(ContainerPane.ORIENTATION_VERTICAL);
        
        w.setContent(container);
        
        ContentPane content = new ContentPane();
        container.add(content);
        
        logger = new Logger();
        container.add(logger);
        
        sessionSelect = new SelectField();
        
        content.add(sessionSelect);
        content.add(Filler.createHorizontalStrut(20));
        Button saveButton = new Button("Serialize to disk");
        saveButton.setActionCommand("save");
        saveButton.addActionListener(this);
        content.add(saveButton);
        content.add(Filler.createVerticalStrut(20));
        Button retrieveButton = new Button("Retrieve from disk");
        retrieveButton.setActionCommand("retrieve");
        retrieveButton.addActionListener(this);
        content.add(retrieveButton);
        content.add(Filler.createVerticalStrut(20));
        Button updateButton = new Button("Update");
        updateButton.addActionListener(this);
        updateButton.setActionCommand("update");
        content.add(updateButton);
        
        return w;
    }

	public void actionPerformed(ActionEvent e) {
        if ("save".equals(e.getActionCommand())) {
            try {
                String fileName = "session.data";
                String name = (String) sessionSelect.getSelectedItem();
                InstancePeer value = (InstancePeer) session.getAttribute(name);
                if (value == null) {
                    logger.log("No application selected.");
                } else {
                    FileOutputStream fos = new FileOutputStream(fileName);
                    ObjectOutputStream oos = new ObjectOutputStream(fos);
                    oos.writeObject(name);
                    oos.writeObject(value);
                    oos.flush();
                    oos.close();
                    fos.close();
                    logger.log("Created \"" + fileName + "\" and stored application \"" + name + "\".");
                }
            } catch (IOException ex) {
                ex.printStackTrace();
                throw new IllegalStateException(ex.toString());
            }
        } else if ("retrieve".equals(e.getActionCommand())) {
            try {
                String fileName = "session.data";
                FileInputStream fis = new FileInputStream(fileName);
                ObjectInputStream ois = new ObjectInputStream(fis);
                String name = (String) ois.readObject();
                Object value = ois.readObject();
                session.setAttribute(name, value);
                ois.close();
                fis.close();
                logger.log("Opened \"" + fileName + "\" and retrieved application \"" + name + "\".");
            } catch (ClassNotFoundException ex) {
                ex.printStackTrace();
                throw new IllegalStateException(ex.toString());
            } catch (IOException ex) {
                ex.printStackTrace();
                throw new IllegalStateException(ex.toString());
            }
        } else if ("update".equals(e.getActionCommand())) {
            logger.clear();
            update();
        }
	}
    
    public void update() {
        Enumeration enum = session.getAttributeNames();
        List list = new ArrayList();
        while (enum.hasMoreElements()) {
            list.add(enum.nextElement());
        }
        String[] attributeNames = (String[]) list.toArray(new String[list.size()]);
        sessionSelect.setModel(new DefaultSelectFieldModel(attributeNames));
    }

}
