/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

import nextapp.echo.Button;
import nextapp.echo.Color;
import nextapp.echo.ContentPane;
import nextapp.echo.EchoInstance;
import nextapp.echo.Label;
import nextapp.echo.Window;
import nextapp.echo.event.ActionEvent;
import nextapp.echo.event.ActionListener;
import nextapp.echoservlet.EchoServer;

public class ButtonDemoServlet extends EchoServer {

    public EchoInstance newInstance() {
        return new ButtonDemo();
    }
}

// Note that ButtonDemo implements the interface 
// ActionListener.
class ButtonDemo extends EchoInstance 
implements ActionListener {

    private Button redButton;
    private Button greenButton;
    private Button blueButton;
        
    private ContentPane content;
    
    // The actionPerformed method is required by the 
    // interface ActionListener.  In this case, the three
    // buttons register this class as an ActionListener.
    // This method will be called when any of the buttons
    // is clicked.  An ActionEvent will be passed in that
    // describes the action, and will contain information 
    // as to which object (button) created the event (was 
    // pressed).
    public void actionPerformed(ActionEvent e) {
    
        if (e.getSource() == redButton) {
            content.setBackground(Color.RED);
        } else if (e.getSource() == greenButton) {
            content.setBackground(Color.GREEN);
        } else if (e.getSource() == blueButton) {
            content.setBackground(Color.BLUE);
        }
    }

    public Window init() {

        // The constructor for Window can specify a title.
        Window window = new Window("Button Demo");
        
        content = new ContentPane();
        
        window.setContent(content);

        Label label = new Label(
                "Click on a button to change the background"
                + " color of this window:");
        content.add(label);
 
        // Create the red button with the text "Red" as its 
        // label.
        redButton = new Button("Red");
        
        // Adds an action listener to the button, this 
        // object.  The button will call the 
        // actionPerformed() method of an action listener
        // when it is clicked.
        redButton.addActionListener(this);
        
        // Set the red button's background to be red.
        redButton.setBackground(Color.RED);
        
        // Add the red button to the content pane.
        content.add(redButton);

        // and so on...
        greenButton = new Button("Green");
        greenButton.addActionListener(this);
        greenButton.setBackground(Color.GREEN);
        content.add(greenButton);

        blueButton = new Button("Blue");
        blueButton.addActionListener(this);
        blueButton.setBackground(Color.BLUE);
        content.add(blueButton);
 
        return window;
    }
}
