/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */
 
import java.awt.Graphics2D;
import java.awt.image.BufferedImage;
 
import nextapp.echo.AwtImageReference;
import nextapp.echo.Button;
import nextapp.echo.ContentPane;
import nextapp.echo.EchoInstance;
import nextapp.echo.Window;
import nextapp.echo.event.ActionEvent;
import nextapp.echo.event.ActionListener;

import nextapp.echoservlet.EchoServer;

public class DynamicImageServlet extends EchoServer {

    public EchoInstance newInstance() {
        return new DynamicImageDemo();
    }
}

class DynamicImageDemo extends EchoInstance 
implements ActionListener {

    private BufferedImage image;
    private Button button;
    
    // Every time the button is pressed, the 
    // actionPerformed() method draws ten randomly
    // positioned and sized rectangles in random
    // colors on the button's image.
    public void actionPerformed(ActionEvent e) {
        Graphics2D g = (Graphics2D) image.getGraphics();

        for (int index = 0; index < 10; ++index) {
            int x1 = (int) (500 * Math.random());
            int y1 = (int) (250 * Math.random());
            int x2 = (int) (500 * Math.random());
            int y2 = (int) (250 * Math.random());

            if (x2 < x1) {
                int swap = x1;
                x1 = x2;
                x2 = swap;
            }

            if (y2 < y1) {
                int swap = y1;
                y1 = y2;
                y2 = swap;
            }

            // Set the AWT Graphics drawing color to a 
            // random value.
            g.setColor(new java.awt.Color(
                    (int) (Math.random() * (1 << 24))));

            // Draw a hollow rectangle on the image.
            g.drawRect(x1, y1, x2 - x1, y2 - y1);
            
        }

        // This call will cause the button to be redrawn
        // on the client browser.  This method must be
        // called in order for the browser to update
        // because no Echo components have been changed
        // in such a way that would warrant updating 
        // information on the client (only the image has
        // been altered.)
        button.getIcon().update();
    }

    public Window init() {
    
        Window window 
                = new Window("Dynamic Image Demonstration");
        
        ContentPane content = new ContentPane();
        
        window.setContent(content);
        
        // Create a new 500 by 250 pixel 
        // java.awt.BufferedImage.
        image = new BufferedImage(500, 250,
                BufferedImage.TYPE_3BYTE_BGR); 
                     
        // Create a new Button which contains the generated
        // image.  AwtImageReference implements the 
        // ImageReference interface.  This makes it possible
        // to use AwtImageReferences anywhere you've used
        // HttpImageReferences before.
        button = new Button(new AwtImageReference(image));

        button.addActionListener(this);
        
        content.add(button);
        
        return window;
    }
}
