/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

import nextapp.echo.Color;
import nextapp.echo.Component;
import nextapp.echo.ContentPane;
import nextapp.echo.EchoConstants;
import nextapp.echo.EchoInstance;
import nextapp.echo.Label;
import nextapp.echo.Table;
import nextapp.echo.Window;
import nextapp.echo.table.AbstractTableModel;
import nextapp.echo.table.TableCellRenderer;
import nextapp.echo.table.TableModel;
import nextapp.echoservlet.EchoServer;

public class MultiplicationTableServlet extends EchoServer {

    // Returns a new user-instance of the Echo application.
    public EchoInstance newInstance() {
        return new MultiplicationTableApp();
    }
}

class MultiplicationTableApp extends EchoInstance {

    class MultiplicationTableModel 
    extends AbstractTableModel {
    
        public Object getValueAt(int column, int row) {
            return new Integer((column + 1) * (row + 1));
        }
    
        public int getColumnCount() {
            return 12;
        }

        public int getRowCount() {
            return 12;
        }
    }
    
    class ValueColorRenderer 
    implements TableCellRenderer {
    
        public Component getTableCellRendererComponent(Table table, 
                Object value, int column, int row) {
            Label label = new Label(value.toString());
            int colorValue = 255 - ((Integer) value).intValue();
            label.setHorizontalAlignment(EchoConstants.RIGHT);
            label.setBackground(
                    new Color(colorValue, colorValue, 255));
            return label;
        }
    }
    
    public Window init() {
    
        TableModel model = new MultiplicationTableModel();
        Table table = new Table(model);
        table.setDefaultRenderer(Object.class, 
                new ValueColorRenderer());
                
        Window window = new Window();
        ContentPane content = new ContentPane();
        content.add(table);
        window.setContent(content);
        
        return window;
    }
}

