/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2004 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

import nextapp.echo.Button;
import nextapp.echo.Color;
import nextapp.echo.ContainerPane;
import nextapp.echo.ContentPane;
import nextapp.echo.EchoInstance;
import nextapp.echo.Filler;
import nextapp.echo.Label;
import nextapp.echo.SelectField;
import nextapp.echo.Window;

import nextapp.echo.event.ActionListener;
import nextapp.echo.event.ActionEvent;

import nextapp.echoservlet.EchoServer;

public class WindowServlet extends EchoServer {

    public EchoInstance newInstance() {
        return new WindowDemo();
    }
}

// This class extends the LayoutDemo.  It enhances it by 
// providing a user selectable border size between 0 and 8
// pixels instead of simply toggling among 0, 1, 2, 4, and 
// 8 pixels like the overriden version of changeBorderSize()
// did. It overrides only the changeBorderSize() method.  
// The  LayoutDemo object calls the changeBorderSize() 
// method when the user clicks the "Change Border Size" 
// button.  
class WindowDemo extends LayoutDemo {

    // This class needs to keep track of the state of the 
    // popup window and the select field inside of it.
    private SelectField select;
    private Window popup = null;

    // This method will be called by LayoutDemo when the
    // user clicks the "Change Border Size" button.
    public void changeBorderSize() {
    
        // If the popup window is open, close it.
        if (popup != null && popup.isVisible()) {
            popup.dispose();
        }
        
        // Create a new 300x150 popup window with the title
        // "Change Border Size"
        popup = new Window("Change Border Size");
        popup.setWidth(300);
        popup.setHeight(150);
        
        // Set the default close operation to 
        // DISPOSE_ON_CLOSE.  This will cause the popup
        // window to disappear and be destroyed if the
        // user clicks it's close button.  If you do not
        // set this attribute, the window will be reopened.
        popup.setDefaultCloseOperation(
                Window.DISPOSE_ON_CLOSE);

        // The popup window will have two panes, one which
        // contains a select field and the other which 
        // contains an Ok button.
        
        // Create the main pane.
        ContentPane mainPane = new ContentPane();
        
        mainPane.add(new Label(
                "Select a border size for the grid:"));
        mainPane.add(Filler.createVerticalStrut(10));

        // Setup the select field.  The select field can 
        // take an array of options in the form of Objects
        // as a parameter to its constructor.  It will 
        // display each object visually by calling its 
        // toString() method.
        // In this case, we create an array of strings from
        // "0" to "8".
        Object[] items = new Object[9];
        for (int index = 0; index <= 8; ++index) {
            items[index] = Integer.toString(index);
        }
        
        // Create the SelectField
        select = new SelectField(items);
        
        // Set the selected index of the SelectField to the
        // current border size of the grid.
        // The demoGrid variable is a protected instance
        // variable of LayoutDemo, which this class extends.
        select.setSelectedIndex(demoGrid.getBorderSize());
        
        mainPane.add(select);
        
        // Create the button pane.
        ContentPane buttonPane = new ContentPane();
        buttonPane.setHeight(30);
        buttonPane.setForeground(Color.WHITE);
        buttonPane.setBackground(BUTTON_PANE_BLUE);
        buttonPane.setScrollBarPolicy(
                ContentPane.SCROLL_BAR_NEVER);
        
        Button ok = new Button("Ok");
        buttonPane.add(ok);
        
        // Add an anonymous inner class as an action 
        // listener for the OK button.
        ok.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                // When clicked, the selected value of the
                // select field is determined and the
                // border of the demo grid is set
                // accordingly.
                demoGrid.setBorderSize(Integer.parseInt(
                        select.getSelectedItem()
                        .toString()));
                
                // Close the popup window.
                popup.dispose();
                popup = null;
            }
        });
        
        // Create a container pane and add the main pane
        // and the button pane to it.
        ContainerPane container = new ContainerPane();
        container.setOrientation(
                ContainerPane.ORIENTATION_VERTICAL);
        container.add(mainPane);
        container.add(buttonPane);
        
        // Set the container to be the contents of the popup
        // window.
        popup.setContent(container);
                
        // Add the window to the EchoInstance using the
        // addWindow() method.  This will cause it to be 
        // opened on the user's browser.
        addWindow(popup);
    }
}
